@@ -69,7 +69,7 @@ class CoursesControllerAssetgroups extends Hubzero_Controller
 	public function displayTask()
 	{
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Incoming
@@ -154,8 +154,6 @@ class CoursesControllerAssetgroups extends Hubzero_Controller
 			$this->view->filters['limit']
 		);
 
-		$this->_getStyles();
-
 		// Set any errors
 		if ($this->getError())
 		{
@@ -348,20 +346,7 @@ class CoursesControllerAssetgroups extends Hubzero_Controller
 			return;
 		}
 
-		$paramsClass = 'JParameter';
-		$mthd = 'bind';
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$paramsClass = 'JRegistry';
-			$mthd = 'loadArray';
-		}
-
-		$p = new $paramsClass('');
-		$p->$mthd(JRequest::getVar('params', array(), 'post'));
-
-		$model->set('params', $p->toString());
-
-		if (!$model->store(true))
+		if (!$model->store())
 		{
 			$this->setError('failed store' . $model->getError());
 			$this->addComponentMessage($model->getError(), 'error');
@@ -547,18 +532,6 @@ class CoursesControllerAssetgroups extends Hubzero_Controller
 		$row->move($inc, 'unit_id=' . $this->database->Quote($row->unit_id) . ' AND parent=' . $this->database->Quote($row->parent));
 		$row->reorder('unit_id=' . $this->database->Quote($row->unit_id) . ' AND parent=' . $this->database->Quote($row->parent));
 
-		//$unit = CoursesModelUnit::getInstance(JRequest::getInt('unit', 0));
-		//$ags = $unit->assetgroups(null, array('parent' => $row->parent));
-
-		if (($ags = $row->find(array('w' => array('parent' => $row->parent, 'unit_id' => $row->unit_id)))))
-		{
-			foreach ($ags as $ag)
-			{
-				$a = new CoursesModelAssetgroup($ag);
-				$a->store();
-			}
-		}
-
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&unit=' . JRequest::getInt('unit', 0)
 		);
