@@ -37,9 +37,9 @@ foreach ($this->rows as $row)
 	$this->ordering[$row->get('parent')][] = $row->get('id');
 }
 
-$canDo = CoursesHelper::getActions();
+$canDo = CoursesHelper::getActions('unit');
 
-JToolBarHelper::title(JText::_('COM_COURSES').': ' . JText::_('Asset groups'), 'courses.png');
+JToolBarHelper::title(JText::_('COM_COURSES').': <small><small>[ ' . JText::_('Asset groups') . ' ]</small></small>', 'courses.png');
 if ($canDo->get('core.create')) 
 {
 	JToolBarHelper::addNew();
@@ -192,11 +192,11 @@ foreach ($this->rows as $row)
 				</td>
 				<td>
 <?php if ($canDo->get('core.edit')) { ?>
-					<a class="glyph assets" href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=edit&amp;id[]=<?php echo $row->get('id'); ?>">
+					<a href="index.php?option=<?php echo $this->option ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=edit&amp;id[]=<?php echo $row->get('id'); ?>">
 						<?php echo $assets; ?>
 					</a>
 <?php } else { ?>
-					<span class="glyph assets">
+					<span>
 						<?php echo $assets; ?>
 					</span>
 <?php } ?>
