@@ -30,9 +30,18 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$canDo = CoursesHelper::getActions();
+$dateFormat = '%d %b %Y';
+$tz = null;
 
-JToolBarHelper::title(JText::_('COM_COURSES') . ': ' . JText::_('Sections'), 'courses.png');
+if (version_compare(JVERSION, '1.6', 'ge'))
+{
+	$dateFormat = 'd M Y';
+	$tz = false;
+}
+
+$canDo = CoursesHelper::getActions('unit');
+
+JToolBarHelper::title(JText::_('COM_COURSES'), 'courses.png');
 if ($canDo->get('core.create')) 
 {
 	JToolBarHelper::addNew();
@@ -145,10 +154,10 @@ foreach ($this->rows as $row)
 <?php } ?>
 				</td>
 				<td>
-					<?php echo JHTML::_('date', $row->get('start_date'), JText::_('DATE_FORMAT_HZ1')); ?>
+					<?php echo JHTML::_('date', $row->get('start_date'), $dateFormat, $tz); ?>
 				</td>
 				<td>
-					<?php echo ($row->get('end_date') && $row->get('end_date') != '0000-00-00 00:00:00') ? JHTML::_('date', $row->get('end_date'), JText::_('DATE_FORMAT_HZ1')) : JText::_('(never)'); ?>
+					<?php echo ($row->get('end_date') && $row->get('end_date') != '0000-00-00 00:00:00') ? JHTML::_('date', $row->get('end_date'), $dateFormat, $tz) : JText::_('(never)'); ?>
 				</td>
 				<td>
 					<?php if ($canDo->get('core.manage') && $students > 0) { ?>
