@@ -30,16 +30,18 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$dateFormat = '%d %b. %Y';
+$dateFormat = '%d %b, %Y';
+$dateFormat = '%d %b %Y';
 $tz = null;
 
 if (version_compare(JVERSION, '1.6', 'ge'))
 {
-	$dateFormat = 'd M. Y';
+	$dateFormat2 = 'd M, Y';
+	$dateFormat = 'd M Y';
 	$tz = false;
 }
 
-JToolBarHelper::title(JText::_('Publication Manager'), 'addedit.png');
+JToolBarHelper::title('<a href="index.php?option=' . $this->option . '&amp;controller=' . $this->controller . '">' . JText::_('Publication Manager') . '</a>', 'addedit.png');
 JToolBarHelper::preferences($this->option, '550');
 JToolBarHelper::spacer();
 
@@ -73,6 +75,7 @@ function submitbutton(pressbutton)
 				<option value="0"<?php echo ($this->filters['status'] == 0 && $this->filters['status'] != 'all') ? ' selected="selected"' : ''; ?>><?php echo JText::_('Unpublished'); ?></option>
 				<option value="1"<?php echo ($this->filters['status'] == 1) ? ' selected="selected"' : ''; ?>><?php echo JText::_('Published'); ?></option>
 				<option value="4"<?php echo ($this->filters['status'] == 4) ? ' selected="selected"' : ''; ?>><?php echo JText::_('Ready'); ?></option>
+				<option value="6"<?php echo ($this->filters['status'] == 6) ? ' selected="selected"' : ''; ?>><?php echo JText::_('Dark archive'); ?></option>
 			</select>
 		</label>
 	
@@ -111,28 +114,27 @@ $filterstring .= ($this->filters['category'])   ? '&amp;category='.$this->filter
 
 for ($i=0, $n=count($this->rows); $i < $n; $i++)
 {
-	$row = $this->rows[$i];
+	$row =& $this->rows[$i];
 
 	// Build some publishing info
 	$info  = JText::_('Created') . ': ' . $row->created . '<br />';
 	$info .= JText::_('Created by') . ': ' . $this->escape($row->created_by) . '<br />';
 
 	// Get the published status
-	$now = JFactory::getDate()->toSql();
+	$now = date( "Y-m-d H:i:s" );
 
 	// See if it's checked out or not
 	$checked = '';
 	if ($row->checked_out || $row->checked_out_time != '0000-00-00 00:00:00')
 	{
 		$info .= ($row->checked_out_time && $row->checked_out_time != '0000-00-00 00:00:00')
-				 ? JText::_('Checked out').': '.JHTML::_('date', $row->checked_out_time, $dateFormat, $tz).'<br />'
+				 ? JText::_('Checked out').': '.JHTML::_('date', $row->checked_out_time, $dateFormat2, $tz).'<br />'
 				 : '';
 		$info .= ($row->checked_out)
 				 ? JText::_('Checked out by').': '.$row->checked_out.'<br />'
 				 : '';
 		$checked = ' ['.JText::_('checked out').']';
 	}
-		
 	// What's the publication status?
 	$status = PublicationsHtml::getPubStateProperty($row, 'status');
 	$class 	= PublicationsHtml::getPubStateProperty($row, 'class');
