@@ -70,11 +70,11 @@ class ResourcesControllerItems extends Hubzero_Controller
 	public function displayTask()
 	{
 		// Push some styles to the template
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->addStyleSheet('components' . DS . $this->_option . DS . 'assets' . DS . 'css' . DS . 'resources.css');
 
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Incoming
@@ -158,11 +158,11 @@ class ResourcesControllerItems extends Hubzero_Controller
 	public function childrenTask()
 	{
 		// Push some styles to the template
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->addStyleSheet('components' . DS . $this->_option . DS . 'assets' . DS . 'css' . DS . 'resources.css');
 
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Resource's parent ID
@@ -260,13 +260,13 @@ class ResourcesControllerItems extends Hubzero_Controller
 		$this->view->setLayout('children');
 
 		// Push some styles to the template
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->addStyleSheet('components' . DS . $this->_option . DS . 'assets' . DS . 'css' . DS . 'resources.css');
 
 		$this->view->pid = '-1';
 
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Incoming
@@ -659,7 +659,7 @@ class ResourcesControllerItems extends Hubzero_Controller
 		$this->view->rconfig = $this->config;
 
 		// Push some needed styles to the tmeplate
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->addStyleSheet('components/' . $this->_option . '/assets/css/resources.css');
 
 		// Incoming resource ID
@@ -701,11 +701,11 @@ class ResourcesControllerItems extends Hubzero_Controller
 		// Is this a new resource?
 		if (!$id)
 		{
-			$this->view->row->created      = JFactory::getDate()->toSql();
+			$this->view->row->created      = date('Y-m-d H:i:s', time());
 			$this->view->row->created_by   = $this->juser->get('id');
-			$this->view->row->modified     = $this->database->getNullDate();
+			$this->view->row->modified     = '0000-00-00 00:00:00';
 			$this->view->row->modified_by  = 0;
-			$this->view->row->publish_up   = JFactory::getDate()->toSql();
+			$this->view->row->publish_up   = date('Y-m-d H:i:s', time());
 			$this->view->row->publish_down = 'Never';
 			if ($this->view->pid)
 			{
@@ -717,7 +717,6 @@ class ResourcesControllerItems extends Hubzero_Controller
 				$this->view->row->published  = 3; // default to "new" status
 				$this->view->row->standalone = 1;
 			}
-			$this->view->row->access = 0;
 		}
 
 		// Editing existing
@@ -748,13 +747,13 @@ class ResourcesControllerItems extends Hubzero_Controller
 		}
 
 		$paramsClass = 'JParameter';
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$paramsClass = 'JRegistry';
-		}
+		//if (version_compare(JVERSION, '1.6', 'ge'))
+		//{
+		//	$paramsClass = 'JRegistry';
+		//}
 
 		// Get params definitions
-		$this->view->params  = new JParameter($this->view->row->params, JPATH_COMPONENT . DS . 'resources.xml');
+		$this->view->params  = new $paramsClass($this->view->row->params, JPATH_COMPONENT . DS . 'resources.xml');
 		$this->view->attribs = new $paramsClass($this->view->row->attribs);
 
 		// Build selects of various types
@@ -800,19 +799,15 @@ class ResourcesControllerItems extends Hubzero_Controller
 			$members = null; //$mp->getRecords(array('sortby'=>'surname DESC','limit'=>'all','search'=>'','show'=>''), true);
 
 			// Get all contributors linked to this resource
-			$authnames = array();
-			if ($this->view->row->id)
-			{
-				$ma = new MembersAssociation($this->database);
-				$sql = "SELECT n.uidNumber AS id, a.authorid, a.name, n.givenName, n.middleName, n.surname, a.role, a.organization  
-						FROM " . $ma->getTableName() . " AS a  
-						LEFT JOIN " . $mp->getTableName() . " AS n ON n.uidNumber=a.authorid 
-						WHERE a.subtable='resources'
-						AND a.subid=" . $this->view->row->id . " 
-						ORDER BY a.ordering";
-				$this->database->setQuery($sql);
-				$authnames = $this->database->loadObjectList();
-			}
+			$ma = new MembersAssociation($this->database);
+			$sql = "SELECT n.uidNumber AS id, a.authorid, a.name, n.givenName, n.middleName, n.surname, a.role, a.organization  
+					FROM " . $ma->getTableName() . " AS a  
+					LEFT JOIN " . $mp->getTableName() . " AS n ON n.uidNumber=a.authorid 
+					WHERE a.subtable='resources'
+					AND a.subid=" . $this->view->row->id . " 
+					ORDER BY a.ordering";
+			$this->database->setQuery($sql);
+			$authnames = $this->database->loadObjectList();
 
 			// Build <select> of contributors
 			$authorslist = new JView(array(
@@ -872,9 +867,8 @@ class ResourcesControllerItems extends Hubzero_Controller
 		if ($isNew)
 		{
 			// New entry
-			$row->created    = $row->created ? $row->created : JFactory::getDate()->toSql();
+			$row->created    = $row->created ? $row->created : date("Y-m-d H:i:s");
 			$row->created_by = $row->created_by ? $row->created_by : $this->juser->get('id');
-			$row->access	 = 0;
 		} else {
 			$old = new ResourcesResource($this->database);
 			$old->load($row->id);
@@ -882,9 +876,9 @@ class ResourcesControllerItems extends Hubzero_Controller
 			$created_by_id = JRequest::getInt('created_by_id', 0);
 
 			// Updating entry
-			$row->modified    = JFactory::getDate()->toSql();
+			$row->modified    = date("Y-m-d H:i:s");
 			$row->modified_by = $this->juser->get('id');
-			//$row->created     = $row->created ? $row->created : JFactory::getDate()->toSql();
+			//$row->created     = $row->created ? $row->created : date("Y-m-d H:i:s");
 			if ($created_by_id)
 			{
 				$row->created_by = $row->created_by ? $row->created_by : $created_by_id;
@@ -894,61 +888,33 @@ class ResourcesControllerItems extends Hubzero_Controller
 				$row->created_by = $row->created_by ? $row->created_by : $this->juser->get('id');
 			}
 		}
-		
-		// publish up
-		$row->publish_up = JFactory::getDate($row->publish_up, JFactory::getConfig()->get('offset'))->toSql();
-		
-		// publish down
-		if (!$row->published_down || trim($row->published_down) == '0000-00-00 00:00:00' 
-			|| trim($row->publish_down) == 'Never')
+		if (trim($row->publish_down) == 'Never')
 		{
 			$row->publish_down = '0000-00-00 00:00:00';
 		}
-		else
-		{
-			$row->publish_down = JFactory::getDate($row->publish_down,
-			 	JFactory::getConfig()->get('offset'))->toSql();
-		}
-		
-		$paramsClass = 'JParameter';
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$paramsClass = 'JRegistry';
-		}
 
 		// Get parameters
-		$params = JRequest::getVar('params', array(), 'post');
+		$params = JRequest::getVar('params', '', 'post');
 		if (is_array($params))
 		{
-			$txt = new $paramsClass('');
+			$txt = array();
 			foreach ($params as $k => $v)
 			{
-				$txt->set($k, $v);
+				$txt[] = "$k=$v";
 			}
-			$row->params = $txt->toString();
+			$row->params = implode("\n", $txt);
 		}
 
 		// Get attributes
-		$attribs = JRequest::getVar('attrib', array(), 'post');
+		$attribs = JRequest::getVar('attrib', '', 'post');
 		if (is_array($attribs))
 		{
-			$txta = new $paramsClass('');
+			$txta = array();
 			foreach ($attribs as $k => $v)
 			{
-				if ($k == 'timeof')
-				{
-					if (strtotime(trim($v)) === false)
-					{
-						$v = NULL;
-					}
-					
-					$v = trim($v) 
-						? JFactory::getDate($v, JFactory::getConfig()->get('offset'))->toSql() 
-						: NULL;
-				}
-				$txta->set($k, $v);
+				$txta[] = "$k=$v";
 			}
-			$row->attribs = $txta->toString();
+			$row->attribs = implode("\n", $txta);
 		}
 
 		// Get custom areas, add wrappers, and compile into fulltxt
@@ -1181,7 +1147,7 @@ class ResourcesControllerItems extends Hubzero_Controller
 		if ($contributors && count($contributors) > 0)
 		{
 			// Email all the contributors
-			$jconfig = JFactory::getConfig();
+			$jconfig =& JFactory::getConfig();
 
 			// E-mail "from" info
 			$from = array();
@@ -1191,7 +1157,7 @@ class ResourcesControllerItems extends Hubzero_Controller
 			// Message subject
 			$subject = JText::_('EMAIL_SUBJECT');
 
-			$juri = JURI::getInstance();
+			$juri =& JURI::getInstance();
 
 			$base = $juri->base();
 			$base = trim($base, '/');
@@ -1207,7 +1173,7 @@ class ResourcesControllerItems extends Hubzero_Controller
 
 			// Send message
 			JPluginHelper::importPlugin('xmessage');
-			$dispatcher = JDispatcher::getInstance();
+			$dispatcher =& JDispatcher::getInstance();
 			if (!$dispatcher->trigger('onSendMessage', array('resources_submission_approved', $subject, $message, $from, $contributors, $this->_option)))
 			{
 				$this->setError(JText::_('Failed to message users.'));
@@ -1258,10 +1224,6 @@ class ResourcesControllerItems extends Hubzero_Controller
 			// Build the path
 			$path = ResourcesUtilities::buildUploadPath($listdir, '');
 
-			$base   = JPATH_ROOT . '/' . trim($this->config->get('webpath', '/site/resources'), '/');
-			$baseY = $base . '/'. JFactory::getDate($row->created)->format("Y");
-			$baseM = $baseY . '/' . JFactory::getDate($row->created)->format("m");
-
 			// Check if the folder even exists
 			if (!is_dir($path) or !$path)
 			{
@@ -1269,19 +1231,10 @@ class ResourcesControllerItems extends Hubzero_Controller
 			}
 			else
 			{
-				if ($path == $base 
-				 || $path == $baseY
-				 || $path == $baseM)
+				// Attempt to delete the folder
+				if (!JFolder::delete($path))
 				{
-					$this->setError(JText::_('Invalid directory.'));
-				}
-				else
-				{
-					// Attempt to delete the folder
-					if (!JFolder::delete($path))
-					{
-						$this->setError(JText::_('UNABLE_TO_DELETE_DIRECTORY'));
-					}
+					$this->setError(JText::_('UNABLE_TO_DELETE_DIRECTORY'));
 				}
 			}
 
@@ -1449,7 +1402,7 @@ class ResourcesControllerItems extends Hubzero_Controller
 				// If we're publishing, set the UP date
 				if ($publish)
 				{
-					$resource->publish_up = JFactory::getDate()->toSql();
+					$resource->publish_up = date("Y-m-d H:i:s");
 				}
 
 				// Is this a standalone resource and we need to email approved submissions?
@@ -1754,43 +1707,38 @@ class ResourcesControllerItems extends Hubzero_Controller
 	 */
 	private function userSelect($name, $active, $nouser=0, $javascript=NULL, $order='a.name')
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		$group_id = 'g.id';
 		$aro_id = 'aro.id';
 
-		if (version_compare(JVERSION, '1.6', 'lt'))
+		if (version_compare(JVERSION, '1.6', 'ge'))
 		{
-			$query = "SELECT a.id AS value, a.name AS text, g.name AS groupname"
-				. "\n FROM #__users AS a"
-				. "\n INNER JOIN #__core_acl_aro AS aro ON aro.value = a.id"	// map user to aro
-				. "\n INNER JOIN #__core_acl_groups_aro_map AS gm ON gm.aro_id = " . $aro_id . ""	// map aro to group
-				. "\n INNER JOIN #__core_acl_aro_groups AS g ON " . $group_id . " = gm.group_id"
-				. "\n WHERE a.block = '0' AND " . $group_id . "=25"
-				. "\n ORDER BY ". $order;
+			$query = "SELECT a.id AS value, a.name AS text, g.title AS groupname"
+			. "\n FROM #__users AS a"
+			. "\n INNER JOIN #__user_usergroup_map AS gm ON gm.user_id = a.id"	// map aro to group
+			. "\n INNER JOIN #__usergroups AS g ON " . $group_id . " = gm.group_id"
+			. "\n WHERE a.block = '0' AND " . $group_id . "=8"
+			. "\n ORDER BY ". $order;
 		}
 		else
 		{
-			$query = "SELECT a.id AS value, a.name AS text, g.title AS groupname"
-				. "\n FROM #__users AS a"
-				. "\n INNER JOIN #__user_usergroup_map AS gm ON gm.user_id = a.id"	// map aro to group
-				. "\n INNER JOIN #__usergroups AS g ON g.id = gm.group_id"
-				. "\n WHERE a.block = '0' AND g.title='Super Users'"
-				. "\n ORDER BY ". $order;
+			$query = "SELECT a.id AS value, a.name AS text, g.name AS groupname"
+			. "\n FROM #__users AS a"
+			. "\n INNER JOIN #__core_acl_aro AS aro ON aro.value = a.id"	// map user to aro
+			. "\n INNER JOIN #__core_acl_groups_aro_map AS gm ON gm.aro_id = " . $aro_id . ""	// map aro to group
+			. "\n INNER JOIN #__core_acl_aro_groups AS g ON " . $group_id . " = gm.group_id"
+			. "\n WHERE a.block = '0' AND " . $group_id . "=25"
+			. "\n ORDER BY ". $order;
 		}
 
 		$database->setQuery($query);
 		$result = $database->loadObjectList();
 
-		if (!$result)
-		{
-			$result = array();
-		}
-
 		if ($nouser)
 		{
 			$users[] = JHTML::_('select.option', '0', 'Do not change', 'value', 'text');
-			$users = array_merge($users, $result);
+			$users = ($result && is_array($result)) ? array_merge($users, $result) : $users;
 		}
 		else
 		{
@@ -1811,22 +1759,13 @@ class ResourcesControllerItems extends Hubzero_Controller
 		$this->view->role = JRequest::getVar('role', '');
 		$rid = JRequest::getInt('rid', 0);
 
-		// Get the member's info
-		ximport('Hubzero_User_Profile');
-		$profile = new Hubzero_User_Profile();
-		$profile->load($this->view->id);
-
-		if (!is_object($profile) || !$profile->get('uidNumber'))
+		if (is_numeric($this->view->id))
 		{
-			$this->database->setQuery("SELECT id FROM #__users WHERE `name`=" . $this->database->Quote($this->view->id));
-			if ($id = $this->database->loadResult())
-			{
-				$profile->load($id);
-			}
-		}
+			// Get the member's info
+			ximport('Hubzero_User_Profile');
+			$profile = new Hubzero_User_Profile();
+			$profile->load($this->view->id);
 
-		if (is_object($profile) && $profile->get('uidNumber'))
-		{
 			if (!$profile->get('name'))
 			{
 				$this->view->name  = $profile->get('givenName') . ' ';
@@ -1838,34 +1777,16 @@ class ResourcesControllerItems extends Hubzero_Controller
 				$this->view->name  = $profile->get('name');
 			}
 			$this->view->org = $profile->get('organization');
-			$this->view->id  = $profile->get('uidNumber');
 		}
 		else 
 		{
-			$this->view->name = null;
-
 			include_once(JPATH_COMPONENT . DS . 'tables' . DS . 'contributor.php');
 
 			$rcc = new ResourcesContributor($this->database);
 
-			if (is_numeric($this->view->id)) 
-			{
-				$this->database->setQuery("SELECT name, organization FROM #__author_assoc WHERE authorid=" . $this->database->Quote($this->view->id) . " LIMIT 1");
-				$author = $this->database->loadObject();
-
-				if (is_object($author) && $author->name)
-				{
-					$this->view->name = $author->name;
-					$this->view->org  = $author->organization;
-				}
-			}
-
-			if (!$this->view->name)
-			{
-				$this->view->org  = '';
-				$this->view->name = str_replace('_', ' ', $this->view->id);
-				$this->view->id   = $rcc->getUserId($this->view->name);
-			}
+			$this->view->org  = '';
+			$this->view->name = str_Replace('_', ' ', $this->view->id);
+			$this->view->id   = $rcc->getUserId($this->view->name);
 		}
 
 		$row = new ResourcesResource($this->database);
