@@ -30,11 +30,11 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$canDo = ResourcesHelperPermissions::getActions('resource');
+$canDo = ResourcesHelper::getActions('resource');
 
 $text = ($this->task == 'edit' ? JText::_('Edit') . ' #' . $this->row->id : JText::_('New'));
 
-JToolBarHelper::title(JText::_('Resource') . ': ' . $text, 'resources.png');
+JToolBarHelper::title(JText::_('Resource') . ': <small><small>[ ' . $text . ' ]</small></small>', 'resources.png');
 if ($canDo->get('core.edit')) 
 {
 	JToolBarHelper::spacer();
@@ -43,7 +43,7 @@ if ($canDo->get('core.edit'))
 JToolBarHelper::cancel();
 
 if ($this->row->standalone == 1) {
-	$database = JFactory::getDBO();
+	$database =& JFactory::getDBO();
 
 	$type = new ResourcesType($database);
 	$type->load($this->row->type);
@@ -74,10 +74,7 @@ if ($this->row->id) {
 
 // Instantiate the sliders object
 jimport('joomla.html.pane');
-$tabs = JPane::getInstance('sliders');
-
-$time = $this->attribs->get('timeof', '');
-$time = strtotime($time) === false ? NULL : $time;
+$tabs =& JPane::getInstance('sliders');
 ?>
 
 <script type="text/javascript">
@@ -196,15 +193,7 @@ function popratings()
 					<th class="key"><label for="attrib[location]">Location:</label></th>
 					<td><input type="text" name="attrib[location]" id="attrib[location]" size="25" maxlength="250" value="<?php echo $this->attribs->get('location', ''); ?>" /></td>
 					<th class="key"><label for="attrib[timeof]">Time:</label></th>
-					<td>
-						<input type="text" name="attrib[timeof]" id="attrib[timeof]" size="25" maxlength="250" value="<?php echo $time ? JHTML::_('date', $time, 'Y-m-d H:i:s') : ''; ?>" placeholder="<?php echo JHTML::_('date', time(), 'Y-m-d H:i:s'); ?>" /></td>
-				</tr>
-				<tr>
-					<th class="key"><label for="attrib_canonical">Canonical:</label></th>
-					<td colspan="3">
-						<input type="text" name="attrib[canonical]" id="attrib_canonical" size="25" maxlength="250" value="<?php echo $this->attribs->get('canonical', ''); ?>" />
-						<span class="hint">URL to a canonical version of this resource. Tells search engines to prefer the item entered here.</span>
-					</td>
+					<td><input type="text" name="attrib[timeof]" id="attrib[timeof]" size="25" maxlength="250" value="<?php echo $this->attribs->get('timeof', ''); ?>" /></td>
 				</tr>
 <?php } else { ?>
 					<th class="key"><label>Logical Type:</label></th>
@@ -240,7 +229,7 @@ function popratings()
 					<td colspan="4">
 						<label>Intro Text:</label><br />
 						<?php
-						$editor = JFactory::getEditor();
+						$editor =& JFactory::getEditor();
 						echo $editor->display('introtext', $this->escape(stripslashes($this->row->introtext)), '100%', '100px', '45', '10', false);
 						?>
 					</td>
@@ -285,7 +274,7 @@ function popratings()
 			<tr>
 				<th><?php echo JText::_('Created:'); ?></th>
 				<td>
-					<?php echo JHTML::_('date', $this->row->created, JText::_('DATE_FORMAT_LC2')); ?>
+					<?php echo $this->row->created; ?>
 				</td>
 			</tr>
 			<tr>
@@ -299,7 +288,7 @@ function popratings()
 			<tr>
 				<th><?php echo JText::_('Modified:'); ?></th>
 				<td>
-					<?php echo JHTML::_('date', $this->row->modified, JText::_('DATE_FORMAT_LC2')); ?>
+					<?php echo $this->row->modified; ?>
 				</td>
 			</tr>
 			<tr>
@@ -386,28 +375,20 @@ function popratings()
 					<td class="paramlist_key"><label>Change Creator:</label></th>
 					<td><?php echo $this->lists['created_by']; ?></td>
 				</tr>
-<?php // if ($this->row->standalone == 1) { ?>
+<?php if ($this->row->standalone == 1) { ?>
 				<tr>
 					<td class="paramlist_key"><label for="publish_up">Start Publishing:</label></th>
 					<td>
-						<?php $up = JHTML::_('date', $this->row->publish_up, 'Y-m-d H:i:s'); ?>
-						<?php echo JHTML::_('calendar', $up, 'publish_up', 'publish_up', "%Y-%m-%d", array('class' => 'inputbox')); ?>
+						<?php echo JHTML::_('calendar', $this->row->publish_up, 'publish_up', 'publish_up', "%Y-%m-%d", array('class' => 'inputbox')); ?>
 					</td>
 				</tr>
 				<tr>
 					<td class="paramlist_key"><label for="publish_down">Finish Publishing:</label></th>
 					<td>
-						<?php
-							$down = 'Never';
-							if (strtolower($this->row->publish_down) != 'never')
-							{
-								$down = JHTML::_('date', $this->row->publish_down, 'Y-m-d H:i:s');
-							}
-						?>
-						<?php echo JHTML::_('calendar', $down, 'publish_down', 'publish_down', "%Y-%m-%d", array('class' => 'inputbox')); ?>
+						<?php echo JHTML::_('calendar', $this->row->publish_down, 'publish_down', 'publish_down', "%Y-%m-%d", array('class' => 'inputbox')); ?>
 					</td>
 				</tr>
-<?php // } ?>
+<?php } ?>
 				<tr>
 					<td class="paramlist_key"><strong>Hits:</strong></td>
 					<td>
