@@ -45,11 +45,11 @@ class StoreControllerOrders extends Hubzero_Controller
 	 */
 	public function execute()
 	{
-		$upconfig = JComponentHelper::getParams('com_members');
+		$upconfig =& JComponentHelper::getParams('com_members');
 		$this->banking = $upconfig->get('bankAccounts');
 		ximport('Hubzero_Bank');
-		
-		parent::execute();		
+
+		parent::execute();
 	}
 
 	/**
@@ -63,7 +63,7 @@ class StoreControllerOrders extends Hubzero_Controller
 		$this->view->store_enabled = $this->config->get('store_enabled');
 
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Get paging variables
@@ -123,7 +123,7 @@ class StoreControllerOrders extends Hubzero_Controller
 				}
 				$o->itemtitles = $items;
 
-				$targetuser = JUser::getInstance($o->uid);
+				$targetuser =& JUser::getInstance($o->uid);
 				$o->author = $targetuser->get('username');
 			}
 		}
@@ -202,7 +202,7 @@ class StoreControllerOrders extends Hubzero_Controller
 				return;
 			}
 
-			$customer = JUser::getInstance($row->uid);
+			$customer =& JUser::getInstance($row->uid);
 		}
 		else
 		{
@@ -217,10 +217,10 @@ class StoreControllerOrders extends Hubzero_Controller
 	//	require_once(JPATH_COMPONENT . DS . 'helpers' . DS . 'receipt.pdf.php');
 
 		// Get the Joomla config
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 
 		// Build the link displayed
-		$juri = JURI::getInstance();
+		$juri =& JURI::getInstance();
 		$sef = JRoute::_('index.php?option=' . $this->_option);
 		if (substr($sef, 0, 1) == '/')
 		{
@@ -321,7 +321,7 @@ class StoreControllerOrders extends Hubzero_Controller
 		
 		if (!is_dir( $dir ))
 		{
-			if (!JFolder::create( $dir ))
+			if (!JFolder::create( $dir, 0755 ))
 			{
 				jimport('joomla.filesystem.folder');
 				JError::raiseError(500, 'Failed to create folder to store receipts');
@@ -407,7 +407,7 @@ class StoreControllerOrders extends Hubzero_Controller
 				}
 			}
 
-			$this->view->customer = JUser::getInstance($this->view->row->uid);
+			$this->view->customer =& JUser::getInstance($this->view->row->uid);
 
 			// Check available user funds		
 			$BTL = new Hubzero_Bank_Teller($this->database, $this->view->row->uid);
@@ -436,10 +436,19 @@ class StoreControllerOrders extends Hubzero_Controller
 	 */
 	public function saveTask()
 	{
+		$dateFormat = '%d %b, %Y';
+		$tz = null;
+
+		if (version_compare(JVERSION, '1.6', 'ge'))
+		{
+			$dateFormat = 'd M, Y';
+			$tz = false;
+		}
+
 		// Check for request forgeries
 		JRequest::checkToken() or jexit('Invalid Token');
 
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 
 		$statusmsg = '';
 		$email = 1; // turn emailing on/off
@@ -461,19 +470,19 @@ class StoreControllerOrders extends Hubzero_Controller
 			$row->total = $cost;
 
 			// get user bank account
-			//$xprofile = Hubzero_User_Profile::getInstance($row->uid);
-			$xprofile = JUser::getInstance($row->uid);
+			//$xprofile =& Hubzero_User_Profile::getInstance($row->uid);
+			$xprofile =& JUser::getInstance($row->uid);
 			$BTL_Q = new Hubzero_Bank_Teller($this->database, $xprofile->get('id'));
 
 			// start email message
-			$emailbody .= JText::_('COM_STORE_THANKYOU').' '.JText::_('COM_STORE_IN_THE').' '.$jconfig->getValue('config.sitename').' '.JText::_('COM_STORE_STORE').'!'."\r\n\r\n";
-			$emailbody .= JText::_('COM_STORE_EMAIL_UPDATE').':'."\r\n";
+			$emailbody .= JText::_('THANKYOU').' '.JText::_('IN_THE').' '.$jconfig->getValue('config.sitename').' '.JText::_('STORE').'!'."\r\n\r\n";
+			$emailbody .= JText::_('EMAIL_UPDATE').':'."\r\n";
 			$emailbody .= '----------------------------------------------------------'."\r\n";
-			$emailbody .= JText::_('COM_STORE_ORDER').' '.JText::_('COM_STORE_NUM').': '. $id ."\r\n";
-			$emailbody .= "\t".JText::_('COM_STORE_ORDER').' '.JText::_('COM_STORE_TOTAL').': '. $cost ."\r\n";
-			$emailbody .= "\t\t".JText::_('COM_STORE_PLACED').': '. JHTML::_('date', $row->ordered, JText::_('COM_STORE_DATE_FORMAT_HZ1'))."\r\n";
-			$emailbody .= "\t\t".JText::_('COM_STORE_STATUS').': ';
-			
+			$emailbody .= JText::_('ORDER').' '.JText::_('NUM').': '. $id ."\r\n";
+			$emailbody .= "\t".JText::_('ORDER').' '.JText::_('TOTAL').': '. $cost ."\r\n";
+			$emailbody .= "\t\t".JText::_('PLACED').': '. JHTML::_('date', $row->ordered, $dateFormat, $tz)."\r\n";
+			$emailbody .= "\t\t".JText::_('STATUS').': ';
+
 			switch ($action)
 			{
 				case 'complete_order':
@@ -493,13 +502,13 @@ class StoreControllerOrders extends Hubzero_Controller
 					// debit account
 					if ($cost > 0)
 					{
-						$BTL_Q->withdraw($cost, JText::_('COM_STORE_BANKING_PURCHASE').' #'.$id, 'store', $id);
+						$BTL_Q->withdraw($cost, JText::_('BANKING_PURCHASE').' #'.$id, 'store', $id);
 					}
 
 					// update order information
-					$row->status_changed = JFactory::getDate()->toSql();
+					$row->status_changed = date("Y-m-d H:i:s");
 					$row->status = 1;
-					$statusmsg = JText::_('COM_STORE_ORDER') . ' #' . $id . ' ' . JText::_('COM_STORE_HAS_BEEN') . ' ' . strtolower(JText::_('COM_STORE_COMPLETED')) . '.';
+					$statusmsg = JText::_('ORDER') . ' #' . $id . ' ' . JText::_('HAS_BEEN') . ' ' . strtolower(JText::_('COMPLETED')) . '.';
 				break;
 
 				case 'cancel_order':
@@ -517,18 +526,18 @@ class StoreControllerOrders extends Hubzero_Controller
 						return;
 					}
 					// update order information
-					$row->status_changed = JFactory::getDate()->toSql();
+					$row->status_changed = date("Y-m-d H:i:s");
 					$row->status = 2;
 
-					$statusmsg = JText::_('COM_STORE_ORDER') . ' #' . $id . ' ' . JText::_('COM_STORE_HAS_BEEN') . ' ' . strtolower(JText::_('COM_STORE_CANCELLED')) . '.';
+					$statusmsg = JText::_('ORDER') . ' #' . $id . ' ' . JText::_('HAS_BEEN') . ' ' . strtolower(JText::_('CANCELLED')) . '.';
 				break;
 
 				case 'message':
-					$statusmsg = JText::_('COM_STORE_MSG_SENT') . '.';
+					$statusmsg = JText::_('MSG_SENT') . '.';
 				break;
 
 				default:
-					$statusmsg = JText::_('COM_STORE_ORDER_DETAILS_UPDATED') . '.';
+					$statusmsg = JText::_('ORDER_DETAILS_UPDATED') . '.';
 				break;
 			}
 
@@ -549,19 +558,19 @@ class StoreControllerOrders extends Hubzero_Controller
 			switch ($row->status)
 			{
 				case 0: ;
-					$emailbody .= ' ' . JText::_('COM_STORE_IN_PROCESS') . "\r\n";
+					$emailbody .= ' ' . JText::_('IN_PROCESS') . "\r\n";
 					break;
 				case 1:
-					$emailbody .= ' '.strtolower(JText::_('COM_STORE_COMPLETED')).' '.JText::_('COM_STORE_ON').' '.JHTML::_('date', $row->status_changed, JText::_('COM_STORE_DATE_FORMAT_HZ1'))."\r\n\r\n";
-					$emailbody .= JText::_('COM_STORE_EMAIL_PROCESSED').'.'."\r\n";
+					$emailbody .= ' '.strtolower(JText::_('COMPLETED')).' '.JText::_('ON').' '.JHTML::_('date', $row->status_changed, $dateFormat, $tz)."\r\n\r\n";
+					$emailbody .= JText::_('EMAIL_PROCESSED').'.'."\r\n";
 					break;
 				case 2:
 				default:
-					$emailbody .= ' '.strtolower(JText::_('COM_STORE_CANCELLED')).' '.JText::_('COM_STORE_ON').' '.JHTML::_('date', $row->status_changed, JText::_('COM_STORE_DATE_FORMAT_HZ1'))."\r\n\r\n";
-					$emailbody .= JText::_('COM_STORE_EMAIL_CANCELLED').'.'."\r\n";
+					$emailbody .= ' '.strtolower(JText::_('CANCELLED')).' '.JText::_('ON').' '.JHTML::_('date', $row->status_changed, $dateFormat, $tz)."\r\n\r\n";
+					$emailbody .= JText::_('EMAIL_CANCELLED').'.'."\r\n";
 					break;
 			}
-			
+
 			if ($data['message'])
 			{ // add custom message			
 				$emailbody .= $data['message']."\r\n";
@@ -572,32 +581,13 @@ class StoreControllerOrders extends Hubzero_Controller
 			{
 				if ($email)
 				{
-					$admin_email = $jconfig->getValue('config.mailfrom');
-					$subject     = $jconfig->getValue('config.sitename') . ' ' . JText::_('COM_STORE_STORE') . ': ' . JText::_('COM_STORE_EMAIL_UPDATE_SHORT') . ' #' . $id;
-					$from        = $jconfig->getValue('config.sitename') . ' ' . JText::_('COM_STORE_STORE');
-					
-					$message = new \Hubzero\Mail\Message();
-					$message->setSubject($subject)
-					->addTo($row->email)
-					->addFrom($admin_email, $from)
-					->setPriority('normal');
-					
-					$message->addPart($emailbody, 'text/plain');
-					
-					$message->addHeader('X-Mailer', 'PHP/' . phpversion())
-					->addHeader('X-Component', $this->_option);
-					
-					$message->send();
-
-					/*
 					ximport('Hubzero_Toolbox');
 					$admin_email = $jconfig->getValue('config.mailfrom');
-					$subject     = $jconfig->getValue('config.sitename') . ' ' . JText::_('COM_STORE_STORE') . ': ' . JText::_('COM_STORE_EMAIL_UPDATE_SHORT') . ' #' . $id;
-					$from        = $jconfig->getValue('config.sitename') . ' ' . JText::_('COM_STORE_STORE');
+					$subject     = $jconfig->getValue('config.sitename') . ' ' . JText::_('STORE') . ': ' . JText::_('EMAIL_UPDATE_SHORT') . ' #' . $id;
+					$from        = $jconfig->getValue('config.sitename') . ' ' . JText::_('STORE');
 					$hub         = array('email' => $admin_email, 'name' => $from);
 
 					Hubzero_Toolbox::send_email($hub, $row->email, $subject, $emailbody);
-					*/
 				}
 			}
 		}
