@@ -52,10 +52,10 @@ class SupportControllerTickets extends Hubzero_Controller
 	{
 		// Get configuration
 		$config = JFactory::getConfig();
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 
 		// Push some styles to the template
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->addStyleSheet('components' . DS . $this->_option . DS . 'assets' . DS . 'css' . DS . $this->_name . '.css');
 
 		$obj = new SupportTicket($this->database);
@@ -241,7 +241,7 @@ class SupportControllerTickets extends Hubzero_Controller
 		$this->view->setLayout('edit');
 
 		// Push some styles to the template
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->addStyleSheet('components' . DS . $this->_option . DS . 'assets' . DS . 'css' . DS . $this->_name . '.css');
 		//$document->addScript('/components' . DS . 'com_support' . DS . 'autosave.js');
 
@@ -262,7 +262,7 @@ class SupportControllerTickets extends Hubzero_Controller
 			$comments = $sc->getComments('admin', $row->id);
 
 			// Parse comment text for attachment tags
-			$juri = JURI::getInstance();
+			$juri =& JURI::getInstance();
 			$webpath = str_replace('/administrator/', '/', $juri->base() . $this->config->get('webpath', '/site/tickets') . DS . $id);
 			$webpath = str_replace('//','/',$webpath);
 			if (isset($_SERVER['HTTPS']))
@@ -291,7 +291,7 @@ class SupportControllerTickets extends Hubzero_Controller
 			// Creating a new ticket
 			$row->severity = 'normal';
 			$row->status   = 0;
-			$row->created  = JFactory::getDate()->toSql();
+			$row->created  = date('Y-m-d H:i:s', time());
 			$row->login    = $this->juser->get('username');
 			$row->name     = $this->juser->get('name');
 			$row->email    = $this->juser->get('email');
@@ -589,56 +589,11 @@ class SupportControllerTickets extends Hubzero_Controller
 			$rowc->ticket     = $id;
 			$rowc->comment    = nl2br($comment);
 			$rowc->comment    = str_replace('<br>', '<br />', $rowc->comment);
-			$rowc->created    = JFactory::getDate()->toSql();
+			$rowc->created    = date('Y-m-d H:i:s', time());
 			$rowc->created_by = JRequest::getVar('username', '');
 			$rowc->changelog  = json_encode($log);
 			$rowc->access     = JRequest::getInt('access', 0);
 
-			// Add any CCs to the e-mail list
-			$cc = JRequest::getVar('cc', '', 'post');
-			if (trim($cc))
-			{
-				$cc = explode(',', $cc);
-				$cc = array_map('trim', $cc);
-				foreach ($cc as $acc)
-				{
-					// Check the format accepted [ID, username, Name (username), Name (email)]
-					if (!is_numeric($acc) && strstr($acc, '('))
-					{
-						$acc = trim(preg_replace('/(.+?)\s+\((.+?)\)/i', '$2', $acc));
-					}
-
-					// Is this a username/ID or email address?
-					if (!strstr($acc, '@'))
-					{
-						// Username or user ID - load the user
-						$juser = JUser::getInstance($acc);
-
-						// Did we find an account?
-						if (!is_object($juser))
-						{
-							// Move on - nothing else we can do here
-							continue;
-						}
-
-						$log['cc'][] = $juser->get('username');
-					}
-					// Make sure it's a valid e-mail address
-					elseif (SupportUtilities::checkValidEmail($acc))
-					{
-						// Is the comment private? If so, we do NOT send e-mail to submitter
-						if ($rowc->access != 1 && strtolower($row->email) == strtolower($acc)) 
-						{
-							continue;
-						}
-
-						$log['cc'][] = $acc;
-					}
-				}
-			}
-
-			$rowc->changelog  = json_encode($log);
-
 			if ($rowc->check())
 			{
 				// If we're only recording a changelog, make it private
@@ -657,8 +612,8 @@ class SupportControllerTickets extends Hubzero_Controller
 				// otherwise, we're only recording a changelog
 				if ($comment || $row->owner != $old->owner)
 				{
-					$juri = JURI::getInstance();
-					$jconfig = JFactory::getConfig();
+					$juri =& JURI::getInstance();
+					$jconfig =& JFactory::getConfig();
 
 					$base = $juri->base();
 					if (substr($base, -14) == 'administrator/')
@@ -711,7 +666,7 @@ class SupportControllerTickets extends Hubzero_Controller
 					}
 					$message['plaintext'] .= $attach->parse($comment) . "\r\n\r\n";
 
-					// Prepare message to allow email responses to be parsed and added to the ticket
+                    // Prepare message to allow email responses to be parsed and added to the ticket
 					if ($allowEmailResponses)
 					{
 						$live_site = rtrim(JURI::base(),'/');
@@ -761,7 +716,7 @@ class SupportControllerTickets extends Hubzero_Controller
 
 					// Send e-mail to admin?
 					JPluginHelper::importPlugin('xmessage');
-					$dispatcher = JDispatcher::getInstance();
+					$dispatcher =& JDispatcher::getInstance();
 
 					// Send e-mail to ticket submitter?
 					$email_submitter = JRequest::getInt('email_submitter', 0);
@@ -774,7 +729,7 @@ class SupportControllerTickets extends Hubzero_Controller
 							jimport('joomla.user.helper');
 							if (($zid = JUserHelper::getUserId($row->login)))
 							{
-								$zuser = JUser::getInstance($row->login);
+								$zuser =& JUser::getInstance($row->login);
 							}
 							// Make sure there even IS an e-mail and it's valid
 							if (is_object($zuser) && $zuser->get('id'))
@@ -838,7 +793,7 @@ class SupportControllerTickets extends Hubzero_Controller
 					{
 						if ($row->owner)
 						{
-							$juser = JUser::getInstance($row->owner);
+							$juser =& JUser::getInstance($row->owner);
 
 							// Only put tokens in if component is configured to allow email responses to tickets and ticket comments
 							if ($allowEmailResponses)
@@ -864,12 +819,12 @@ class SupportControllerTickets extends Hubzero_Controller
 					}
 
 					// Add any CCs to the e-mail list
-					//$cc = JRequest::getVar('cc', '', 'post');
-					if (count($log['cc']))
+					$cc = JRequest::getVar('cc', '', 'post');
+					if (trim($cc))
 					{
-						//$cc = explode(',', $cc);
-						//$cc = array_map('trim', $cc);
-						foreach ($log['cc'] as $acc)
+						$cc = explode(',', $cc);
+						$cc = array_map('trim', $cc);
+						foreach ($cc as $acc)
 						{
 							// Check the format accepted [ID, username, Name (username), Name (email)]
 							if (!is_numeric($acc) && strstr($acc, '('))
@@ -881,7 +836,7 @@ class SupportControllerTickets extends Hubzero_Controller
 							if (!strstr($acc, '@'))
 							{
 								// Username or user ID - load the user
-								$juser = JUser::getInstance($acc);
+								$juser =& JUser::getInstance($acc);
 
 								// Did we find an account?
 								if (!is_object($juser))
@@ -917,7 +872,7 @@ class SupportControllerTickets extends Hubzero_Controller
 										'name'    => $juser->get('name'),
 										'address' => $juser->get('email')
 									);
-									//$log['cc'][] = $juser->get('username');
+									$log['cc'][] = $juser->get('username');
 								}
 							}
 							// Make sure it's a valid e-mail address
@@ -939,7 +894,7 @@ class SupportControllerTickets extends Hubzero_Controller
 								{
 									$emails[] = $acc;
 								}
-								//$log['cc'][] = $acc;
+								$log['cc'][] = $acc;
 							}
 						}
 					}
@@ -1099,48 +1054,40 @@ class SupportControllerTickets extends Hubzero_Controller
 	 */
 	private function _userSelect($name, $active, $nouser=0, $javascript=NULL, $order='a.name')
 	{
-		$query = "SELECT a.username AS value, a.name AS text"
-			. " FROM #__users AS a"
-			. " INNER JOIN #__support_acl_aros AS aro ON aro.model='user' AND aro.foreign_key = a.id"
-			. " WHERE a.block = '0'"
-			. " ORDER BY ". $order;
+		$group_id = 'g.id';
+		$aro_id = 'aro.id';
+
+		if (version_compare(JVERSION, '1.6', 'ge'))
+		{
+			$query = "SELECT a.username AS value, a.name AS text, g.title AS groupname"
+			. "\n FROM #__users AS a"
+			. "\n INNER JOIN #__user_usergroup_map AS gm ON gm.user_id = a.id"	// map aro to group
+			. "\n INNER JOIN #__usergroups AS g ON " . $group_id . " = gm.group_id"
+			. "\n WHERE a.block = '0' AND " . $group_id . "=8"
+			. "\n ORDER BY ". $order;
+		}
+		else
+		{
+			$query = "SELECT a.username AS value, a.name AS text, g.name AS groupname"
+			. "\n FROM #__users AS a"
+			. "\n INNER JOIN #__core_acl_aro AS aro ON aro.value = a.id"	// map user to aro
+			. "\n INNER JOIN #__core_acl_groups_aro_map AS gm ON gm.aro_id = " . $aro_id . ""	// map aro to group
+			. "\n INNER JOIN #__core_acl_aro_groups AS g ON " . $group_id . " = gm.group_id"
+			. "\n WHERE a.block = '0' AND " . $group_id . "=25"
+			. "\n ORDER BY ". $order;
+		}
 
 		$this->database->setQuery($query);
-		if ($nouser) 
+		if ($nouser)
 		{
 			$users[] = JHTML::_('select.option', '', 'No User', 'value', 'text');
 			$users = array_merge($users, $this->database->loadObjectList());
-		} 
-		else 
+		}
+		else
 		{
 			$users = $this->database->loadObjectList();
 		}
 
-		$query = "SELECT a.username AS value, a.name AS text, aro.alias"
-			. " FROM #__users AS a"
-			. " INNER JOIN #__xgroups_members AS m ON m.uidNumber = a.id"
-			. " INNER JOIN #__support_acl_aros AS aro ON aro.model='group' AND aro.foreign_key = m.gidNumber"
-			. " WHERE a.block = '0'"
-			. " ORDER BY ". $order;
-		$this->database->setQuery($query);
-		if ($results = $this->database->loadObjectList())
-		{
-			$groups = array();
-			foreach ($results as $result)
-			{
-				if (!isset($groups[$result->alias]))
-				{
-					$groups[$result->alias] = array();
-				}
-				$groups[$result->alias][] = $result;
-			}
-			foreach ($groups as $name => $gusers)
-			{
-				$users[] = JHTML::_('select.optgroup', JText::_('group:') . ' ' . $name);
-				$users = array_merge($users, $gusers);
-			}
-		}
-
 		$users = JHTML::_('select.genericlist', $users, $name, ' '. $javascript, 'value', 'text', $active, false, false);
 
 		return $users;
@@ -1183,7 +1130,7 @@ class SupportControllerTickets extends Hubzero_Controller
 						$users[] = JHTML::_('select.optgroup', stripslashes($hzg->description));
 						foreach ($members as $member)
 						{
-							$u = JUser::getInstance($member);
+							$u =& JUser::getInstance($member);
 							if (!is_object($u))
 							{
 								continue;
@@ -1212,7 +1159,7 @@ class SupportControllerTickets extends Hubzero_Controller
 
 				foreach ($members as $member)
 				{
-					$u = JUser::getInstance($member);
+					$u =& JUser::getInstance($member);
 					if (!is_object($u))
 					{
 						continue;
@@ -1372,12 +1319,12 @@ class SupportControllerTickets extends Hubzero_Controller
 		}
 
 		// Construct our file path
-		$file_path = JPATH_ROOT . DS . trim($this->config->get('webpath', '/site/tickets'), DS) . DS . $listdir;
+		$file_path = JPATH_ROOT . $this->config->get('webpath') . DS . $listdir;
 
 		if (!is_dir($file_path))
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($file_path))
+			if (!JFolder::create($file_path, 0777))
 			{
 				$this->setError(JText::_('COM_SUPPORT_UNABLE_TO_CREATE_UPLOAD_PATH'));
 				return '';
@@ -1388,18 +1335,9 @@ class SupportControllerTickets extends Hubzero_Controller
 		jimport('joomla.filesystem.file');
 		$file['name'] = JFile::makeSafe($file['name']);
 		$file['name'] = str_replace(' ', '_', $file['name']);
-		$ext = strtolower(JFile::getExt($file['name']));
-
-		$filename = JFile::stripExt($file['name']);
-		while (file_exists($file_path . DS . $filename . '.' . $ext)) 
-		{
-			$filename .= rand(10, 99);
-		}
-
-		$finalfile = $file_path . DS . $filename . '.' . $ext;
 
 		// Perform the upload
-		if (!JFile::upload($file['tmp_name'], $finalfile))
+		if (!JFile::upload($file['tmp_name'], $file_path . DS . $file['name']))
 		{
 			$this->setError(JText::_('COM_SUPPORT_ERROR_UPLOADING'));
 			return '';
@@ -1407,11 +1345,11 @@ class SupportControllerTickets extends Hubzero_Controller
 		else
 		{
 			// Scan for viruses
-			//$path = $file_path . DS . $file['name']; //JPATH_ROOT . DS . 'virustest';
-			exec("clamscan -i --no-summary --block-encrypted $finalfile", $output, $status);
+			$path = $file_path . DS . $file['name']; //JPATH_ROOT . DS . 'virustest';
+			exec("clamscan -i --no-summary --block-encrypted $path", $output, $status);
 			if ($status == 1)
 			{
-				if (JFile::delete($finalfile)) 
+				if (JFile::delete($path)) 
 				{
 					$this->setError(JText::_('File rejected due to possible security risk.'));
 					return '';
@@ -1424,9 +1362,9 @@ class SupportControllerTickets extends Hubzero_Controller
 
 			$row = new SupportAttachment($this->database);
 			$row->bind(array(
-				'id'          => 0,
-				'ticket'      => $listdir,
-				'filename'    => $filename . '.' . $ext,
+				'id' => 0,
+				'ticket' => $listdir,
+				'filename' => $file['name'],
 				'description' => $description
 			));
 			if (!$row->check())
