@@ -2,7 +2,7 @@
 /**
  * HUBzero CMS
  *
- * Copyright 2005-2013 Purdue University. All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
  * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
@@ -24,54 +24,36 @@
  *
  * @package   hubzero-cms
  * @author    Shawn Rice <zooley@purdue.edu>
- * @copyright Copyright 2005-2013 Purdue University. All rights reserved.
+ * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
  * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_answers' . DS . 'tables' . DS . 'questionslog.php');
-require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_answers' . DS . 'tables' . DS . 'question.php');
+define('ANSWERS_STATE_OPEN',    0);
+define('ANSWERS_STATE_CLOSED',  1);
+define('ANSWERS_STATE_DELETED', 2);
 
+require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_answers' . DS . 'tables' . DS . 'question.php');
+require_once(JPATH_ROOT . DS . 'components' . DS . 'com_answers' . DS . 'helpers' . DS . 'tags.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_answers' . DS . 'helpers' . DS . 'economy.php');
 
-require_once(JPATH_ROOT . DS . 'components' . DS . 'com_answers' . DS . 'models' . DS . 'tags.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_answers' . DS . 'models' . DS . 'abstract.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_answers' . DS . 'models' . DS . 'response.php');
+require_once(JPATH_ROOT . DS . 'components' . DS . 'com_answers' . DS . 'models' . DS . 'iterator.php');
 
 /**
- * Answers mdoel class for a question
+ * Courses model class for a forum
  */
 class AnswersModelQuestion extends AnswersModelAbstract
 {
-	/**
-	 * Open state
-	 * 
-	 * @var integer
-	 */
-	const ANSWERS_STATE_OPEN   = 0;
-
-	/**
-	 * Closed state
-	 * 
-	 * @var integer
-	 */
-	const ANSWERS_STATE_CLOSED = 1;
-
-	/**
-	 * Deleted
-	 * 
-	 * @var integer
-	 */
-	const ANSWERS_STATE_DELETE = 2;
-
 	/**
 	 * Table class name
 	 * 
 	 * @var string
 	 */
-	protected $_tbl_name = 'AnswersTableQuestion';
+	protected $_tbl_name = 'AnswersQuestion';
 
 	/**
 	 * Class scope
@@ -88,7 +70,7 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	private $_comment = null;
 
 	/**
-	 * \Hubzero\ItemList
+	 * AnswersModelIterator
 	 * 
 	 * @var object
 	 */
@@ -104,17 +86,10 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	/**
 	 * Flag for if authorization checks have been run
 	 * 
-	 * @var boolean
+	 * @var mixed
 	 */
 	private $_authorized = false;
 
-	/**
-	 * URL for this entry
-	 * 
-	 * @var string
-	 */
-	private $_base = 'index.php?option=com_answers';
-
 	/**
 	 * Returns a reference to a question model
 	 *
@@ -122,7 +97,7 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	 *     $offering = AnswersModelQuestion::getInstance($id);
 	 *
 	 * @param      integer $oid Question ID
-	 * @return     object AnswersModelQuestion
+	 * @return     object ForumModelCourse
 	 */
 	static function &getInstance($oid=null)
 	{
@@ -148,7 +123,7 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	 */
 	public function isClosed()
 	{
-		if ($this->get('state') == static::ANSWERS_STATE_CLOSED) 
+		if ($this->get('state') == ANSWERS_STATE_CLOSED) 
 		{
 			return true;
 		}
@@ -162,7 +137,21 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	 */
 	public function isOpen()
 	{
-		if ($this->get('state') == static::ANSWERS_STATE_OPEN) 
+		if ($this->get('state') == ANSWERS_STATE_OPEN) 
+		{
+			return true;
+		}
+		return false;
+	}
+
+	/**
+	 * Is the question open?
+	 * 
+	 * @return     boolean
+	 */
+	public function isDeleted()
+	{
+		if ($this->get('state') == ANSWERS_STATE_DELETED) 
 		{
 			return true;
 		}
@@ -181,7 +170,7 @@ class AnswersModelQuestion extends AnswersModelAbstract
 			return 0;
 		}
 
-		if ($this->get('reward', -1) == 1)
+		if ($this->get('reward', -1) == -1)
 		{
 			$BT = new Hubzero_Bank_Transaction($this->_db);
 			$this->set('reward', $BT->getAmount('answers', 'hold', $this->get('id')));
@@ -201,7 +190,29 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	}
 
 	/**
-	 * Set and get a specific comment
+	 * Get the creator of this entry
+	 * 
+	 * Accepts an optional property name. If provided
+	 * it will return that property value. Otherwise,
+	 * it returns the entire JUser object
+	 *
+	 * @return     mixed
+	 */
+	public function creator($property=null)
+	{
+		if (!isset($this->_creator) || !is_object($this->_creator))
+		{
+			$this->_creator = JUser::getInstance($this->get('created_by'));
+		}
+		if ($property && is_a($this->_creator, 'JUser'))
+		{
+			return $this->_creator->get($property);
+		}
+		return $this->_creator;
+	}
+
+	/**
+	 * Set and get a specific offering
 	 * 
 	 * @return     void
 	 */
@@ -211,9 +222,7 @@ class AnswersModelQuestion extends AnswersModelAbstract
 		 || ($id !== null && (int) $this->_comment->get('id') != $id))
 		{
 			$this->_comment = null;
-
-			// See if we already have a list of comments that we can look through
-			if ($this->_comments instanceof \Hubzero\ItemList)
+			if (isset($this->_comments) && is_a($this->_comments, 'AnswersModelIterator'))
 			{
 				foreach ($this->_comments as $key => $comment)
 				{
@@ -224,11 +233,8 @@ class AnswersModelQuestion extends AnswersModelAbstract
 					}
 				}
 			}
-
-			// Nothing found so far?
 			if (!$this->_comment)
 			{
-				// Load the record
 				$this->_comment = AnswersModelComment::getInstance($id);
 			}
 		}
@@ -236,40 +242,31 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	}
 
 	/**
-	 * Get a list of responses
+	 * Get a list of categories for a forum
+	 *   Accepts either a numeric array index or a string [id, name]
+	 *   If index, it'll return the entry matching that index in the list
+	 *   If string, it'll return either a list of IDs or names
 	 * 
-	 * @param      string  $rtrn    Data type to return [count, list]
-	 * @param      array   $filters Filters to apply to query
-	 * @param      boolean $clear   Clear cached data?
-	 * @return     mixed Returns an integer or array depending upon format chosen
+	 * @param      mixed $idx Index value
+	 * @return     array
 	 */
-	public function comments($rtrn='list', $filters=array(), $clear=false)
+	public function comments($rtrn='list', $filters=array())
 	{
-		$tbl = new AnswersTableResponse($this->_db);
+		$tbl = new AnswersResponse($this->_db);
 
 		if (!isset($filters['qid']))
 		{
 			$filters['qid'] = $this->get('id');
 		}
-		if (!isset($filters['state']))
-		{
-			$filters['state']    = 1;
-		}
-		if (!isset($filters['filterby']))
-		{
-			$filters['filterby'] = 'rejected';
-		}
-		if (!isset($filters['replies']))
-		{
-			$filters['replies'] = true;
-		}
+		$filters['state']    = 1;
+		$filters['filterby'] = 'rejected';
 		$filters['sort']     = 'created';
 		$filters['sort_Dir'] = 'DESC';
 
 		switch (strtolower($rtrn))
 		{
 			case 'count':
-				if (!isset($this->_comments_count) || $clear)
+				if ($this->get('comments_count', null) === null)
 				{
 					$total = 0;
 
@@ -280,7 +277,7 @@ class AnswersModelQuestion extends AnswersModelAbstract
 					foreach ($c as $com)
 					{
 						$total++;
-						if ($filters['replies'] && $com->replies()->total()) 
+						if ($com->replies()) 
 						{
 							foreach ($com->replies() as $rep)
 							{
@@ -292,16 +289,15 @@ class AnswersModelQuestion extends AnswersModelAbstract
 							}
 						}
 					}
-
-					$this->_comments_count = $total;
+					$this->set('comments_count', $total);
 				}
-				return $this->_comments_count;
+				return $this->get('comments_count', 0);
 			break;
 
 			case 'list':
 			case 'results':
 			default:
-				if (!($this->_comments instanceof \Hubzero\ItemList) || $clear) 
+				if ($this->get('comments', null) === null || !is_a($this->get('comments'), 'AnswersModelIterator'))
 				{
 					if ($results = $tbl->getResults($filters))
 					{
@@ -314,23 +310,25 @@ class AnswersModelQuestion extends AnswersModelAbstract
 					{
 						$results = array();
 					}
-					$this->_comments = new \Hubzero\ItemList($results);
+					$this->set('comments', new AnswersModelIterator($results));
 				}
-				return $this->_comments;
+				return $this->get('comments');
 			break;
 		}
 	}
 
 	/**
-	 * Get a list of chosen responses
+	 * Get a list of categories for a forum
+	 *   Accepts either a numeric array index or a string [id, name]
+	 *   If index, it'll return the entry matching that index in the list
+	 *   If string, it'll return either a list of IDs or names
 	 * 
-	 * @param      string $rtrn    Data type to return [count, list]
-	 * @param      array  $filters Filters to apply to query
-	 * @return     mixed Returns an integer or array depending upon format chosen
+	 * @param      mixed $idx Index value
+	 * @return     array
 	 */
 	public function chosen($rtrn='list', $filters=array())
 	{
-		$tbl = new AnswersTableResponse($this->_db);
+		$tbl = new AnswersResponse($this->_db);
 
 		if (!isset($filters['qid']))
 		{
@@ -354,7 +352,7 @@ class AnswersModelQuestion extends AnswersModelAbstract
 			case 'list':
 			case 'results':
 			default:
-				if ($this->get('chosen', null) === null || !($this->get('chosen') instanceof \Hubzero\ItemList))
+				if ($this->get('chosen', null) === null || !is_a($this->get('chosen'), 'AnswersModelIterator'))
 				{
 					if ($results = $tbl->getResults($filters))
 					{
@@ -367,7 +365,7 @@ class AnswersModelQuestion extends AnswersModelAbstract
 					{
 						$results = array();
 					}
-					$this->set('chosen', new \Hubzero\ItemList($results));
+					$this->set('chosen', new AnswersModelIterator($results));
 				}
 				return $this->get('chosen');
 			break;
@@ -375,35 +373,33 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	}
 
 	/**
-	 * Get tags on the entry
-	 * Optinal first agument to determine format of tags
+	 * Check if the current user is enrolled
 	 * 
-	 * @param      string  $as    Format to return state in [comma-deliminated string, HTML tag cloud, array]
-	 * @param      integer $admin Include amdin tags? (defaults to no)
-	 * @return     mixed
+	 * @return     boolean
 	 */
-	public function tags($as='cloud', $admin=0)
+	public function tags($what='cloud')
 	{
-		if (!$this->exists())
-		{
-			switch (strtolower($as))
-			{
-				case 'array':
-					return array();
-				break;
+		$bt = new AnswersTags($this->_db);
 
-				case 'string':
-				case 'cloud':
-				case 'html':
-				default:
-					return '';
-				break;
-			}
+		$tags = null;
+
+		$what = strtolower(trim($what));
+		switch ($what)
+		{
+			case 'array':
+				$tags = $bt->get_tags_on_object($this->get('id'), 0, 0);
+			break;
+
+			case 'string':
+				$tags = $bt->get_tag_string($this->get('id'));
+			break;
+
+			case 'cloud':
+				$tags = $bt->get_tag_cloud(0, 0, $this->get('id'));
+			break;
 		}
 
-		$cloud = new AnswersModelTags($this->get('id'));
-
-		return $cloud->render($as, array('admin' => $admin));
+		return $tags; 
 	}
 
 	/**
@@ -411,23 +407,23 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	 * 
 	 * @return     boolean
 	 */
-	public function tag($tags=null, $user_id=0, $admin=0)
+	public function tag($tags=null, $user_id=0)
 	{
-		$cloud = new AnswersModelTags($this->get('id'));
+		$bt = new AnswersTags($this->_db);
 
-		return $cloud->setTags($tags, $user_id, $admin);
-	}
+		if (!$user_id)
+		{
+			$juser = JFactory::getUser();
+			$user_id = $juser->get('id');
+		}
 
-	/**
-	 * Add a single tag to the entry
-	 * 
-	 * @return     boolean
-	 */
-	public function addTag($tag=null, $user_id=0, $admin=0)
-	{
-		$cloud = new AnswersModelTags($this->get('id'));
-
-		return $cloud->add($tag, $user_id, $admin);
+		return $bt->tag_object(
+			$user_id, 
+			$this->get('id'), 
+			trim($tags), 
+			1, 
+			1
+		);
 	}
 
 	/**
@@ -464,10 +460,14 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	 * Link will vary depending upon action desired, such as edit, delete, etc.
 	 * 
 	 * @param      string $type The type of link to return
-	 * @return     string
+	 * @return     boolean
 	 */
 	public function link($type='')
 	{
+		if (!isset($this->_base))
+		{
+			$this->_base = 'index.php?option=com_answers';
+		}
 		$link = $this->_base;
 
 		// If it doesn't exist or isn't published
@@ -490,7 +490,7 @@ class AnswersModelQuestion extends AnswersModelAbstract
 			break;
 
 			case 'math':
-				$link .= '&task=question&id=' . $this->get('id') . '#math';
+				$link .= '&task=math&id=' . $this->get('id');
 			break;
 
 			case 'report':
@@ -507,16 +507,35 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	}
 
 	/**
-	 * Get the content of the record. 
-	 * Optional argument to determine how content should be handled
-	 *
-	 * parsed - performs parsing on content (i.e., converting wiki markup to HTML)
-	 * clean  - parses content and then strips tags
-	 * raw    - as is, no parsing
+	 * Return a formatted timestamp
 	 * 
-	 * @param      string  $as      Format to return content in [parsed, clean, raw]
+	 * @param      string $as What data to return
+	 * @return     boolean
+	 */
+	public function published($as='')
+	{
+		switch (strtolower($as))
+		{
+			case 'date':
+				return JHTML::_('date', $this->get('created'), ANSWERS_DATE_FORMAT, ANSWERS_DATE_TIMEZONE);
+			break;
+
+			case 'time':
+				return JHTML::_('date', $this->get('created'), ANSWERS_TIME_FORMAT, ANSWERS_DATE_TIMEZONE);
+			break;
+
+			default:
+				return $this->get('created');
+			break;
+		}
+	}
+
+	/**
+	 * Get the state of the entry as either text or numerical value
+	 * 
+	 * @param      string  $as      Format to return state in [text, number]
 	 * @param      integer $shorten Number of characters to shorten text to
-	 * @return     string
+	 * @return     mixed String or Integer
 	 */
 	public function content($as='parsed', $shorten=0)
 	{
@@ -530,7 +549,15 @@ class AnswersModelQuestion extends AnswersModelAbstract
 					return $this->get('question_parsed');
 				}
 
-				$p = Hubzero_Wiki_Parser::getInstance();
+				$paramsClass = 'JParameter';
+				if (version_compare(JVERSION, '1.6', 'ge'))
+				{
+					$paramsClass = 'JRegistry';
+				}
+
+				//$config = JComponentHelper::getParams($option);
+
+				$p =& Hubzero_Wiki_Parser::getInstance();
 
 				$wikiconfig = array(
 					'option'   => 'com_answers',
@@ -573,11 +600,11 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	}
 
 	/**
-	 * Get the subject in various formats
+	 * Get the state of the entry as either text or numerical value
 	 * 
 	 * @param      string  $as      Format to return state in [text, number]
 	 * @param      integer $shorten Number of characters to shorten text to
-	 * @return     string
+	 * @return     mixed String or Integer
 	 */
 	public function subject($as='parsed', $shorten=0)
 	{
@@ -591,7 +618,15 @@ class AnswersModelQuestion extends AnswersModelAbstract
 					return $this->get('subject_parsed');
 				}
 
-				$p = Hubzero_Wiki_Parser::getInstance();
+				$paramsClass = 'JParameter';
+				if (version_compare(JVERSION, '1.6', 'ge'))
+				{
+					$paramsClass = 'JRegistry';
+				}
+
+				//$config = JComponentHelper::getParams($option);
+
+				$p =& Hubzero_Wiki_Parser::getInstance();
 
 				$wikiconfig = array(
 					'option'   => 'com_answers',
@@ -634,95 +669,9 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	}
 
 	/**
-	 * Check if a user has voted for this entry
+	 * Store changes to this offering
 	 *
-	 * @param      integer $user_id Optinal user ID to set as voter
-	 * @return     integer
-	 */
-	public function voted($user_id=0)
-	{
-		if ($this->get('voted', -1) == -1)
-		{
-			$juser = ($user_id) ? JUser::getInstance($user_id) : JFactory::getUser();
-
-			// See if a person from this IP has already voted in the last week
-			$aql = new AnswersTableQuestionsLog($this->_db);
-			$this->set(
-				'voted', 
-				$aql->checkVote($this->get('id'), Hubzero_Environment::ipAddress(), $juser->get('id'))
-			);
-		}
-
-		return $this->get('voted', 0);
-	}
-
-	/**
-	 * Vote for the entry
-	 *
-	 * @param      integer $vote    The vote [0, 1]
-	 * @param      integer $user_id Optinal user ID to set as voter
-	 * @return     boolean False if error, True on success
-	 */
-	public function vote($vote=0, $user_id=0)
-	{
-		if (!$this->exists())
-		{
-			$this->setError(JText::_('No record found'));
-			return false;
-		}
-
-		if (!$vote)
-		{
-			$this->setError(JText::_('No vote provided'));
-			return false;
-		}
-
-		$juser = ($user_id) ? JUser::getInstance($user_id) : JFactory::getUser();
-
-		$al = new AnswersTableQuestionsLog($this->_db);
-		$al->qid   = $this->get('id');
-		$al->ip    = Hubzero_Environment::ipAddress();
-		$al->voter = $juser->get('id');
-
-		if ($al->checkVote($al->qid, $al->ip, $al->voter))
-		{
-			$this->setError(JText::_('COM_ANSWERS_NOTICE_ALREADY_VOTED_FOR_QUESTION'));
-			return false;
-		}
-
-		if ($this->get('created_by') == $juser->get('username')) 
-		{
-			$this->setError(JText::_('COM_ANSWERS_NOTICE_RECOMMEND_OWN_QUESTION'));
-			return false;
-		}
-
-		$this->set('helpful', (int) $this->get('helpful') + 1);
-
-		if (!$this->store()) 
-		{
-			return false;
-		}
-
-		$al->expires = date('Y-m-d H:i:s', time() + (7 * 24 * 60 * 60)); // in a week
-
-		if (!$al->check()) 
-		{
-			$this->setError($al->getError());
-			return false;
-		}
-		if (!$al->store()) 
-		{
-			$this->setError($al->getError());
-			return false;
-		}
-
-		return true;
-	}
-
-	/**
-	 * Accept a response as the chosen answer
-	 *
-	 * @param     integer $answer_id ID of response to be chosen
+	 * @param     boolean $check Perform data validation check?
 	 * @return    boolean False if error, True on success
 	 */
 	public function accept($answer_id=0)
@@ -751,8 +700,8 @@ class AnswersModelQuestion extends AnswersModelAbstract
 		// Mark the question as answered
 		$this->set('state', 1);
 
-		// If banking is enabled
-		if ($this->config('banking'))
+		// If this question has a reward...
+		if ($this->get('reward'))
 		{
 			// Accepted answer is same person as question submitter?
 			if ($this->get('created_by') == $answer->get('created_by'))
@@ -788,71 +737,98 @@ class AnswersModelQuestion extends AnswersModelAbstract
 	}
 
 	/**
-	 * Distribute points
-	 *
-	 * @return    void
+	 * Check a user's authorization
+	 * 
+	 * @param      string $action Action to check
+	 * @return     boolean True if authorized, false if not
 	 */
-	public function adjustCredits()
+	public function access($action='view')
 	{
-		if ($this->get('reward'))
+		if (!$this->_authorized)
 		{
-			// Adjust credits
-			// Remove hold
-			$BT = new Hubzero_Bank_Transaction($this->_db);
-			$reward = $BT->getAmount('answers', 'hold', $this->get('id'));
-			$BT->deleteRecords('answers', 'hold', $this->get('id'));
+			// Set NOT viewable by default
+			// We need to ensure the forum is published first
+			$this->params->set('access-view-entry', false);
 
-			// Make credit adjustment
-			if (is_object($this->creator()))
+			if ($this->exists() && $this->isAvailable())
 			{
-				$BTL = new Hubzero_Bank_Teller($this->_db, $this->creator('id'));
-				$credit = $BTL->credit_summary();
-				$adjusted = $credit - $reward;
-				$BTL->credit_adjustment($adjusted);
+				$this->params->set('access-view-entry', true);
 			}
 
-			$this->set('reward', 0);
-		}
-	}
-
-	/**
-	 * Delete the record and all associated data
-	 *
-	 * @return    boolean False if error, True on success
-	 */
-	public function delete()
-	{
-		// Ensure we have a database to work with
-		if (empty($this->_db))
-		{
-			$this->setError(JText::_('Database not found.'));
-			return false;
-		}
-
-		// Can't delete what doesn't exist
-		if (!$this->exists()) 
-		{
-			return true;
-		}
-
-		// Adjust credits
-		$this->adjustCredits();
-
-		// Remove comments
-		foreach ($this->comments('list', array('filterby' => 'all')) as $comment)
-		{
-			if (!$comment->delete())
+			$juser = JFactory::getUser();
+			if ($juser->get('guest'))
 			{
-				$this->setError($comment->getError());
-				return false;
+				$this->_authorized = true;
+			}
+			else
+			{
+				// Anyone logged in can create a forum
+				//$this->params->set('access-create-entry', true);
+
+				// Check if they're a site admin
+				if (version_compare(JVERSION, '1.6', 'lt'))
+				{
+					if ($juser->authorize('com_blog', 'manage')) 
+					{
+						$this->params->set('access-admin-entry', true);
+						$this->params->set('access-manage-entry', true);
+						$this->params->set('access-delete-entry', true);
+						$this->params->set('access-edit-entry', true);
+						$this->params->set('access-edit-state-entry', true);
+						$this->params->set('access-edit-own-entry', true);
+					}
+				}
+				else 
+				{
+					$this->params->set('access-admin-entry', $juser->authorise('core.admin', $this->get('id')));
+					$this->params->set('access-manage-entry', $juser->authorise('core.manage', $this->get('id')));
+					$this->params->set('access-delete-entry', $juser->authorise('core.manage', $this->get('id')));
+					$this->params->set('access-edit-entry', $juser->authorise('core.manage', $this->get('id')));
+					$this->params->set('access-edit-state-entry', $juser->authorise('core.manage', $this->get('id')));
+					$this->params->set('access-edit-own-entry', $juser->authorise('core.manage', $this->get('id')));
+				}
+
+				// If they're not an admin
+				if (!$this->params->get('access-admin-entry') 
+				 && !$this->params->get('access-manage-entry'))
+				{
+					// Does the forum exist?
+					/*if (!$this->exists())
+					{
+						// Give editing access if the blog doesn't exist
+						// i.e., it's a new forum
+						switch ($this->get('scope'))
+						{
+							case 'site':
+							break;
+							
+							case 'member':
+							break;
+						}
+						$this->params->set('access-view-entry', true);
+						$this->params->set('access-delete-entry', true);
+						$this->params->set('access-edit-entry', true);
+						$this->params->set('access-edit-state-entry', true);
+						$this->params->set('access-edit-own-entry', true);
+					}
+					// Check if they're the forum creator or forum manager
+					else*/
+					if ($this->get('created_by') == $juser->get('id')) 
+					{
+						// Give full access
+						$this->params->set('access-view-entry', true);
+						$this->params->set('access-manage-entry', true);
+						$this->params->set('access-delete-entry', true);
+						$this->params->set('access-edit-entry', true);
+						$this->params->set('access-edit-state-entry', true);
+						$this->params->set('access-edit-own-entry', true);
+					}
+				}
+
+				$this->_authorized = true;
 			}
 		}
-
-		// Remove all tags
-		$this->tag('');
-
-		// Attempt to delete the record
-		return parent::delete();
+		return $this->params->get('access-' . strtolower($action) . '-entry');
 	}
 }
 
