@@ -99,28 +99,6 @@ if (!$this->question->get('anonymous'))
 					<span class="closed"><?php echo JText::_('COM_ANSWERS_STATUS_CLOSED'); ?></span></p>
 				<?php } ?>
 				</p>
-				<?php
-				$tags = $this->question->tags('array', 1);
-				$resource = null;
-				foreach ($tags as $tag)
-				{
-					if (preg_match('/^tool:/i', $tag->get('raw_tag')))
-					{
-						$resource = 'alias=' . substr($tag->get('raw_tag'), strlen('tool:'));
-					}
-					else if (preg_match('/^resource:/i', $tag->get('raw_tag')))
-					{
-						$resource = 'id=' . substr($tag->get('raw_tag'), strlen('resource:'));
-					}
-					if ($resource)
-					{
-						?>
-						<p><?php echo JText::sprintf('COM_ANSWERS_QUESTION_ASKED_ON', '<a href="' . JRoute::_('index.php?option=com_resources&' . $resource) . '">' . JText::_('COM_ANSWERS_FOLLOWING_RESOURCE') . '</a>'); ?></p>
-						<?php 
-						break;
-					}
-				}
-				?>
 
 			<?php if ($this->question->reward() && $this->question->isOpen() && $this->question->config('banking')) { ?>
 				<p class="intro">
@@ -128,9 +106,9 @@ if (!$this->question->get('anonymous'))
 				</p>
 			<?php } ?>
 
-			<?php if ($this->question->get('maxaward') && $this->question->isOpen() && $this->question->config('banking')) { ?>
+			<?php if ($this->question->get('maxaward') && $this->question->isOpen() && $this->banking) { ?>
 				<p class="youcanearn">
-					<?php echo JText::sprintf('COM_ANSWERS_EARN_UP_TO_FOR_BEST_ANSWER', $this->question->get('maxaward')); ?>
+					<?php echo JText::sprintf('COM_ANSWERS_EARN_UP_TO_FOR_BEST_ANSWER', $this->question->get('maxaward')); ?> <a href="<?php echo JRoute::_($this->question->link('math')); ?>"><?php echo JText::_('COM_ANSWERS_DETAILS'); ?></a>
 				</p>
 			<?php } ?>
 			</div><!-- / .status_display -->
@@ -140,7 +118,8 @@ if (!$this->question->get('anonymous'))
 	<div class="subject">
 		<div class="entry question" id="q<?php echo $this->question->get('id'); ?>">
 			<p class="entry-member-photo">
-				<img src="<?php echo $this->question->creator()->getPicture($this->question->get('anonymous')); ?>" alt="" />
+				<span class="question-anchor"><a name="q<?php echo $this->question->get('id'); ?>"></a></span>
+				<img src="<?php echo Hubzero_User_Profile_Helper::getMemberPhoto($user, $this->question->get('anonymous')); ?>" alt="" />
 			</p><!-- / .question-member-photo -->
 			<div class="entry-content">
 			<?php if (!$this->question->isReported()) { ?>
@@ -163,9 +142,9 @@ if (!$this->question->get('anonymous'))
 					<strong><?php echo $name; ?></strong> 
 					<a class="permalink" href="<?php echo JRoute::_($this->question->link()); ?>" title="<?php echo JText::_('COM_ANSWERS_PERMALINK'); ?>">
 						<span class="entry-date-at"><?php echo JText::_('COM_ANSWERS_DATETIME_AT'); ?></span> 
-						<span class="icon-time time"><time datetime="<?php echo $this->question->created(); ?>"><?php echo $this->question->created('time'); ?></time></span> 
+						<span class="icon-time time"><time datetime="<?php echo $this->question->published(); ?>"><?php echo $this->question->published('time'); ?></time></span> 
 						<span class="entry-date-on"><?php echo JText::_('COM_ANSWERS_DATETIME_ON'); ?></span> 
-						<span class="icon-date date"><time datetime="<?php echo $this->question->created(); ?>"><?php echo $this->question->created('date'); ?></time></span>
+						<span class="icon-date date"><time datetime="<?php echo $this->question->published(); ?>"><?php echo $this->question->published('date'); ?></time></span>
 					</a>
 				</p><!-- / .question-title -->
 
@@ -185,7 +164,7 @@ if (!$this->question->get('anonymous'))
 			<?php } ?>
 
 				<div class="entry-tags">
-					<?php echo $this->question->tags('cloud', 0); ?>
+					<?php echo $this->question->tags('cloud'); ?>
 				</div><!-- / .question-tags -->
 		<?php } ?>
 			</div><!-- / .question-content -->
@@ -227,15 +206,15 @@ if (!$this->question->get('anonymous'))
 			<div class="subject-wrap">
 				<p class="warning"><?php echo JText::_('COM_ANSWERS_NOTICE_CONFIRM_DELETE'); ?></p>
 
-				<form action="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=deleteq&id=' . $this->question->get('id')); ?>" method="post" id="deleteForm">
+				<form action="<?php echo JRoute::_('index.php?option=' . $this->option . '&task=delete'); ?>" method="post" id="deleteForm">
 					<input type="hidden" name="qid" value="<?php echo $this->question->get('id'); ?>" />
 					<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 					<input type="hidden" name="controller" value="<?php echo $this->controller; ?>" />
 					<input type="hidden" name="task" value="deleteq" />
 
 					<p class="submit">
-						<input class="btn btn-danger" type="submit" value="<?php echo JText::_('COM_ANSWERS_YES_DELETE'); ?>" />
-						<a class="btn btn-secondary" href="<?php echo JRoute::_($this->question->link()); ?>"><?php echo JText::_('COM_ANSWERS_NO_DELETE'); ?></a>
+						<input class="btn btn-success btn-primary" type="submit" value="<?php echo JText::_('COM_ANSWERS_YES_DELETE'); ?>" />
+						<a class="btn btn-danger btn-secondary" href="<?php echo JRoute::_($this->question->link()); ?>"><?php echo JText::_('COM_ANSWERS_NO_DELETE'); ?></a>
 					</p>
 				</form>
 			</div><!-- / .subject-wrap -->
@@ -248,6 +227,8 @@ if (!$this->question->get('anonymous'))
 
 	<?php if ($this->responding == 6 && $this->question->isOpen() && $this->question->config('banking')) { // show how points are awarded   ?>
 	<div class="below section">
+		<h3><?php echo JText::_('COM_ANSWERS_POINTS_BREAKDOWN'); ?></h3>
+
 		<div class="aside">
 			<div class="container">
 				<p class="info"><?php echo JText::_('COM_ANSWERS_POINT_BREAKDOWN_TBL_SUMMARY'); ?></p>
@@ -256,55 +237,54 @@ if (!$this->question->get('anonymous'))
 
 		<div class="subject">
 			<div class="subject-wrap">
-				<table id="pointbreakdown">
-					<caption><?php echo JText::_('COM_ANSWERS_POINTS_BREAKDOWN'); ?></caption>
-					<thead>
-						<tr>
-							<th> </th>
-							<th scope="col"><?php echo JText::_('COM_ANSWERS_POINTS'); ?></th>
-							<th scope="col"><?php echo JText::_('COM_ANSWERS_DETAILS'); ?></th>
-						</tr>
-					</thead>
-					<tfoot>
-						<tr>
-							<td colspan="3">
-								* <?php echo JText::_('COM_ANSWERS_ACTIVITY_POINTS_EXPLANATION'); ?> <a href="<?php echo $this->question->config('infolink'); ?>"><?php echo JText::_('COM_ANSWERS_READ_FURTHER_DETAILS'); ?></a>.
-							</td>
-						</tr>
-					</tfoot>
-					<tbody>
-						<tr>
-							<th scope="row"><?php echo JText::_('COM_ANSWERS_ACTIVITY'); ?>*</th>
-							<td><?php echo $this->question->reward('marketvalue'); ?></td>
-							<td> </td>
-						</tr>
-						<tr>
-							<th scope="row"><?php echo JText::_('COM_ANSWERS_BONUS'); ?></th>
-							<td><?php echo $this->question->reward(); ?></td>
-							<td> </td>
-						</tr>
-						<tr>
-							<th scope="row"><?php echo JText::_('COM_ANSWERS_TOTAL_MARKET_VALUE'); ?></th>
-							<td><?php echo $this->question->reward('totalmarketvalue') ?></td>
-							<td><?php echo JText::_('COM_ANSWERS_TOTAL'); ?></td>
-						</tr>
-						<tr>
-							<th scope="row"><?php echo JText::_('COM_ANSWERS_ASKER_WILL_EARN'); ?></th>
-							<td><?php echo $this->question->reward('asker_earnings'); ?></td>
-							<td><?php echo JText::_('COM_ANSWERS_ONE_THIRD_OF_ACTIVITY_POINTS'); ?></td>
-						</tr>
-						<tr>
-							<th scope="row"><?php echo JText::_('COM_ANSWERS_ASKER_WILL_PAY'); ?></th>
-							<td><?php echo $this->question->reward(); ?></td>
-							<td><?php echo JText::_('COM_ANSWERS_REWARD_ASSIGNED_BY_ASKER'); ?></td>
-						</tr>
-						<tr>
-							<th scope="row"><?php echo JText::_('COM_ANSWERS_BEST_ANSWER_MAY_EARN'); ?></th>
-							<td><?php echo $this->question->reward('answer_earnings'); ?></td>
-							<td><?php echo JText::_('COM_ANSWERS_UP_TO_TWO_THIRDS_OF_ACTIVITY_POINTS'); ?></td>
-						</tr>
-					</tbody>
-				</table>
+			<table id="pointbreakdown" summary="<?php echo JText::_('COM_ANSWERS_POINTS'); ?>">
+				<thead>
+					<tr>
+						<th> </th>
+						<th scope="col"><?php echo JText::_('COM_ANSWERS_POINTS'); ?></th>
+						<th scope="col"><?php echo JText::_('COM_ANSWERS_DETAILS'); ?></th>
+					</tr>
+				</thead>
+				<tfoot>
+					<tr>
+						<td colspan="3">
+							* <?php echo JText::_('COM_ANSWERS_ACTIVITY_POINTS_EXPLANATION'); ?> <a href="<?php echo $this->question->config('infolink'); ?>"><?php echo JText::_('COM_ANSWERS_READ_FURTHER_DETAILS'); ?></a>.
+						</td>
+					</tr>
+				</tfoot>
+				<tbody>
+					<tr>
+						<th scope="row"><?php echo JText::_('COM_ANSWERS_ACTIVITY'); ?>*</th>
+						<td><?php echo $this->question->reward('marketvalue'); ?></td>
+						<td> </td>
+					</tr>
+					<tr>
+						<th scope="row"><?php echo JText::_('COM_ANSWERS_BONUS'); ?></th>
+						<td><?php echo $this->question->reward(); ?></td>
+						<td> </td>
+					</tr>
+					<tr>
+						<th scope="row"><?php echo JText::_('COM_ANSWERS_TOTAL_MARKET_VALUE'); ?></th>
+						<td><?php echo $this->question->reward('totalmarketvalue') ?></td>
+						<td><?php echo JText::_('COM_ANSWERS_TOTAL'); ?></td>
+					</tr>
+					<tr>
+						<th scope="row"><?php echo JText::_('COM_ANSWERS_ASKER_WILL_EARN'); ?></th>
+						<td><?php echo $this->question->reward('asker_earnings'); ?></td>
+						<td><?php echo JText::_('COM_ANSWERS_ONE_THIRD_OF_ACTIVITY_POINTS'); ?></td>
+					</tr>
+					<tr>
+						<th scope="row"><?php echo JText::_('COM_ANSWERS_ASKER_WILL_PAY'); ?></th>
+						<td><?php echo $this->question->reward(); ?></td>
+						<td><?php echo JText::_('COM_ANSWERS_REWARD_ASSIGNED_BY_ASKER'); ?></td>
+					</tr>
+					<tr>
+						<th scope="row"><?php echo JText::_('COM_ANSWERS_BEST_ANSWER_MAY_EARN'); ?></th>
+						<td><?php echo $this->question->reward('answer_earnings'); ?></td>
+						<td><?php echo JText::_('COM_ANSWERS_UP_TO_TWO_THIRDS_OF_ACTIVITY_POINTS'); ?></td>
+					</tr>
+				</tbody>
+			</table>
 			</div>
 		</div><!-- / .subject -->
 		<div class="clear"></div>
@@ -319,7 +299,7 @@ if (!$this->question->get('anonymous'))
 		</h3>
 		<div class="aside">
 			<div class="container">
-				<table class="wiki-reference">
+				<table class="wiki-reference" summary="Wiki Syntax Reference">
 					<caption>Wiki Syntax Reference</caption>
 					<tbody>
 						<tr>
@@ -358,7 +338,7 @@ if (!$this->question->get('anonymous'))
 			<?php if (!$this->juser->get('guest')) { ?>
 			<form action="<?php echo JRoute::_('index.php?option=' . $this->option); ?>" method="post" id="commentform">
 				<p class="comment-member-photo">
-					<span class="comment-anchor"><!-- <a name="answerform"></a> --></span>
+					<span class="comment-anchor"><a name="answerform"></a></span>
 					<?php
 						$jxuser = Hubzero_User_Profile::getInstance($this->juser->get('id'));
 						if (!$this->juser->get('guest')) {
@@ -371,19 +351,14 @@ if (!$this->question->get('anonymous'))
 				</p>
 				<fieldset>
 					<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
-					<input type="hidden" name="controller" value="<?php echo $this->controller; ?>" />
 					<input type="hidden" name="task" value="savea" />
-
-					<?php echo JHTML::_('form.token'); ?>
-
-					<input type="hidden" name="response[id]" value="0" />
 					<input type="hidden" name="response[qid]" value="<?php echo $this->question->get('id'); ?>" />
 
 					<label for="responseanswer">
 						<?php echo JText::_('COM_ANSWERS_YOUR_RESPONSE'); ?>:
 						<?php
 						ximport('Hubzero_Wiki_Editor');
-						$editor = Hubzero_Wiki_Editor::getInstance();
+						$editor =& Hubzero_Wiki_Editor::getInstance();
 						echo $editor->display('response[answer]', 'responseanswer', '', 'minimal', '50', '10');
 						?>
 					</label>
@@ -420,9 +395,9 @@ if (!$this->question->get('anonymous'))
 
 	<!-- list of chosen answers -->
 	<?php if ($this->question->chosen('count')) { ?>
-	<div class="below section" id="bestanswer">
+	<div class="below section">
 		<h3>
-			<!-- <a name="bestanswer"></a> -->
+			<a name="bestanswer"></a>
 			<?php echo JText::_('COM_ANSWERS_CHOSEN_ANSWER'); ?>
 		</h3>
 
@@ -455,9 +430,9 @@ if (!$this->question->get('anonymous'))
 <!-- end answer block -->
 
 <!-- start comment block -->
-	<div class="below section" id="answers">
+	<div class="below section">
 		<h3>
-			<!-- <a name="answers"></a> -->
+			<a name="answers"></a>
 			<span class="comment-count"><?php echo $this->question->comments('count'); ?></span> <?php echo JText::_('COM_ANSWERS_RESPONSES'); ?>
 		</h3>
 
@@ -473,7 +448,7 @@ if (!$this->question->get('anonymous'))
 		
 		<?php if ($this->juser->get('username') == $this->question->get('created_by') && $this->question->isOpen()) { ?>
 			<div class="container">
-				<p class="info"><?php echo JText::_('COM_ANSWERS_DO_NOT_FORGET_TO_CLOSE') . ($this->question->config('banking') ? ' ' . JText::_('COM_ANSWERS_DO_NOT_FORGET_TO_CLOSE_POINTS') : ''); ?></p>
+			<p class="info"><?php echo JText::_('COM_ANSWERS_DO_NOT_FORGET_TO_CLOSE'); ?></p>
 			</div><!-- / .container -->
 		<?php } ?>
 		</div><!-- / .aside -->
