@@ -49,26 +49,8 @@ class CoursesControllerForm extends Hubzero_Controller {
 	 */
 	public function execute()
 	{
-		$this->getCourseInfo();
-
-		$section = $this->course->offering()->section()->get('alias');
-		$section = ($section != '__default' && !empty($section)) ? ":{$section}" : '';
-
-		// Get the courses member
-		$this->juser  = JFactory::getUser();
-		$this->member = $this->course->offering()->section()->member($this->juser->get('id'))->get('id');
-		if (!$this->member || !is_numeric($this->member))
-		{
-			$this->member = $this->course->offering()->member($this->juser->get('id'))->get('id');
-			if (!$this->member || !is_numeric($this->member))
-			{
-				JError::raiseError(422, 'No user found');
-				return false;
-			}
-		}
-
-		// Set the base path
-		$this->base = "index.php?option=com_courses&controller=form&gid={$this->course->get('alias')}&offering={$this->course->offering()->get('alias')}{$section}";
+		// Get the user
+		$this->juser = JFactory::getUser();
 
 		parent::execute();
 	}
@@ -80,7 +62,7 @@ class CoursesControllerForm extends Hubzero_Controller {
 	 */
 	public function _buildPathway()
 	{
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 
 		if (count($pathway->getPathWay()) <= 0) 
 		{
@@ -91,16 +73,11 @@ class CoursesControllerForm extends Hubzero_Controller {
 		}
 
 		$pathway->addItem(
-			JText::_(ucfirst($this->course->get('title'))),
-			"index.php?option=com_courses&controller=form&gid={$this->course->get('alias')}"
+			JText::_('Forms'),
+			'index.php?option=' . $this->_option . '&controller=form'
 		);
 
-		$pathway->addItem(
-			JText::_(ucfirst($this->course->offering()->get('title'))),
-			$this->base
-		);
-
-		if ($this->_task != 'index')
+		if($this->_task != 'index')
 		{
 			$pathway->addItem(
 				JText::_(ucfirst($this->_task)),
@@ -125,7 +102,7 @@ class CoursesControllerForm extends Hubzero_Controller {
 		}
 
 		//set title of browser window
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->_title);
 	}
 
@@ -158,7 +135,6 @@ class CoursesControllerForm extends Hubzero_Controller {
 		}
 
 		$this->view->title = $this->_title;
-		$this->view->base  = $this->base;
 
 		// Display
 		$this->view->display();
@@ -280,7 +256,6 @@ class CoursesControllerForm extends Hubzero_Controller {
 		$this->view->pdf   = $this->assertExistentForm();
 		$this->view->dep   = ($dep) ? $dep : new PdfFormDeployment;
 		$this->view->title = $this->view->pdf->getTitle();
-		$this->view->base  = $this->base;
 
 		$this->view->display();
 	}
@@ -318,7 +293,7 @@ class CoursesControllerForm extends Hubzero_Controller {
 			{
 				$tmpl = (JRequest::getWord('tmpl', false)) ? '&tmpl=component' : '';
 				$this->setRedirect(
-					JRoute::_($this->base . '&task=form.showDeployment&id='.$dep->save().'&formId='.$pdf->getId().$tmpl, false),
+					JRoute::_('index.php?option=com_courses&controller=form&task=showDeployment&id='.$dep->save().'&formId='.$pdf->getId().$tmpl, false),
 					JText::_('Deployment successfully created'),
 					'passed'
 				);
@@ -358,7 +333,7 @@ class CoursesControllerForm extends Hubzero_Controller {
 		{
 			$tmpl = (JRequest::getWord('tmpl', false)) ? '&tmpl=component' : '';
 			$this->setRedirect(
-				JRoute::_($this->base . '&task=form.showDeployment&id='.$dep->save($deploymentId).'&formId='.$pdf->getId().$tmpl, false),
+				JRoute::_('index.php?option=com_courses&controller=form&task=showDeployment&id='.$dep->save($deploymentId).'&formId='.$pdf->getId().$tmpl, false),
 				JText::_('Deployment successfully updated'),
 				'passed'
 			);
@@ -395,7 +370,6 @@ class CoursesControllerForm extends Hubzero_Controller {
 		$this->view->pdf   = $this->assertExistentForm();
 		$this->view->title = $this->view->pdf->getTitle();
 		$this->view->dep   = ($dep) ? $dep : PdfFormDeployment::load($id);
-		$this->view->base  = $this->base;
 
 		// Display
 		$this->view->display();
@@ -413,7 +387,10 @@ class CoursesControllerForm extends Hubzero_Controller {
 			JError::raiseError(422);
 		}
 
-		$dep = PdfFormDeployment::fromCrumb($crumb, $this->course->offering()->section()->get('id'));
+		// First, attempt to compute section
+		$section = FormHelper::getSection($crumb);
+
+		$dep = PdfFormDeployment::fromCrumb($crumb, $section);
 		$dbg = JRequest::getVar('dbg', false);
 
 		switch ($dep->getState())
@@ -439,10 +416,9 @@ class CoursesControllerForm extends Hubzero_Controller {
 				$this->_getScripts('assets/js/' . $this->_task);
 
 				$this->view->dep   = $dep;
-				$this->view->resp  = $dep->getRespondent($this->member, $attempt);
+				$this->view->resp  = $dep->getRespondent(NULL, $attempt);
 				$this->view->pdf   = $dep->getForm();
 				$this->view->title = $this->view->pdf->getTitle();
-				$this->view->base  = $this->base;
 				$this->view->dep   = $dep;
 
 				// Display
@@ -457,7 +433,7 @@ class CoursesControllerForm extends Hubzero_Controller {
 					JError::raiseError(403, "You're not allowed this many attempts!");
 				}
 
-				$resp = $dep->getRespondent($this->member, $attempt);
+				$resp = $dep->getRespondent(NULL, $attempt);
 
 				if($resp->getEndTime())
 				{
@@ -473,7 +449,6 @@ class CoursesControllerForm extends Hubzero_Controller {
 					$this->view->incomplete = array();
 					$this->view->pdf        = $dep->getForm();
 					$this->view->title      = $this->view->pdf->getTitle();
-					$this->view->base       = $this->base;
 					$this->view->dep        = $dep;
 					$this->view->resp       = $resp;
 					$this->view->display();
@@ -490,7 +465,6 @@ class CoursesControllerForm extends Hubzero_Controller {
 
 					$this->view->pdf        = $dep->getForm();
 					$this->view->title      = $this->view->pdf->getTitle();
-					$this->view->base       = $this->base;
 					$this->view->dep        = $dep;
 					$this->view->resp       = $resp;
 					$this->view->incomplete = (isset($this->view->incomplete)) ? $this->view->incomplete : array();
@@ -513,13 +487,13 @@ class CoursesControllerForm extends Hubzero_Controller {
 
 		$attempt = JRequest::getInt('attempt', 1);
 
-		PdfFormDeployment::fromCrumb($crumb)->getRespondent($this->member, $attempt)->markStart();
+		PdfFormDeployment::fromCrumb($crumb)->getRespondent(NULL, $attempt)->markStart();
 
 		$tmpl = (JRequest::getWord('tmpl', false)) ? '&tmpl=' . JRequest::getWord('tmpl') : '';
 		$att  = ($attempt > 1) ? '&attempt='.$attempt : '';
 
 		$this->setRedirect(
-			JRoute::_($this->base . '&task=form.complete&crumb=' . $crumb . $att . $tmpl, false)
+			JRoute::_('index.php?option=com_courses&controller=form&task=complete&crumb=' . $_POST['crumb'] . $att . $tmpl, false)
 		);
 		return;
 	}
@@ -539,12 +513,7 @@ class CoursesControllerForm extends Hubzero_Controller {
 
 		$attempt = JRequest::getInt('attempt', 1);
 
-		$resp = PdfFormDeployment::fromCrumb($_POST['crumb'])->getRespondent($this->member, $attempt);
-
-		if (!$resp->getEndTime())
-		{
-			$resp->saveProgress($_POST['question'], $_POST['answer']);
-		}
+		PdfFormDeployment::fromCrumb($_POST['crumb'])->getRespondent(NULL, $attempt)->saveProgress($_POST['question'], $_POST['answer']);
 
 		echo json_encode(array("result"=>"success"));
 		exit();
@@ -567,23 +536,14 @@ class CoursesControllerForm extends Hubzero_Controller {
 
 		$dep = PdfFormDeployment::fromCrumb($crumb);
 
-		// Make sure they're not trying to take the form too many times
-		if($attempt > $dep->getAllowedAttempts())
-		{
-			JError::raiseError(403, "You're not allowed this many attempts!");
-		}
-
 		list($complete, $answers) = $dep->getForm()->getQuestionAnswerMap($_POST);
 
 		if ($complete)
 		{
-			$resp = $dep->getRespondent($this->member, $attempt);
-			if (!$resp->getEndTime())
-			{
-				$resp->saveAnswers($_POST)->markEnd();
-			}
+			$resp = $dep->getRespondent(NULL, $attempt);
+			$resp->saveAnswers($_POST)->markEnd();
 
-			$this->setRedirect(JRoute::_($this->base . '&task=form.complete&crumb='.$crumb.$att, false));
+			$this->setRedirect(JRoute::_('index.php?option=com_courses&controller=form&task=complete&crumb='.$crumb.$att, false));
 			return;
 		}
 		else
@@ -665,30 +625,39 @@ class CoursesControllerForm extends Hubzero_Controller {
 		return $pdf;
 	}
 
-	/**
-	 * Get course info from route
-	 * 
-	 * @return bool
-	 */
-	public function getCourseInfo()
-	{
-		$gid      = JRequest::getVar('gid');
-		$offering = JRequest::getVar('offering');
-		$section  = JRequest::getVar('section');
-
-		$this->course = new CoursesModelCourse($gid);
-		$this->course->offering($offering);
-		$this->course->offering()->section($section);
-	}
-
 	/**
 	 * Check if form is part of a course
 	 * 
 	 * @return bool
 	 */
-	public function authorizeCourse()
-	{
-		return $this->course->access('manage');
+	public function authorizeCourse() {
+		// First, check for a form id
+		if(!$fid = JRequest::getInt('formId', false))
+		{
+			return false;
+		}
+
+		$dbh = JFactory::getDBO();
+
+		$dbh->setQuery(
+			'SELECT ca.course_id
+			FROM `#__courses_assets` AS ca
+			LEFT JOIN `#__courses_forms` AS cf ON cf.asset_id = ca.id
+			WHERE cf.id = ' . $dbh->Quote($fid)
+		);
+
+		if($result = $dbh->loadResult())
+		{
+			// Get course model
+			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'course.php');
+			$course = CoursesModelCourse::getInstance((int) $result);
+
+			return $course->access('manage');
+		}
+		else
+		{
+			return false;
+		}
 	}
 }
 
@@ -701,7 +670,7 @@ class FormHelper {
 	 * 
 	 * @return     string
 	 */
-	public static function timeDiff($secs)
+	public function timeDiff($secs)
 	{
 		$seconds = array(1, 'second');
 		$minutes = array(60 * $seconds[0], 'minute');
@@ -734,12 +703,34 @@ class FormHelper {
 		return join(', ', $rv);
 	}
 
+	/**
+	 * Get section for current student and form
+	 * 
+	 * @return     string
+	 */
+	public function getSection($crumb)
+	{
+		$db = JFactory::getDBO();
+		$query = "SELECT cm.section_id FROM `#__courses_form_deployments` cfd
+					JOIN `#__courses_assets` ca ON cfd.crumb = substring(ca.url, 30)
+					JOIN `#__courses_offering_section_dates` cosd ON ca.id = cosd.scope_id
+					JOIN `#__courses_members` cm ON cosd.section_id = cm.section_id 
+					WHERE cosd.scope = 'asset'
+					AND cm.user_id = " . $db->quote(JFactory::getUser()->get('id')) . "
+					AND cfd.crumb = " . $db->quote($crumb);
+
+		$db->setQuery($query);
+		$result = $db->loadResult();
+
+		return ($result) ? $result : NULL;
+	}
+
 	/**
 	 * Convert integer to ordinal number
 	 * 
 	 * @return     string
 	 */
-	public static function toOrdinal($int)
+	public function toOrdinal($int)
 	{
 		$ends = array('th','st','nd','rd','th','th','th','th','th','th');
 
@@ -754,4 +745,4 @@ class FormHelper {
 
 		return $abbreviation;
 	}
-}
+}
\ No newline at end of file
