@@ -47,19 +47,17 @@ class CoursesControllerMedia extends Hubzero_Controller
 	{
 		// Include need media tracking library
 		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_resources' . DS . 'tables' . DS . 'media.tracking.php');
-		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_resources' . DS . 'tables' . DS . 'media.tracking.detailed.php');
 
 		// Instantiate objects
-		$juser    = JFactory::getUser();
-		$database = JFactory::getDBO();
-		$session  = JFactory::getSession();
+		$juser    =& JFactory::getUser();
+		$database =& JFactory::getDBO();
+		$session  =& JFactory::getSession();
 
 		// Get request vars
 		$time       = JRequest::getVar('time', 0);
 		$duration   = JRequest::getVar('duration', 0);
 		$event      = JRequest::getVar('event', 'update');
 		$resourceid = JRequest::getVar('resourceid', 0);
-		$detailedId = JRequest::getVar('detailedTrackingId', 0);
 		$ipAddress  = $_SERVER['REMOTE_ADDR'];
 
 		// Check for asset id
@@ -70,12 +68,10 @@ class CoursesControllerMedia extends Hubzero_Controller
 		}
 
 		// Instantiate new media tracking object
-		$mediaTracking         = new ResourceMediaTracking($database);
-		$mediaTrackingDetailed = new ResourceMediaTrackingDetailed($database);
+		$mediaTracking = new ResourceMediaTracking($database);
 
 		// Load tracking information for user for this resource
-		$trackingInformation         = $mediaTracking->getTrackingInformationForUserAndResource($juser->get('id'), $resourceid, 'course');
-		$trackingInformationDetailed = $mediaTrackingDetailed->loadByDetailId($detailedId);
+		$trackingInformation = $mediaTracking->getTrackingInformationForUserAndResource($juser->get('id'), $resourceid, 'course');
 
 		// Are we creating a new tracking record
 		if (!is_object($trackingInformation))
@@ -85,12 +81,11 @@ class CoursesControllerMedia extends Hubzero_Controller
 			$trackingInformation->session_id                  = $session->getId();
 			$trackingInformation->ip_address                  = $ipAddress; 
 			$trackingInformation->object_id                   = $resourceid;
-			$trackingInformation->object_type                 = 'resource';
-			$trackingInformation->object_duration             = $duration;
+			$trackingInformation->object_type                 = 'course';
 			$trackingInformation->current_position            = $time;
 			$trackingInformation->farthest_position           = $time;
-			$trackingInformation->current_position_timestamp  = JFactory::getDate()->toSql();
-			$trackingInformation->farthest_position_timestamp = JFactory::getDate()->toSql();
+			$trackingInformation->current_position_timestamp  = date('Y-m-d H:i:s');
+			$trackingInformation->farthest_position_timestamp = date('Y-m-d H:i:s');
 			$trackingInformation->completed                   = 0;
 			$trackingInformation->total_views                 = 1;
 			$trackingInformation->total_viewing_time          = 0;
@@ -109,7 +104,7 @@ class CoursesControllerMedia extends Hubzero_Controller
 
 			// Set the new current position
 			$trackingInformation->current_position           = $time;
-			$trackingInformation->current_position_timestamp = JFactory::getDate()->toSql();
+			$trackingInformation->current_position_timestamp = date('Y-m-d H:i:s');
 
 			// Set the object duration
 			if ($duration > 0)
@@ -121,15 +116,15 @@ class CoursesControllerMedia extends Hubzero_Controller
 			if ($trackingInformation->current_position > $trackingInformation->farthest_position)
 			{
 				$trackingInformation->farthest_position           = $time;
-				$trackingInformation->farthest_position_timestamp = JFactory::getDate()->toSql();
+				$trackingInformation->farthest_position_timestamp = date('Y-m-d H:i:s');
 			}
 
 			// If event type is start, means we need to increment view count
-			if ($event == 'start' || $event == 'replay')
+			if ($event == 'start')
 			{
 				$trackingInformation->total_views++;
 			}
-			
+
 			// If event type is end, we need to increment completed count
 			if ($event == 'ended')
 			{
@@ -137,51 +132,6 @@ class CoursesControllerMedia extends Hubzero_Controller
 			}
 		}
 
-		// Save detailed tracking info
-		$trackingInformationDetailed                              = new stdClass;
-		if ($event == 'start')
-		{
-			$trackingInformationDetailed->user_id                     = $juser->get('id');
-			$trackingInformationDetailed->session_id                  = $session->getId();
-			$trackingInformationDetailed->ip_address                  = $ipAddress; 
-			$trackingInformationDetailed->object_id                   = $resourceid;
-			$trackingInformationDetailed->object_type                 = 'resource';
-			$trackingInformationDetailed->object_duration             = $duration;
-			$trackingInformationDetailed->current_position            = $time;
-			$trackingInformationDetailed->farthest_position           = $time;
-			$trackingInformationDetailed->current_position_timestamp  = JFactory::getDate()->toSql();
-			$trackingInformationDetailed->farthest_position_timestamp = JFactory::getDate()->toSql();
-			$trackingInformationDetailed->completed                   = 0;
-		}
-		else
-		{
-			// Set the new current position
-			$trackingInformationDetailed->current_position           = $time;
-			$trackingInformationDetailed->current_position_timestamp = JFactory::getDate()->toSql();
-
-			// Set the object duration
-			if ($duration > 0)
-			{
-				$trackingInformationDetailed->object_duration = $duration;
-			}
-
-			// Check to see if we need to set a new farthest position
-			if(isset($trackingInformationDetailed->farthest_position) && $trackingInformationDetailed->current_position > $trackingInformationDetailed->farthest_position)
-			{
-				$trackingInformationDetailed->farthest_position           = $time;
-				$trackingInformationDetailed->farthest_position_timestamp = JFactory::getDate()->toSql();
-			}
-
-			// If event type is end, we need to increment completed count
-			if ($event == 'ended')
-			{
-				$trackingInformationDetailed->completed++;
-			}
-		}
-
-		// Save detailed
-		$mediaTrackingDetailed->save($trackingInformationDetailed);
-
 		// Save tracking information
 		if ($mediaTracking->save($trackingInformation))
 		{
@@ -189,7 +139,6 @@ class CoursesControllerMedia extends Hubzero_Controller
 			{
 				$trackingInformation->id = $mediaTracking->id;
 			}
-			$trackingInformation->detailedId = $mediaTrackingDetailed->id;
 			echo json_encode($trackingInformation);
 		}
 	}
@@ -234,7 +183,7 @@ class CoursesControllerMedia extends Hubzero_Controller
 		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path)) 
+			if (!JFolder::create($path, 0777)) 
 			{
 				$this->addComponentMessage(JText::_('UNABLE_TO_CREATE_UPLOAD_PATH'), 'error');
 				$this->mediaTask();
@@ -270,7 +219,7 @@ class CoursesControllerMedia extends Hubzero_Controller
 	private function ajaxuploadTask()
 	{
 		//get config
-		$config = JComponentHelper::getParams('com_media');
+		$config =& JComponentHelper::getParams('com_media');
 
 		// Incoming
 		$listdir = JRequest::getInt('listdir', 0);
@@ -281,11 +230,6 @@ class CoursesControllerMedia extends Hubzero_Controller
 		//max upload size
 		$sizeLimit = $config->get('upload_maxsize');
 
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$sizeLimit = $sizeLimit * 1024 * 1024;
-		}
-
 		//get the file
 		if (isset($_GET['qqfile']))
 		{
