@@ -88,19 +88,12 @@ class CoursesModelCourse extends CoursesModelAbstract
 	private $_manager = NULL;
 
 	/**
-	 * List of managers
+	 * CoursesModelIterator
 	 * 
-	 * @var array
+	 * @var object
 	 */
 	private $_managers = NULL;
 
-	/**
-	 * List of students
-	 * 
-	 * @var array
-	 */
-	private $_students = NULL;
-
 	/**
 	 * CoursesModelOffering
 	 * 
@@ -127,7 +120,7 @@ class CoursesModelCourse extends CoursesModelAbstract
 	 * 
 	 * @var string
 	 */
-	private $_base = NULL;
+	private $_link = NULL;
 
 	/**
 	 * Constructor
@@ -239,8 +232,7 @@ class CoursesModelCourse extends CoursesModelAbstract
 					}
 				}
 			}
-
-			if (is_null($this->_offering))
+			else
 			{
 				// Get current offering
 				$this->_offering = CoursesModelOffering::getInstance($id, $this->get('id'));
@@ -313,7 +305,7 @@ class CoursesModelCourse extends CoursesModelAbstract
 	}
 
 	/**
-	 * Retrieve a specific manager record by user ID
+	 * Check if the current user is enrolled
 	 * 
 	 * @return     boolean
 	 */
@@ -339,10 +331,10 @@ class CoursesModelCourse extends CoursesModelAbstract
 	}
 
 	/**
-	 * Get a list of managers for a course
-	 *   If a manager has multiple entries, it will set
-	 *   the entry int he array with the record that has
-	 *   the highest permission levels
+	 * Get a list of units for an offering
+	 *   Accepts either a numeric array index or a string [id, name]
+	 *   If index, it'll return the entry matching that index in the list
+	 *   If string, it'll return either a list of IDs or names
 	 * 
 	 * @param      array   $filters Filters to build query from
 	 * @param      boolean $clear   Force a new dataset?
@@ -407,48 +399,6 @@ class CoursesModelCourse extends CoursesModelAbstract
 		return $this->_managers;
 	}
 
-	/**
-	 * Get a list of students for a course
-	 * 
-	 * @param      array   $filters Filters to build query from
-	 * @param      boolean $clear   Force a new dataset?
-	 * @return     mixed
-	 */
-	public function students($filters=array(), $clear=false)
-	{
-		if (!isset($filters['course_id']))
-		{
-			$filters['course_id'] = (int) $this->get('id');
-		}
-		$filters['student'] = 1;
-
-		if (isset($filters['count']) && $filters['count'])
-		{
-			$tbl = new CoursesTableMember($this->_db);
-
-			return $tbl->count($filters);
-		}
-
-		if (!isset($this->_students) || !is_array($this->_students) || $clear)
-		{
-			$tbl = new CoursesTableMember($this->_db);
-
-			$results = array();
-
-			if (($data = $tbl->find($filters)))
-			{
-				foreach ($data as $key => $result)
-				{
-					$results[$key] = new CoursesModelStudent($result, $this->get('id'));
-				}
-			}
-
-			$this->_students = $results; //new CoursesModelIterator($results);
-		}
-
-		return $this->_students;
-	}
-
 	/**
 	 * Get a list of instructors for a course
 	 * 
@@ -472,41 +422,12 @@ class CoursesModelCourse extends CoursesModelAbstract
 	{
 		$user_ids = $this->_userIds($data);
 
-		$tbl = new CoursesTableMember($this->_db);
-
-		$filters = array(
-			'course_id' => (int) $this->get('id')
-		);
-
 		foreach ($user_ids as $user_id)
 		{
-			$filters['user_id'] = $user_id;
-
-			if (($data = $tbl->find($filters)))
-			{
-				$this->_managers[$user_id] = new CoursesModelManager(array_shift($data), $this->get('id'));
-
-				if (count($data) > 0)
-				{
-					foreach ($data as $key => $result)
-					{
-						$tbl->delete($result->id);
-						//$data[$key] = new CoursesModelManager($result, $this->get('id'));
-						//$data[$key]->delete();
-					}
-				}
-			}
-
-			if (!isset($this->_managers[$user_id]))
-			{
-				$this->_managers[$user_id] = new CoursesModelManager($user_id, $this->get('id'));
-			}
+			$this->_managers[$user_id] = new CoursesModelManager($user_id, $this->get('id'));
 			$this->_managers[$user_id]->set('user_id', $user_id);
 			$this->_managers[$user_id]->set('course_id', $this->get('id'));
 			$this->_managers[$user_id]->set('role_id', $role_id);
-			$this->_managers[$user_id]->set('section_id', 0);
-			$this->_managers[$user_id]->set('student', 0);
-			$this->_managers[$user_id]->set('offering_id', 0);
 			$this->_managers[$user_id]->store();
 		}
 	}
@@ -728,7 +649,7 @@ class CoursesModelCourse extends CoursesModelAbstract
 		// for every user added to this course
 		JPluginHelper::importPlugin('courses');
 
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 		$dispatcher->trigger('onCourseSave', array($this));
 
 		if ($affected > 0)
@@ -754,10 +675,12 @@ class CoursesModelCourse extends CoursesModelAbstract
 	 */
 	public function delete()
 	{
+		$value = parent::delete();
+
 		JPluginHelper::importPlugin('courses');
 		JDispatcher::getInstance()->trigger('onCourseDelete', array($this));
 
-		return parent::delete();
+		return $value;
 	}
 
 	/**
@@ -874,7 +797,7 @@ class CoursesModelCourse extends CoursesModelAbstract
 		if (!isset($this->_plugins[$event]))
 		{
 			JPluginHelper::importPlugin('courses');
-			$dispatcher = JDispatcher::getInstance();
+			$dispatcher =& JDispatcher::getInstance();
 
 			$this->_plugins[$event] = $dispatcher->trigger($event, array(
 					$this
@@ -893,9 +816,9 @@ class CoursesModelCourse extends CoursesModelAbstract
 	 */
 	public function link($type='')
 	{
-		if (!isset($this->_base))
+		if (!isset($this->_link))
 		{
-			$this->_base  = 'index.php?option=com_courses&gid=' . $this->get('alias');
+			$this->_link  = 'index.php?option=com_courses&gid=' . $this->get('alias');
 		}
 
 		// If it doesn't exist or isn't published
