@@ -42,6 +42,7 @@ require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models'
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'announcement.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'page.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'gradebook.php');
+require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'offeringBadge.php');
 
 require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_courses' . DS . 'tables' . DS . 'role.php');
 
@@ -148,6 +149,13 @@ class CoursesModelOffering extends CoursesModelAbstract
 	 */
 	private $_gradebook = NULL;
 
+	/**
+	 * CoursesModelOfferingBadge
+	 * 
+	 * @var object
+	 */
+	private $_badge = NULL;
+
 	/**
 	 * CoursesModelIterator
 	 * 
@@ -176,13 +184,6 @@ class CoursesModelOffering extends CoursesModelAbstract
 	 */
 	private $_link = NULL;
 
-	/**
-	 * JRegistry
-	 * 
-	 * @var object
-	 */
-	private $_params = NULL;
-
 	/**
 	 * Constructor
 	 * 
@@ -263,31 +264,6 @@ class CoursesModelOffering extends CoursesModelAbstract
 		return $instances[$key];
 	}
 
-	/**
-	 * Get a param value
-	 * 
-	 * @param	   string $key     Property to return
-	 * @param	   mixed  $default Default value to return
-	 * @return     mixed
-	 */
-	public function params($key='', $default=null)
-	{
-		if (!$this->_params)
-		{
-			$paramsClass = 'JParameter';
-			if (version_compare(JVERSION, '1.6', 'ge'))
-			{
-				$paramsClass = 'JRegistry';
-			}
-			$this->_params = new $paramsClass($this->get('params'));
-		}
-		if ($key)
-		{
-			return $this->_params->get((string) $key, $default);
-		}
-		return $this->_params;
-	}
-
 	/**
 	 * Method to get/set the current unit
 	 *
@@ -302,7 +278,7 @@ class CoursesModelOffering extends CoursesModelAbstract
 			$this->_section = null;
 			$this->_link = null; // Clear any potential existing data that may have another (prevous) section's info
 
-			if (isset($this->_sections))
+			if (isset($this->_section))
 			{
 				foreach ($this->sections() as $section)
 				{
@@ -313,8 +289,7 @@ class CoursesModelOffering extends CoursesModelAbstract
 					}
 				}
 			}
-
-			if (!$this->_section)
+			else
 			{
 				$this->_section = CoursesModelSection::getInstance($id, $this->get('id'));
 			}
@@ -337,10 +312,6 @@ class CoursesModelOffering extends CoursesModelAbstract
 		{
 			$filters['offering_id'] = (int) $this->get('id');
 		}
-		if (!isset($filters['available']) && !JFactory::getApplication()->isAdmin())
-		{
-			$filters['available'] = true;
-		}
 
 		if (isset($filters['count']) && $filters['count'])
 		{
@@ -391,8 +362,7 @@ class CoursesModelOffering extends CoursesModelAbstract
 					if ((int) $unit->get('id') == $id || (string) $unit->get('alias') == $id)
 					{
 						$this->_unit = $unit;
-						$units = $this->units();
-						$this->_unit->siblings($units);
+						$this->_unit->siblings($this->units());
 						break;
 					}
 				}
@@ -415,7 +385,7 @@ class CoursesModelOffering extends CoursesModelAbstract
 	 * @param      mixed $idx Index value
 	 * @return     array
 	 */
-	public function units($filters=array(), $clear=false)
+	public function units($filters=array())
 	{
 		if (!isset($filters['offering_id']))
 		{
@@ -433,7 +403,7 @@ class CoursesModelOffering extends CoursesModelAbstract
 			return $tbl->count($filters);
 		}
 
-		if (!($this->_units instanceof CoursesModelIterator) || $clear)
+		if (!isset($this->_units) || !is_a($this->_units, 'CoursesModelIterator'))
 		{
 			$tbl = new CoursesTableUnit($this->_db);
 
@@ -591,20 +561,9 @@ class CoursesModelOffering extends CoursesModelAbstract
 		{
 			$this->_student = null;
 
-			/*if (isset($this->_members) && isset($this->_members[$user_id]))
+			if (isset($this->_members) && isset($this->_members[$user_id]))
 			{
 				$this->_student = $this->_members[$user_id];
-			}*/
-			if (isset($this->_members)) // && isset($this->_members[$user_id]))
-			{
-				foreach ($this->_members as $member)
-				{
-					if ($member->get('user_id') == $user_id && $member->get('section_id') == $this->section()->get('id') && $member->get('student') )
-					{
-						$this->_student = $member;
-						break;
-					}
-				}
 			}
 		}
 
@@ -634,6 +593,21 @@ class CoursesModelOffering extends CoursesModelAbstract
 		return $this->_gradebook; 
 	}
 
+	/**
+	 * Get offering badge
+	 * 
+	 * @return     obj
+	 */
+	public function badge()
+	{
+		if (!isset($this->_badge))
+		{
+			$this->_badge = new CoursesModelOfferingBadge($this->get('badge_id'));
+		}
+
+		return $this->_badge; 
+	}
+
 	/**
 	 * Check if the current user is enrolled
 	 * 
@@ -658,16 +632,9 @@ class CoursesModelOffering extends CoursesModelAbstract
 		{
 			$this->_member = null;
 
-			if (isset($this->_members)) // && isset($this->_members[$user_id]))
+			if (isset($this->_members) && isset($this->_members[$user_id]))
 			{
-				foreach ($this->_members as $member)
-				{
-					if ($member->get('user_id') == $user_id && $member->get('section_id') == $this->section()->get('id'))
-					{
-						$this->_member = $member;
-						break;
-					}
-				}
+				$this->_member = $this->_members[$user_id];
 			}
 		}
 
@@ -741,7 +708,7 @@ class CoursesModelOffering extends CoursesModelAbstract
 				{
 					if (!isset($results[$result->user_id]))
 					{
-						$results[$key] = new $mdl($result);
+						$results[$result->user_id] = new $mdl($result);
 					}
 				}
 			}
@@ -760,7 +727,6 @@ class CoursesModelOffering extends CoursesModelAbstract
 	 */
 	public function membership($user_id=0)
 	{
-		$filters = array();
 		if (!isset($filters['course_id']))
 		{
 			$filters['course_id'] = (int) $this->get('course_id');
@@ -774,8 +740,6 @@ class CoursesModelOffering extends CoursesModelAbstract
 			$user_id = JFactory::getUser()->get('id');
 		}
 		$filters['user_id'] = (int) $user_id;
-		$filters['sort'] = 'offering_id ASC, student';
-		$filters['sort_Dir'] = 'ASC';
 
 		if (isset($filters['count']) && $filters['count'])
 		{
@@ -993,7 +957,7 @@ class CoursesModelOffering extends CoursesModelAbstract
 		if (!isset($this->_plugins) || !is_array($this->_plugins))
 		{
 			JPluginHelper::importPlugin('courses');
-			$dispatcher = JDispatcher::getInstance();
+			$dispatcher =& JDispatcher::getInstance();
 
 			$plugins = $dispatcher->trigger('onCourseAreas', array());
 
@@ -1221,7 +1185,7 @@ class CoursesModelOffering extends CoursesModelAbstract
 	{
 		// Get plugins
 		JPluginHelper::importPlugin('courses');
-		$dispatcher =  JDispatcher::getInstance();
+		$dispatcher = & JDispatcher::getInstance();
 
 		// Trigger the functions that return the areas we'll be using
 		//then add overview to array
@@ -1315,7 +1279,7 @@ class CoursesModelOffering extends CoursesModelAbstract
 	 * Link will vary depending upon action desired, such as edit, delete, etc.
 	 * 
 	 * @param      string $type The type of link to return
-	 * @return     string
+	 * @return     boolean
 	 */
 	public function link($type='')
 	{
@@ -1342,25 +1306,7 @@ class CoursesModelOffering extends CoursesModelAbstract
 			break;
 
 			case 'enroll':
-				JPluginHelper::importPlugin('courses');
-
-				$course = CoursesModelCourse::getInstance($this->get('course_id'));
-
-				$data = JDispatcher::getInstance()->trigger('onCourseEnrollLink', array(
-					$course, $this, $this->section()
-				));
-				if ($data && count($data) > 0)
-				{
-					$link = implode('', $data);
-				}
-				else
-				{
-					$link = $this->_link . '&task=enroll';
-				}
-			break;
-			
-			case 'overview':
-				$link = 'index.php?option=com_courses&gid=' . $this->get('course_alias');
+				$link = $this->_link . '&task=enroll';
 			break;
 
 			case 'permalink':
