@@ -36,7 +36,6 @@ require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models'
 
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'section' . DS . 'code.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'section' . DS . 'date.php');
-require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'section' . DS . 'badge.php');
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'member.php');
 
 /**
@@ -114,13 +113,6 @@ class CoursesModelSection extends CoursesModelAbstract
 	 */
 	private $_date = NULL;
 
-	/**
-	 * CoursesModelSectionBadge
-	 * 
-	 * @var object
-	 */
-	private $_badge = NULL;
-
 	/**
 	 * Constructor
 	 * 
@@ -145,12 +137,6 @@ class CoursesModelSection extends CoursesModelAbstract
 		{
 			$this->_tbl->bind($oid);
 		}
-
-		if (!$this->exists() && $offering_id)
-		{
-			$this->set('id', 0);
-			$this->set('offering_id', $offering_id);
-		}
 	}
 
 	/**
@@ -206,10 +192,10 @@ class CoursesModelSection extends CoursesModelAbstract
 			return false;
 		}
 
-		$now = JFactory::getDate()->toSql();
+		$now = date('Y-m-d H:i:s', time());
 
 		if ($this->get('start_date') 
-		 && $this->get('start_date') != $this->_db->getNullDate() 
+		 && $this->get('start_date') != '0000-00-00 00:00:00' 
 		 && $this->get('start_date') > $now) 
 		{
 			return false;
@@ -230,10 +216,10 @@ class CoursesModelSection extends CoursesModelAbstract
 			return true;
 		}
 
-		$now = JFactory::getDate()->toSql();
+		$now = date('Y-m-d H:i:s', time());
 
 		if ($this->get('end_date') 
-		 && $this->get('end_date') != $this->_db->getNullDate() 
+		 && $this->get('end_date') != '0000-00-00 00:00:00' 
 		 && $this->get('end_date') <= $now) 
 		{
 			return true;
@@ -250,7 +236,7 @@ class CoursesModelSection extends CoursesModelAbstract
 	public function canEnroll()
 	{
 		// If it doesn't exist or isn't published
-		if (!$this->exists() || !$this->isPublished()) 
+		if (!$this->isAvailable()) 
 		{
 			return false;
 		}
@@ -466,23 +452,15 @@ class CoursesModelSection extends CoursesModelAbstract
 		{
 			$role_id = $role->get('id');
 		}
-		if (!$this->get('course_id'))
-		{
-			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'offering.php');
-			$offering = CoursesModelOffering::getInstance($this->get('offering_id'));
-			$this->set('course_id', $offering->get('course_id'));
-		}
 		foreach ($data as $result)
 		{
-			$user_id = (int) $this->_userId($result);
+			$user_id = $this->_userId($result);
 
 			// Create the entry
-			$model = CoursesModelMember::getInstance($user_id, $this->get('course_id'), $this->get('offering_id'), $this->get('id'));
-			$model->set('user_id', $user_id);
-			$model->set('course_id', $this->get('course_id'));
+			$model = new CoursesModelMember($result, null, null, $this->get('id'));
+			$model->set('role_id', $role_id);
 			$model->set('offering_id', $this->get('offering_id'));
 			$model->set('section_id', $this->get('id'));
-			$model->set('role_id', $role_id);
 			if ($role->get('alias') == 'student')
 			{
 				$model->set('student', 1);
@@ -513,22 +491,11 @@ class CoursesModelSection extends CoursesModelAbstract
 		{
 			$data = array($data);
 		}
-		if (!$this->get('course_id'))
-		{
-			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'offering.php');
-			$offering = CoursesModelOffering::getInstance($this->get('offering_id'));
-			$this->set('course_id', $offering->get('course_id'));
-		}
 		foreach ($data as $result)
 		{
 			$user_id = $this->_userId($result);
 
-			$model = CoursesModelMember::getInstance($user_id, $this->get('course_id'), $this->get('offering_id'), $this->get('id'));
-			if (!$model->exists())
-			{
-				$this->setError(JText::sprintf('Entry for user #%s, course #%s, offering #%s, section #%s not found.', $user_id, $this->get('course_id'), $this->get('offering_id'), $this->get('id')));
-				continue;
-			}
+			$model = CoursesModelMember::getInstance($user_id, $this->get('id'));
 			if (!$model->delete())
 			{
 				$this->setError($model->getError());
@@ -579,7 +546,7 @@ class CoursesModelSection extends CoursesModelAbstract
 
 		JPluginHelper::importPlugin('courses');
 
-		//$dispatcher = JDispatcher::getInstance();
+		//$dispatcher =& JDispatcher::getInstance();
 		JDispatcher::getInstance()->trigger('onAfterSaveSection', array($this, $isNew));
 
 		if ($isNew)
@@ -731,19 +698,5 @@ class CoursesModelSection extends CoursesModelAbstract
 		}
 		return $codes;
 	}
+}
 
-	/**
-	 * Get section badge
-	 *
-	 * @return     obj
-	*/
-	public function badge()
-	{
-		if (!isset($this->_badge))
-		{
-			$this->_badge = CoursesModelSectionBadge::loadBySectionId($this->get('id'));
-		}
-
-		return $this->_badge; 
-	}
-}
\ No newline at end of file
