@@ -31,15 +31,6 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-$dateFormat = '%b %d, %Y';
-$tz = null;
-
-if (version_compare(JVERSION, '1.6', 'ge'))
-{
-	$dateFormat = 'M d, Y';
-	$tz = false;
-}
-
 if (!defined('n')) {
 
 /**
@@ -79,7 +70,7 @@ class ProjectsHtml
 	 * @param      string $format
 	 * @return     string
 	 */
-	public static function valformat($value, $format) 
+	public function valformat($value, $format) 
 	{
 		if ($format == 1) 
 		{
@@ -133,34 +124,33 @@ class ProjectsHtml
 	 * @param      boolean 	$full	Return detailed date/time?
 	 * @return     string
 	 */
-	public static function formatTime($time, $full = false, $utc = false) 
+	public function formatTime($time, $full = false) 
 	{
 		$parsed 	= date_parse($time);
 		$timestamp	= strtotime($time);
 
-		$now 		= $utc ? JFactory::getDate()->toSql() : date('c');
+		$now = date( 'Y-m-d H:i:s' );
 		$current  	= date_parse($now);
 		
 		if ($full)
 		{
-		//	return $utc ? JFactory::getDate($timestamp)->format('g:i A M j, Y') : date('Y-m-d H:i:s', $timestamp) ;
-			return JHTML::_('date', $timestamp, 'M d, Y H:i:s', false);
+			return date('g:i A M j, Y', $timestamp);
 		}
 		
 		if ($current['year'] == $parsed['year'])
 		{
 			if ($current['month'] == $parsed['month'] && $current['day'] == $parsed['day'])
 			{
-				return JHTML::_('date', $timestamp, 'g:i A', false);
+				return date('g:i A', $timestamp);
 			}
 			else
 			{
-				return JHTML::_('date', $timestamp, 'M j', false);
+				return date('M j', $timestamp);
 			}
 		}
 		else
 		{
-			return JHTML::_('date', $timestamp, 'M j, Y', false);
+			return date('M j, Y', $timestamp);
 		}
 	}
 	
@@ -170,25 +160,29 @@ class ProjectsHtml
 	 * @param      string $timestamp
 	 * @return     string
 	 */
-	public static function timeAgo($timestamp, $utc = true) 
+	public function timeAgo($timestamp) 
 	{
 		$timestamp = Hubzero_View_Helper_Html::mkt($timestamp);
+		$text = Hubzero_View_Helper_Html::timeAgoo($timestamp);
 		
-		// Get current time
-		$current_time = $utc ? strtotime(JFactory::getDate()) : strtotime(date('c'));
-		
-		$text = ProjectsHtml::timeDifference($current_time - $timestamp);
+		$parts = explode(' ',$text);
+
+		$text  = $parts[0].' '.$parts[1];
+		if ($text == '0 seconds' || $parts[0] < 0) 
+		{
+			$text = JText::_('COM_PROJECTS_JUST_A_MOMENT');
+		}
 
 		return $text;
 	}
 	
 	/**
-	 * Get time difference
+	 * TGet time difference
 	 * 
 	 * @param      string $difference
 	 * @return     string
 	 */
-	public static function timeDifference ($difference)
+	public function timeDifference ($difference)
 	{
 		// Set the periods of time
 		$periods = array('second', 'minute', 'hour', 'day', 'week', 'month', 'year', 'decade');
@@ -236,10 +230,10 @@ class ProjectsHtml
 	 * @param      string $timestamp
 	 * @return     string
 	 */
-	public static function timeFromNow ($timestamp)
+	public function timeFromNow ($timestamp)
 	{
-		// Get current UTC time
-		$current_time = strtotime(JFactory::getDate());
+		// Store the current time
+		$current_time = time();
 
 		// Determine the difference, between the time now and the timestamp
 		$difference =  strtotime($timestamp) - $current_time;
@@ -260,7 +254,7 @@ class ProjectsHtml
 	 * @param      string $prefix
 	 * @return     string
 	 */
-	public static function getFileAttribs( $path = '', $base_path = '', $get = '', $prefix = JPATH_ROOT )
+	public function getFileAttribs( $path = '', $base_path = '', $get = '', $prefix = JPATH_ROOT )
 	{
 		if (!$path) 
 		{
@@ -316,7 +310,7 @@ class ProjectsHtml
 	 * @param      string $directory
 	 * @return     string
 	 */
-	public static function getDirSize ($directory = '') 
+	public function getDirSize ($directory = '') 
 	{
 		if(!$directory) 
 		{
@@ -359,7 +353,7 @@ class ProjectsHtml
 	 * @param      int $round
 	 * @return     string
 	 */
-	public static function formatSize($file_size, $round = 0) 
+	public function formatSize($file_size, $round = 0) 
 	{
 		if ($file_size >= 1073741824) 
 	//	if ($file_size >= 107374182) 
@@ -391,7 +385,7 @@ class ProjectsHtml
 	 * @param      string $round
 	 * @return     string
 	 */
-	public static function convertSize($file_size, $from = 'b', $to = 'GB', $round = 0) 
+	public function convertSize($file_size, $from = 'b', $to = 'GB', $round = 0) 
 	{
 		$file_size = str_replace(' ', '', $file_size);
 
@@ -410,7 +404,7 @@ class ProjectsHtml
 				$file_size = round(($file_size / 1024 * 100) / 100, $round);
 			} 
 		}
-		elseif ($from == 'GB') 
+		else if($from == 'GB') 
 		{
 			if ($to == 'b') 
 			{
@@ -437,7 +431,7 @@ class ProjectsHtml
 	 * @param      string $icon
 	 * @return     string
 	 */
-	public static function getGoogleIcon ($mimeType, $include_dir = 1, $icon = '') 
+	public function getGoogleIcon ($mimeType, $include_dir = 1, $icon = '') 
 	{
 		switch (strtolower($mimeType)) 
 		{
@@ -478,45 +472,6 @@ class ProjectsHtml
 		
 	}
 	
-	/**
-	 * Fix up some mimetypes
-	 * 
-	 * @param      string $file
-	 * @param      string $mimeType
-	 * @return     string
-	 */
-	public static function fixUpMimeType ($file = NULL, $mimeType = NULL) 
-	{
-		if ($file)
-		{
-			// Get file extention
-			$parts = explode('.', $file);
-			$ext   = count($parts) > 1 ? array_pop($parts) : '';
-			$ext   = strtolower($ext);
-			
-			switch (strtolower($ext)) 
-			{
-				case 'key':
-					$mimeType = 'application/x-iwork-keynote-sffkey';
-					break;
-					
-				case 'ods':
-					$mimeType = 'application/vnd.oasis.opendocument.spreadsheet';
-					break;
-					
-				case 'wmf':
-					$mimeType = 'application/x-msmetafile';
-					break;
-					
-				case 'tex':
-					$mimeType = 'application/x-tex';
-					break;
-			}
-		}
-				
-		return $mimeType;
-	}
-	
 	/**
 	 * Get file icon image
 	 * 
@@ -525,7 +480,7 @@ class ProjectsHtml
 	 * @param      string $icon
 	 * @return     string
 	 */
-	public static function getFileIcon ($ext, $include_dir = 1, $icon = '') 
+	public function getFileIcon ($ext, $include_dir = 1, $icon = '') 
 	{
 		switch (strtolower($ext)) 
 		{
@@ -646,7 +601,7 @@ class ProjectsHtml
 	 * @param      object $view
 	 * @return     string HTML
 	 */
-	public static function embedProjectImage( $view )
+	public function embedProjectImage( $view )
 	{ 
 		$path = DS . trim($view->config->get('imagepath', '/site/projects'), DS) . DS . $view->project->alias . DS . 'images';
 		$image  = $view->project->picture 
@@ -670,7 +625,7 @@ class ProjectsHtml
 	 * @param      object $view
 	 * @return     string HTML
 	 */
-	public static function writeMemberOptions ( $view ) 
+	public function writeMemberOptions ( $view ) 
 	{ 
 		$dateFormat = '%b %d, %Y';
 		$tz = null;
@@ -744,10 +699,11 @@ class ProjectsHtml
 	 * @param      boolean $show_pic
 	 * @return     string HTML
 	 */
-	public static function writeProjectHeader ($view, $back = 0, $underline = 0, $show_privacy = 0, $show_pic = 1) 
+	public function writeProjectHeader ($view, $back = 0, $underline = 0, $show_privacy = 0, $show_pic = 1) 
 	{
 		// Use alias or id in urls?
-		$goto  = 'alias=' . $view->project->alias;
+		$use_alias = $view->config->get('use_alias', 0);
+		$goto  = $use_alias ? 'alias='.$view->project->alias : 'id='.$view->project->id;
 		$privacy_txt = $view->project->private ? JText::_('COM_PROJECTS_PRIVATE') : JText::_('COM_PROJECTS_PUBLIC');
 		
 		if($view->project->private) 
@@ -813,15 +769,10 @@ class ProjectsHtml
 	 * @param      array $config
 	 * @return     string HTML
 	 */
-	public static function getThumbSrc( $id, $alias, $picname = '', $config )
+	public function getThumbSrc( $id, $alias, $picname = '', $config )
 	{		
 		$src  = '';
 		$path = DS . trim($config->get('imagepath', '/site/projects'), DS) . DS . $alias . DS . 'images';
-		
-		if (file_exists( JPATH_ROOT . $path . DS . 'thumb.png' ))
-		{
-			return $path . DS . 'thumb.png';
-		}
 	
 		if ($picname) 
 		{
@@ -841,48 +792,13 @@ class ProjectsHtml
 	// Misc
 	//----------------------------------------------------------
 	
-	/**
-	 * Tool development header
-	 * 
-	 * @return     string HTML
-	 */
-	public static function toolDevHeader( $option, $config, $project, $tool, $active, $bcrumb = '')
-	{
-		// tool-only tab menu 
-		$view = new Hubzero_Plugin_View(
-			array(
-				'folder'=>'projects',
-				'element'=>'tools',
-				'name'=>'view'
-			)
-		);
-
-		// Load plugin parameters
-		$tool_plugin 	= JPluginHelper::getPlugin( 'projects', 'tools' );
-		$view->plgparams = new JParameter($tool_plugin->params);
-
-		$view->route 	= 'index.php?option=' . $option . a . 'alias=' . $project->alias . a . 'active=tools';
-		$view->url 		= JRoute::_('index.php?option=' . $option . a . 'alias=' . $project->alias . a . 'active=tools');
-		$view->tool 	= $tool;
-		$view->active 	= $active;
-		$view->title 	= 'Tools';
-
-		// Get path for tool thumb image
-		$p_path 			= ProjectsHelper::getProjectPath($project->alias, $config->get('imagepath'), 1, 'images');			
-		$imagePath 			= $p_path . DS . 'tools';
-		$view->projectPath 	= $imagePath;
-		$view->path_bc 		= $bcrumb;
-		$view->ih 			= new ProjectsImgHandler();				
-		return $view->loadTemplate();
-	}
-	
 	/**
 	 * Show 'no preview' message
 	 * 
 	 * @param      string $msg
 	 * @return     string HTML
 	 */
-	public static function showNoPreviewMessage( $msg = '' ) 
+	public function showNoPreviewMessage( $msg = '' ) 
 	{
 		$msg = $msg ? $msg : JText::_('PLG_PROJECTS_PUBLICATIONS_PUB_PREVIEW_NO_CONTENT');
 		return '<p class="pale">'.$msg.'</p>';
@@ -898,7 +814,7 @@ class ProjectsHtml
 	 * @param      boolean $useletters
 	 * @return     string HTML
 	 */	
-	public static function generateCode( $minlength = 10, $maxlength = 10, $usespecial = 0, $usenumbers = 0, $useletters = 1, $mixedcaps = false )
+	public function generateCode( $minlength = 10, $maxlength = 10, $usespecial = 0, $usenumbers = 0, $useletters = 1, $mixedcaps = false )
 	{	
 		$key = '';
 		$charset = '';
@@ -918,7 +834,7 @@ class ProjectsHtml
 	 * @param      string $in
 	 * @return     string
 	 */		
-	public static function cleanText ($in = '') 
+	public function cleanText ($in = '') 
 	{	
 		$in = stripslashes($in);
 		$in = str_replace('&quote;','&quot;',$in);
@@ -938,7 +854,7 @@ class ProjectsHtml
 	 * @param      string $rel
 	 * @return     string HTML
 	 */		
-	public static function replaceUrls($string, $rel = 'nofollow') 
+	public function replaceUrls($string, $rel = 'nofollow') 
 	{
 	    $host = "([a-z\d][-a-z\d]*[a-z\d]\.)+[a-z][-a-z\d]*[a-z]";
 	    $port = "(:\d{1,})?";
@@ -954,7 +870,7 @@ class ProjectsHtml
 	 * @param      string $haystack
 	 * @return     boolean
 	 */	
-	public static function myArraySearch( $needle, $haystack ) 
+	public function myArraySearch( $needle, $haystack ) 
 	{
 	    if (empty($needle) || empty($haystack)) 
 		{
@@ -988,7 +904,7 @@ class ProjectsHtml
 	 * 
 	 * @return     string
 	 */
-	public static function getAppendedNumber ( $path = null )
+	public function getAppendedNumber ( $path = null )
 	{
 		$append = '';
 		
@@ -1024,7 +940,7 @@ class ProjectsHtml
 	 * @param      string $delim
 	 * @return     string
 	 */
-	public static function cleanFileNum ( $path = null, $end = '', $delim = '-' )
+	public function cleanFileNum ( $path = null, $end = '', $delim = '-' )
 	{
 		$newpath = $path;
 		
@@ -1068,14 +984,13 @@ class ProjectsHtml
 	 * @param      string $ext
 	 * @return     string
 	 */
-	public static function fixFileName ( $path = null, $append = '', $ext = '' )
+	public function fixFileName ( $path = null, $append = '', $ext = '' )
 	{
 		if (!$path) 
 		{
-			// $this->setError( JText::_('No path set.') );
+			$this->setError( JText::_('No path set.') );
 			return false;
 		}
-
 		if (!$append) 
 		{
 			return $path;
@@ -1116,7 +1031,7 @@ class ProjectsHtml
 	 * @param      string  $file      String to shorten
 	 * @return     string 
 	 */
-	public static function takeOutExt($file = '')
+	public function takeOutExt($file = '')
 	{
 		// Take out extention
 		if ($file)
@@ -1166,7 +1081,7 @@ class ProjectsHtml
 	 * @param      int $chars
 	 * @return     string
 	 */	
-	public static function shortenName( $name, $chars = 12 ) 
+	public function shortenName( $name, $chars = 12 ) 
 	{
 		$name = trim($name);
 
@@ -1196,7 +1111,7 @@ class ProjectsHtml
 	 * @param      int $chars
 	 * @return     string
 	 */	
-	public static function shortenUrl( $name, $chars = 40 ) 
+	public function shortenUrl( $name, $chars = 40 ) 
 	{
 		$name = trim($name);
 
@@ -1216,7 +1131,7 @@ class ProjectsHtml
 	 * @param      int $chars
 	 * @return     string
 	 */
-	public static function shortenFileName( $name, $chars = 30 ) 
+	public function shortenFileName( $name, $chars = 30 ) 
 	{
 		$name = trim($name);
 		$original = $name;
@@ -1249,7 +1164,7 @@ class ProjectsHtml
 	 * @param      string $reviewer
 	 * @return     string
 	 */
-	public static function getAdminNotes($notes = '', $reviewer = '')
+	public function getAdminNotes($notes = '', $reviewer = '')
 	{
 		preg_match_all("#<nb:".$reviewer.">(.*?)</nb:".$reviewer.">#s", $notes, $matches);
 		$ntext = '';
@@ -1276,7 +1191,7 @@ class ProjectsHtml
 	 * @param      string $reviewer
 	 * @return     string
 	 */
-	public static function getAdminNoteCount($notes = '', $reviewer = '')
+	public function getAdminNoteCount($notes = '', $reviewer = '')
 	{
 
 		preg_match_all("#<nb:".$reviewer.">(.*?)</nb:".$reviewer.">#s", $notes, $matches);
@@ -1299,7 +1214,7 @@ class ProjectsHtml
 	 * @param      int $shorten
 	 * @return     string
 	 */
-	public static function parseAdminNote($note = '', $reviewer = '', $showmeta = 1, $shorten = 0)
+	public function parseAdminNote($note = '', $reviewer = '', $showmeta = 1, $shorten = 0)
 	{
 		$note = str_replace('<nb:'.$reviewer.'>','', $note);
 		$note = str_replace('</nb:'.$reviewer.'>','', $note);
@@ -1334,7 +1249,7 @@ class ProjectsHtml
 	 * @param      string $reviewer
 	 * @return     string
 	 */
-	public static function getLastAdminNote($notes = '', $reviewer = '')
+	public function getLastAdminNote($notes = '', $reviewer = '')
 	{
 		$match = '';
 		preg_match_all("#<nb:".$reviewer.">(.*?)</nb:".$reviewer.">#s", $notes, $matches);
@@ -1364,7 +1279,7 @@ class ProjectsHtml
 	 * @param      array $from
 	 * @return     void
 	 */	
-	public static function email($email, $subject, $message, $from) 
+	public function email($email, $subject, $message, $from) 
 	{
 		if ($from) 
 		{
