@@ -48,7 +48,7 @@ class RegisterController extends Hubzero_Controller
 		$app = JFactory::getApplication();
 		$this->jconfig = JFactory::getConfig();
 
-		$juri = JURI::getInstance();
+		$juri =& JURI::getInstance();
 		$this->baseURL = rtrim($juri->base(), DS);
 
 		// Make sure we're using a secure connection
@@ -102,8 +102,8 @@ class RegisterController extends Hubzero_Controller
 			return JError::raiseError(500, JText::_('COM_REGISTER_ERROR_GUEST_SESSION_EDITING'));
 		}
 
-		$xprofile = Hubzero_Factory::getProfile();
-		$jsession = JFactory::getSession();
+		$xprofile =& Hubzero_Factory::getProfile();
+		$jsession =& JFactory::getSession();
 
 		// Get the return URL
 		$return = base64_decode(JRequest::getVar('return', '',  'method', 'base64'));
@@ -168,7 +168,7 @@ class RegisterController extends Hubzero_Controller
 
 		$target_xprofile->loadRegistration($xregistration);
 		
-		$params = JComponentHelper::getParams('com_members');
+		$params =& JComponentHelper::getParams('com_members');
 		
 		$hubHomeDir = rtrim($params->get('homedir'),'/');
 		
@@ -199,7 +199,7 @@ class RegisterController extends Hubzero_Controller
 
 		if ($target_xprofile->get('registerDate') == '') 
 		{
-			$target_xprofile->set('registerDate', JFactory::getDate()->toSql());
+			$target_xprofile->set('registerDate', date('Y-m-d H:i:s'));
 		}
 
 		if ($xregistration->get('email') != $target_xprofile->get('email')) 
@@ -381,19 +381,19 @@ class RegisterController extends Hubzero_Controller
 			return $this->_show_registration_form($xregistration, 'proxycreate');
 		}
 
-		$xprofile = Hubzero_Factory::getProfile();
+		$xprofile =& Hubzero_Factory::getProfile();
 
 		// Get some settings
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 		$this->jconfig = $jconfig;
-		$params = JComponentHelper::getParams('com_members');
+		$params =& JComponentHelper::getParams('com_members');
 		$hubHomeDir = rtrim($params->get('homedir'),'/');
 		
 		jimport('joomla.application.component.helper');
-		$config   = JComponentHelper::getParams('com_users');
+		$config   =& JComponentHelper::getParams('com_users');
 		$usertype = $config->get('new_usertype', 'Registered');
 
-		$acl = JFactory::getACL();
+		$acl =& JFactory::getACL();
 
 		// Create a new Joomla user
 		$target_juser = new JUser();
@@ -402,26 +402,8 @@ class RegisterController extends Hubzero_Controller
 		$target_juser->set('username', $xregistration->get('login'));
 		$target_juser->set('password_clear','');
 		$target_juser->set('email', $xregistration->get('email'));
-
-		if (version_compare(JVERSION, '1.6', 'lt'))
-		{
-			$target_juser->set('gid', $acl->get_group_id('', $usertype));
-			$target_juser->set('usertype', $usertype);
-		}
-		else
-		{
-			// There's got to be a better way to do this!
-			$db = JFactory::getDbo();
-			$query = $db->getQuery(true)
-				->select('id')
-				->from('#__usergroups')
-				->where('title = ' . $db->quote(trim($usertype)));
-			$db->setQuery($query);
-			$result = $db->loadResult();
-
-			$target_juser->set('groups', array($result));
-		}
-
+		$target_juser->set('gid', $acl->get_group_id('', $usertype));
+		$target_juser->set('usertype', $usertype);
 		$target_juser->save();
 
 		// Attempt to retrieve the new user
@@ -442,7 +424,7 @@ class RegisterController extends Hubzero_Controller
 				$target_xprofile->set('regHost', JRequest::getVar('REMOTE_HOST','','server'));
 			}
 
-			$target_xprofile->set('registerDate', JFactory::getDate()->toSql());
+			$target_xprofile->set('registerDate', date('Y-m-d H:i:s'));
 			$target_xprofile->set('proxyUidNumber', $this->juser->get('id'));
 			$target_xprofile->set('proxyPassword', $xregistration->get('password'));
 
@@ -453,8 +435,6 @@ class RegisterController extends Hubzero_Controller
 		if ($result) 
 		{
 			$result = Hubzero_User_Password::changePassword($target_xprofile->get('username'), $xregistration->get('password'));
-			// Now expire the password
-			Hubzero_User_Password::expirePassword($target_xprofile->get('username'));
 		}
 		
 		// Did we successully create/update an account?
@@ -526,8 +506,8 @@ class RegisterController extends Hubzero_Controller
 		// Instantiate a new registration object
 		$xregistration = new Hubzero_Registration();
 
-		$xprofile    = Hubzero_Factory::getProfile();
-		$jsession = JFactory::getSession();
+		$xprofile    =& Hubzero_Factory::getProfile();
+		$jsession =& JFactory::getSession();
 
 		$hzal = Hubzero_Auth_Link::find_by_id($this->juser->get('auth_link_id'));
 
@@ -580,7 +560,7 @@ class RegisterController extends Hubzero_Controller
 
 		if (!$force && $check && JRequest::getMethod() == 'POST') 
 		{
-			$params = JComponentHelper::getParams('com_members');
+			$params =& JComponentHelper::getParams('com_members');
 			$hubHomeDir = rtrim($params->get('homedir'),'/');
 
 			$updateEmail     = false;
@@ -610,7 +590,7 @@ class RegisterController extends Hubzero_Controller
 
 			if ($xprofile->get('registerDate') == '') 
 			{
-				$xprofile->set('registerDate', JFactory::getDate()->toSql());
+				$xprofile->set('registerDate', date('Y-m-d H:i:s'));
 			}
 
 			if ($xregistration->get('email') != $xprofile->get('email')) 
@@ -655,7 +635,7 @@ class RegisterController extends Hubzero_Controller
 				$jsession->set('user', $sjuser);
 
 				// Get the session object
-				$table =  JTable::getInstance('session');
+				$table = & JTable::getInstance('session');
 				$table->load($jsession->getId());
 				$table->username = $xprofile->get('username');
 				$table->update();
@@ -746,6 +726,8 @@ class RegisterController extends Hubzero_Controller
 	{
 		ximport('Hubzero_Auth_Link');
 
+		global $mainframe;
+
 		// Add the CSS to the template
 		$this->_getStyles();
 
@@ -760,18 +742,11 @@ class RegisterController extends Hubzero_Controller
 
 		if (!$this->juser->get('guest') && !$this->juser->get('tmp_user')) 
 		{
-			$app = JFactory::getApplication();
+			$app =& JFactory::getApplication();
 			$app->redirect("/members/myaccount", JText::_('COM_REGISTER_ERROR_NONGUEST_SESSION_CREATION'), "warning");
 			return;
 		}
 
-		$usersConfig =  JComponentHelper::getParams('com_users');
-		if ($usersConfig->get('allowUserRegistration') == '0') 
-		{
-			JError::raiseError(404, JText::_('JGLOBAL_RESOURCE_NOT_FOUND'));
-			return;
-		}
-
 		if ($this->juser->get('auth_link_id')) 
 		{
 			$hzal = Hubzero_Auth_Link::find_by_id($this->juser->get('auth_link_id'));
@@ -797,12 +772,13 @@ class RegisterController extends Hubzero_Controller
 			{
 				// Get required system objects
 				$user 		= clone(JFactory::getUser());
-				$pathway 	= JFactory::getApplication()->getPathway();
-				$config		= JFactory::getConfig();
-				$authorize	= JFactory::getACL();
-				$document   = JFactory::getDocument();
+				$pathway 	=& $mainframe->getPathway();
+				$config		=& JFactory::getConfig();
+				$authorize	=& JFactory::getACL();
+				$document   =& JFactory::getDocument();
 
 				// If user registration is not allowed, show 403 not authorized.
+				$usersConfig = &JComponentHelper::getParams('com_users');
 				if ($usersConfig->get('allowUserRegistration') == '0') 
 				{
 					JError::raiseError(403, JText::_('Access Forbidden'));
@@ -813,13 +789,7 @@ class RegisterController extends Hubzero_Controller
 				$newUsertype = $usersConfig->get('new_usertype');
 				if (!$newUsertype) 
 				{
-					$db = JFactory::getDbo();
-					$query = $db->getQuery(true)
-						->select('id')
-						->from('#__usergroups')
-						->where('title = "Registered"');
-					$db->setQuery($query);
-					$newUsertype = $db->loadResult();
+					$newUsertype = 'Registered';
 				}
 
 				$user->set('username', $xregistration->get('login'));
@@ -834,17 +804,10 @@ class RegisterController extends Hubzero_Controller
 
 				// Set some initial user values
 				$user->set('id', 0);
-				if (version_compare(JVERSION, '1.6', 'lt'))
-				{
-					$user->set('usertype', $newUsertype);
-					$user->set('gid', $authorize->get_group_id('', $newUsertype, 'ARO'));
-				}
-				else
-				{
-					$user->set('groups', array($newUsertype));
-				}
+				$user->set('usertype', $newUsertype);
+				$user->set('gid', $authorize->get_group_id('', $newUsertype, 'ARO'));
 
-				$date = JFactory::getDate();
+				$date =& JFactory::getDate();
 				$user->set('registerDate', $date->toMySQL());
 
 				/*
@@ -878,7 +841,7 @@ class RegisterController extends Hubzero_Controller
 					*/
 
 					// Get some settings
-					$params = JComponentHelper::getParams('com_members');
+					$params =& JComponentHelper::getParams('com_members');
 					$hubHomeDir = rtrim($params->get('homedir'), '/');
 					
 					// Attempt to get the new user
@@ -1084,7 +1047,7 @@ class RegisterController extends Hubzero_Controller
 			default:       $index = 0; break;
 		}
 
-		$hconfig = JComponentHelper::getParams('com_register');
+		$hconfig =& JComponentHelper::getParams('com_register');
 
 		$default = str_pad($default, 4, '-');
 		$configured = $hconfig->get($name);
@@ -1343,7 +1306,7 @@ class RegisterController extends Hubzero_Controller
 			return;
 		}
 
-		$xprofile = Hubzero_Factory::getProfile();
+		$xprofile =& Hubzero_Factory::getProfile();
 		$login = $xprofile->get('username');
 		$email = $xprofile->get('email');
 		$email_confirmed = $xprofile->get('emailConfirmed');
@@ -1431,7 +1394,7 @@ class RegisterController extends Hubzero_Controller
 			return;
 		}
 
-		$xprofile = Hubzero_Factory::getProfile();
+		$xprofile =& Hubzero_Factory::getProfile();
 		$login = $xprofile->get('username');
 		$email = $xprofile->get('email');
 		$email_confirmed = $xprofile->get('emailConfirmed');
@@ -1471,15 +1434,15 @@ class RegisterController extends Hubzero_Controller
 				else 
 				{
 					// New email submitted - attempt to save it
-					$xprofile = Hubzero_User_Profile::getInstance($login);
+					$xprofile =& Hubzero_User_Profile::getInstance($login);
 					if ($xprofile) 
 					{
-						$dtmodify = JFactory::getDate()->toSql();
+						$dtmodify = date("Y-m-d H:i:s");
 						$xprofile->set('email',$pemail);
 						$xprofile->set('modifiedDate',$dtmodify);
 						if ($xprofile->update()) 
 						{
-							$juser = JUser::getInstance($login);
+							$juser =& JUser::getInstance($login);
 							$juser->set('email', $pemail);
 							$juser->save();
 						} 
@@ -1581,76 +1544,57 @@ class RegisterController extends Hubzero_Controller
 			return;
 		}
 
-		$xprofile = Hubzero_Factory::getProfile();
+		$xprofile =& Hubzero_Factory::getProfile();
 
 		$email_confirmed = $xprofile->get('emailConfirmed');
 
 		if (($email_confirmed == 1) || ($email_confirmed == 3)) 
 		{
-			// The current user is confirmed - check to see if the incoming code is valid at all
-			if (Hubzero_Registration_Helper::isActiveCode($code))
-			{
-				$this->setError('login mismatch');
-
-				// Build logout/login/confirm redirect flow
-				$login_return  = base64_encode(JRoute::_('index.php?option=' . $this->option . '&task=' . $this->_task . '&confirm=' . $code));
-				$logout_return = base64_encode(JRoute::_('index.php?option=com_login&return=' . $login_return));
-
-				$redirect = JRoute::_('index.php?option=com_logout&return=' . $logout_return);
-			}
+			// All is well
 		} 
 		elseif ($email_confirmed < 0 && $email_confirmed == -$code) 
 		{
-			//var to hold return path
-			$return = '';
-			
-			// get com_register return path
-			$hconfig =  JComponentHelper::getParams('com_register');
-			$cReturn = $hconfig->get('ConfirmationReturn');
-			if ($cReturn) 
-			{
-				$return = $cReturn;
-			}
-			
-			//load user profile
 			ximport('Hubzero_User_Profile');
 			$profile = new Hubzero_User_Profile();
 			$profile->load($xprofile->get('username'));
-			
-			//check to see if we have a return param
-			$pReturn = base64_decode($profile->getParam('return'));
-			if ($pReturn) 
+
+			$myreturn = base64_decode($profile->getParam('return'));
+			if ($myreturn) 
 			{
-				$return = $pReturn;
 				$profile->setParam('return','');
 			}
-			
-			// make as confirmed
 			$profile->set('emailConfirmed', 1);
-			
-			// set public setting
-			$mconfig = JComponentHelper::getParams('com_members');
+
+			$mconfig =& JComponentHelper::getParams('com_members');
 			$profile->set('public', $mconfig->get('privacy', '0'));
-			
-			// upload profile
+
 			if (!$profile->update()) 
 			{
 				$this->setError(JText::_('COM_REGISTER_ERROR_CONFIRMING'));
 			}
-			
+
+			$hconfig = &JComponentHelper::getParams('com_register');
+
+			// Override any other return settings if $return is explicitly set
+			$return = $hconfig->get('ConfirmationReturn');
+			if ($return) 
+			{
+				$myreturn = $return;
+			}
+
 			// Redirect
-			if (empty($return)) 
+			if (empty($myreturn)) 
 			{
 				$r = $hconfig->get('LoginReturn');
-				$return = ($r) ? $r : JRoute::_('index.php?option=com_members&task=myaccount');
+				$myreturn = ($r) ? $r : JRoute::_('index.php?option=com_members&task=myaccount');
 				// consume cookie (yum) if available to return to whatever action prompted registration
 				if (isset($_COOKIE['return'])) {
-					$return = $_COOKIE['return'];
+					$myreturn = $_COOKIE['return'];
 					setcookie('return', '', time() - 3600);
 				}
 			}
 
-			$app->redirect($return,'','message',true);
+			$app->redirect($myreturn,'','message',true);
 		} 
 		else 
 		{
@@ -1664,7 +1608,6 @@ class RegisterController extends Hubzero_Controller
 		$view->login    = $xprofile->get('username');
 		$view->email    = $xprofile->get('email');
 		$view->code     = $code;
-		$view->redirect = ($redirect) ? $redirect : '';
 		$view->sitename = $this->jconfig->getValue('config.sitename');
 		if ($this->getError()) 
 		{
@@ -1680,7 +1623,7 @@ class RegisterController extends Hubzero_Controller
 	 */
 	protected function unconfirmed()
 	{
-		$xprofile = Hubzero_Factory::getProfile();
+		$xprofile =& Hubzero_Factory::getProfile();
 		$email_confirmed = $xprofile->get('emailConfirmed');
 
 		// Incoming
@@ -1739,7 +1682,7 @@ class RegisterController extends Hubzero_Controller
 	 */
 	protected function _buildPathway()
 	{
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 
 		if (count($pathway->getPathWay()) <= 0) 
 		{
@@ -1772,7 +1715,7 @@ class RegisterController extends Hubzero_Controller
 		{
 			$title = JText::_('COM_REGISTER');
 		}
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($title);
 	}
 
@@ -1784,7 +1727,7 @@ class RegisterController extends Hubzero_Controller
 	private function _cookie_check()
 	{
 		$app = JFactory::getApplication();
-		$jsession = JFactory::getSession();
+		$jsession =& JFactory::getSession();
 		$jcookie = $jsession->getName();
 
 		if (!isset($_COOKIE[$jcookie])) 
