@@ -21,7 +21,6 @@ HUB.Presenter = {
 		transcriptBoxScrolling = false;
 		canSendTracking = true;
 		sendingTracking = false;
-		detailedTrackingId = null;
 		doneLoading = false;
 		
 		//add class presenter to body
@@ -889,7 +888,7 @@ HUB.Presenter = {
 			//start tracking again
 			canSendTracking = true;
 			sendingTracking = false;
-			HUB.Presenter.replayMediaTracking();
+			HUB.Presenter.startMediaTracking();
 			
 			//get player and play
 			player = HUB.Presenter.getPlayer();
@@ -904,6 +903,14 @@ HUB.Presenter = {
 	
 	navBar: function() 
 	{
+		//back home
+		jQ("#nanohub").bind("click",function(e) {
+			if(!mobile) {
+				e.preventDefault();
+				window.close();
+			}
+		});
+		
 		//presentation picker
 		jQ("#presentation").bind("change", function(e) {
 			if(this.value != "") {
@@ -1249,11 +1256,6 @@ HUB.Presenter = {
 		}, 5000);
 	},
 	
-	replayMediaTracking: function()
-	{
-		HUB.Presenter.mediaTrackingEvent('replay');
-	},
-	
 	updateMediaTracking: function()
 	{
 		HUB.Presenter.mediaTrackingEvent('update');
@@ -1303,23 +1305,14 @@ HUB.Presenter = {
 			//make ajax call
 			jQ.ajax({
 				type: 'POST',
-				dataType: 'json',
+				data: { event: eventType, resourceid: resourceId, time: playerTime, duration: playerDuration },
 				url: url,
-				data: { 
-					event: eventType,
-					resourceid: resourceId,
-					time: playerTime,
-					duration: playerDuration,
-					detailedTrackingId: detailedTrackingId
-				},
 				error: function( jqXHR, status, error )
 				{
 					console.log(error);
 				},
 				success: function( data, status, jqXHR )
-				{
-					detailedTrackingId = data.detailedId;
-				},
+				{},
 				complete: function( jqXHR, status )
 				{
 					//we have to wait another 5 seconds to update
