@@ -45,7 +45,7 @@ class ResourcesHtml
 	 * @param      integer $quotes Include quotes?
 	 * @return     string
 	 */
-	public static function encode_html($str, $quotes=1)
+	public function encode_html($str, $quotes=1)
 	{
 		$str = stripslashes($str);
 		$a = array(
@@ -69,7 +69,7 @@ class ResourcesHtml
 	 * @param      integer $desclen Length to shorten to
 	 * @return     string
 	 */
-	public static function cleanText($text, $desclen=300)
+	public function cleanText($text, $desclen=300)
 	{
 		$elipse = false;
 
@@ -102,7 +102,7 @@ class ResourcesHtml
 	 * @param      string $tag HTML element
 	 * @return     string HTML
 	 */
-	public static function warning($msg, $tag='p')
+	public function warning($msg, $tag='p')
 	{
 		return '<' . $tag . ' class="warning">' . $msg . '</' . $tag . '>' . "\n";
 	}
@@ -114,7 +114,7 @@ class ResourcesHtml
 	 * @param      string $tag HTML element
 	 * @return     string HTML
 	 */
-	public static function archive($msg, $tag='p')
+	public function archive($msg, $tag='p')
 	{
 		return '<' . $tag . ' class="archive">' . $msg . '</' . $tag . '>' . "\n";
 	}
@@ -125,7 +125,7 @@ class ResourcesHtml
 	 * @param      string $msg Message to display
 	 * @return     string HTML
 	 */
-	public static function alert($msg)
+	public function alert($msg)
 	{
 		return "<script type=\"text/javascript\"> alert('" . $msg . "'); window.history.go(-1); </script>\n";
 	}
@@ -137,7 +137,7 @@ class ResourcesHtml
 	 * @param      string $txt   Header text
 	 * @return     string HTML
 	 */
-	public static function hed($level, $txt)
+	public function hed($level, $txt)
 	{
 		return '<h' . $level . '>' . $txt . '</h' . $level . '>';
 	}
@@ -151,7 +151,7 @@ class ResourcesHtml
 	 * @param      string $class Class to add
 	 * @return     string HTML
 	 */
-	public static function formSelect($name, $array, $value, $class='')
+	public function formSelect($name, $array, $value, $class='')
 	{
 		$out  = '<select name="' . $name . '" id="' . $name . '"';
 		$out .= ($class) ? ' class="' . $class . '">' . "\n" : '>' . "\n";
@@ -174,7 +174,7 @@ class ResourcesHtml
 	 * @param      string $s Secondary cell content
 	 * @return     string HTML
 	 */
-	public static function tableRow($h, $c='', $s='')
+	public function tableRow($h, $c='', $s='')
 	{
 		$html  = '  <tr>' . "\n";
 		$html .= '   <th>' . $h . '</th>' . "\n";
@@ -203,9 +203,9 @@ class ResourcesHtml
 	 * @param      string  $r_type     Resource type ID
 	 * @return     string HTML
 	 */
-	public static function adminIcon($id, $published, $show_edit, $created_by=0, $type, $r_type)
+	public function adminIcon($id, $published, $show_edit, $created_by=0, $type, $r_type)
 	{
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 
 		if ($published < 0) 
 		{
@@ -249,7 +249,7 @@ class ResourcesHtml
 	 * @param      string $tag  Tag to extract <nb:tag></nb:tag>
 	 * @return     string 
 	 */
-	public static function parseTag($text, $tag)
+	public function parseTag($text, $tag)
 	{
 		preg_match("#<nb:" . $tag . ">(.*?)</nb:" . $tag . ">#s", $text, $matches);
 		if (count($matches) > 0) 
@@ -272,7 +272,7 @@ class ResourcesHtml
 	 * @param      integer $someid ID to format
 	 * @return     string
 	 */
-	public static function niceidformat($someid)
+	public function niceidformat($someid)
 	{
 		ximport('Hubzero_View_Helper_Html');
 		return Hubzero_View_Helper_Html::niceidformat($someid);
@@ -286,145 +286,26 @@ class ResourcesHtml
 	 * @param      string  $base Base path to prepend
 	 * @return     string
 	 */
-	public static function build_path($date='', $id, $base)
+	public function build_path($date='', $id, $base)
 	{
-		$dir_id = self::niceidformat($id);
-		
 		if ($date && preg_match("/([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})/", $date, $regs)) 
 		{
 			$date = mktime($regs[4], $regs[5], $regs[6], $regs[2], $regs[3], $regs[1]);
 		}
 		if ($date) 
 		{
-			$dir_year  = JFactory::getDate($date)->format('Y');
-			$dir_month = JFactory::getDate($date)->format('m');
-
-			if (!is_dir($base . DS . $dir_year . DS . $dir_month . DS . $dir_id) && intval($dir_year) <= 2013 && intval($dir_month) <= 11)
-			{
-				$dir_year  = JHTML::_('date', $date, 'Y');
-				$dir_month = JHTML::_('date', $date, 'm');
-			}
+			$dir_year  = date('Y', $date);
+			$dir_month = date('m', $date);
 		} 
 		else 
 		{
-			$dir_year  = JFactory::getDate()->format('Y');
-			$dir_month = JFactory::getDate()->format('m');
+			$dir_year  = date('Y');
+			$dir_month = date('m');
 		}
+		$dir_id = self::niceidformat($id);
 
 		return $base . DS . $dir_year . DS . $dir_month . DS . $dir_id;
 	}
-	
-	/**
-	 * Display certain supporting docs and/or link to more
-	 * 
-	 * @param      object  $publication   	Publication object
-	 * @param      string  $option 			Component name
-	 * @param      object  $children 		Publication attachments	
-	 * @return     string HTML
-	 */
-	public static function sortSupportingDocs( $publication, $option, $children ) 
-	{
-		// Set counts		
-		$docs 	= 0;
-		
-		$html 	= '';
-		$supln  = '<ul class="supdocln">'."\n";
-		$supli  = array();
-		$shown 	= array();
-				
-		if ($children)
-		{
-			foreach ($children as $child) 
-			{			
-				$docs++;									
-				$child->title = $child->title ? stripslashes($child->title) : '';				
-				$child->title = str_replace( '"', '&quot;', $child->title );
-				$child->title = str_replace( '&amp;', '&', $child->title );
-				$child->title = str_replace( '&', '&amp;', $child->title );
-				$child->title = str_replace( '&amp;quot;', '&quot;', $child->title );
-				
-				$title = ($child->logicaltitle)
-						? stripslashes($child->logicaltitle)
-						: stripslashes($child->title);
-						
-				$params = new JParameter( $child->params );
-				
-				$ftype 	  = ResourcesHtml::getFileExtension($child->path);
-				//$class    = $params->get('class', $ftype);
-				$doctitle = $params->get('title', $title);
-				
-				// Things we want to highlight
-				$toShow = array('User Guide', 'Syllabus', 'iTunes', 'iTunes U', 'Audio', 'Video', 'Slides', 'YouTube', 'Vimeo');
-
-				$url = ResourcesHtml::processPath($option, $child, $publication->id);
-				$extra = '';
-				
-				foreach ($toShow as $item)
-				{
-					if (strtolower($doctitle) !=  preg_replace('/' . strtolower($item) . '/', '', strtolower($doctitle))
-						&& !in_array($item, $shown)) 
-					{
-						$class = str_replace(' ', '', strtolower($item));
-						$childParams  = new JParameter($child->params);
-						$childAttribs = new JParameter($child->attribs);
-						$linkAction = $childParams->get('link_action', 0);
-						$width      = $childAttribs->get('width', 640) + 20;
-						$height     = $childAttribs->get('height', 360) + 60;
-						
-						if ($linkAction == 1)
-						{
-							$supli[] = ' <li><a class="'.$class.'" rel="external" href="'.$url.'" title="'.$child->title.'"' 
-							. $extra . '>'.$item.'</a></li>'."\n";
-						}
-						elseif ($linkAction == 2)
-						{
-							$class .= ' play';
-							$class .= ' ' . $width . 'x' . $height;
-							$supli[] = ' <li><a class="'.$class.'" href="'.$url.'" title="'.$child->title.'"' 
-							. $extra . '>'.$item.'</a></li>'."\n";
-						}
-						else
-						{
-							$supli[] = ' <li><a class="'.$class.'" href="'.$url.'" title="'.$child->title.'"' 
-							. $extra . '>'.$item.'</a></li>'."\n";
-						}
-
-						$shown[] = $item;
-					}
-				}
-			}
-		}	
-		
-		$sdocs = count( $supli ) > 2 ? 2 : count( $supli );
-		$otherdocs = $docs - $sdocs;
-		$otherdocs = ($sdocs + $otherdocs) == 3  ? 0 : $otherdocs;
-
-		for ($i=0; $i < count( $supli ); $i++) 
-		{
-			$supln .=  $i < 2 ? $supli[$i] : '';
-			$supln .=  $i == 2 && !$otherdocs ? $supli[$i] : '';
-		}	
-		
-		// View more link?			
-		if ($docs > 0 && $otherdocs > 0) 
-		{
-			$supln .= ' <li class="otherdocs"><a href="' . JRoute::_('index.php?option=' . $option 
-				. '&id=' . $publication->id . '&active=supportingdocs')
-				.'" title="' . JText::_('View All') . ' ' . $docs.' ' . JText::_('Supporting Documents').' ">' 
-				. $otherdocs . ' ' . JText::_('more') . ' &rsaquo;</a></li>' . "\n";
-		}
-		 
-		if (!$sdocs && $docs > 0) 
-		{
-			$html .= "\t\t" . '<p class="viewalldocs"><a href="' . JRoute::_('index.php?option=' 
-				. $option . '&id=' . $publication->id . '&active=supportingdocs') . '">' 
-				. JText::_('Additional materials available') . ' (' . $docs .')</a></p>'."\n";
-		}
-		
-		$supln .= '</ul>'."\n";
-		$html .= $sdocs ? $supln : '';
-		return $html;			
-	}
 
 	/**
 	 * Display a list of screenshots for a tool
@@ -439,12 +320,12 @@ class ResourcesHtml
 	 * @param      string  $path      Path
 	 * @return     string HTML
 	 */
-	public static function screenshots($id, $created, $upath, $wpath, $versionid=0, $sinfo=array(), $slidebar=0, $path='')
+	public function screenshots($id, $created, $upath, $wpath, $versionid=0, $sinfo=array(), $slidebar=0, $path='')
 	{
 		$path = self::build_path($created, $id, '');
 
 		// Get contribtool parameters
-		$tconfig = JComponentHelper::getParams('com_tools');
+		$tconfig =& JComponentHelper::getParams('com_tools');
 		$allowversions = $tconfig->get('screenshot_edit');
 
 		if ($versionid && $allowversions) 
@@ -580,7 +461,7 @@ class ResourcesHtml
 	 * @param      string $pic File name
 	 * @return     string
 	 */
-	public static function thumbnail($pic)
+	public function thumbnail($pic)
 	{
 		jimport('joomla.filesystem.file');
 		return JFile::stripExt($pic) . '-tn.gif';
@@ -593,7 +474,7 @@ class ResourcesHtml
 	 * @param      integer $sel    Selected level
 	 * @return     string HTML
 	 */
-	public static function skillLevelCircle($levels = array(), $sel = 0)
+	public function skillLevelCircle($levels = array(), $sel = 0)
 	{
 		$html = '<ul class="audiencelevel">' . "\n";
 		foreach ($levels as $key => $value)
@@ -613,7 +494,7 @@ class ResourcesHtml
 	 * @param      string $audiencelink Link to learn more about skill levels
 	 * @return     string HTML
 	 */
-	public static function skillLevelTable($labels = array(), $audiencelink)
+	public function skillLevelTable($labels = array(), $audiencelink)
 	{
 		$html  = '<table class="skillset" summary="' . JText::_('Resource Audience Skill Rating Table') . '">' . "\n";
 		$html .= "\t".'<thead>' . "\n";
@@ -643,7 +524,7 @@ class ResourcesHtml
 	 * @param      string  $audiencelink Link to learn more about skill levels
 	 * @return     string HTML
 	 */
-	public static function showSkillLevel($audience, $showtips = 1, $numlevels = 4, $audiencelink = '')
+	public function showSkillLevel($audience, $showtips = 1, $numlevels = 4, $audiencelink = '')
 	{
 		$html     = '';
 		$levels   = array();
@@ -733,7 +614,7 @@ class ResourcesHtml
 	 * @param      string  $xtra      Extra content to append
 	 * @return     string HTML
 	 */
-	public static function metadata($params, $ranking, $statshtml, $id, $sections, $xtra='')
+	public function metadata($params, $ranking, $statshtml, $id, $sections, $xtra='')
 	{
 		/*$html = '';
 		if ($params->get('show_ranking')) 
@@ -784,7 +665,7 @@ class ResourcesHtml
 	 * @param      string $content Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function supportingDocuments($content)
+	public function supportingDocuments($content)
 	{
 		$html  = self::hed(3,JText::_('COM_RESOURCES_SUPPORTING_DOCUMENTS')) . "\n";
 		$html .= $content;
@@ -798,14 +679,14 @@ class ResourcesHtml
 	 * @param      array $license License name
 	 * @return     string HTML
 	 */
-	public static function license($license)
+	public function license($license)
 	{
 		include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_resources' . DS . 'tables' . DS . 'license.php');
 
 		$license = str_replace(' ', '-', strtolower($license));
 		$license = preg_replace("/[^a-zA-Z0-9\-_]/", '', $license);
 
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 		$rl = new ResourcesLicense($database);
 		$rl->load($license);
 
@@ -843,7 +724,7 @@ class ResourcesHtml
 	 * @param      string $c        Extra classes
 	 * @return     string HTML
 	 */
-	public static function sections($sections, $cats, $active='about', $h, $c)
+	public function sections($sections, $cats, $active='about', $h, $c)
 	{
 		$html = '';
 
@@ -857,12 +738,10 @@ class ResourcesHtml
 		{
 			if ($section['html'] != '') 
 			{
-				/*
 				if (!isset($cats[$k]) || !$cats[$k])
 				{
 					continue;
 				}
-				*/
 				$cls  = ($c) ? $c . ' ' : '';
 				//if (key($cats[$k]) != $active) 
 				if ($section['area'] != $active)
@@ -887,7 +766,7 @@ class ResourcesHtml
 	 * @param      string $alias  Resource alias
 	 * @return     string HTML
 	 */
-	public static function tabs($option, $id, $cats, $active='about', $alias='')
+	public function tabs($option, $id, $cats, $active='about', $alias='')
 	{
 		$html  = "\t" . '<ul id="sub-menu" class="sub-menu">' . "\n";
 		$i = 1;
@@ -906,13 +785,13 @@ class ResourcesHtml
 				}
 				if (strtolower($name) == $active) 
 				{
-					$app = JFactory::getApplication();
-					$pathway = $app->getPathway();
+					$app =& JFactory::getApplication();
+					$pathway =& $app->getPathway();
 					$pathway->addItem($cat[$name],$url);
 
 					if ($active != 'about') 
 					{
-						$document = JFactory::getDocument();
+						$document =& JFactory::getDocument();
 						$title = $document->getTitle();
 						$document->setTitle($title . ': ' . $cat[$name]);
 					}
@@ -939,8 +818,17 @@ class ResourcesHtml
 	 * @param      integer $show_posted Show published date
 	 * @return     string HTML
 	 */
-	public static function title($option, $resource, $params, $show_edit, $config=null, $show_posted=1)
+	public function title($option, $resource, $params, $show_edit, $config=null, $show_posted=1)
 	{
+		$dateFormat = '%d %b %Y';
+		$tz = null;
+
+		if (version_compare(JVERSION, '1.6', 'ge'))
+		{
+			$dateFormat = 'd M Y';
+			$tz = false;
+		}
+
 		$mode = JRequest::getWord('mode', '');
 
 		$txt = '';
@@ -979,7 +867,7 @@ class ResourcesHtml
 			$typenorm = preg_replace("/[^a-zA-Z0-9]/", '', strtolower($resource->getTypeTitle()));
 
 			$html .= '<p>' . JText::_('COM_RESOURCES_POSTED') . ' ';
-			$html .= ($thedate) ? JHTML::_('date', $thedate, JText::_('DATE_FORMAT_HZ1')) . ' ' : '';
+			$html .= ($thedate) ? JHTML::_('date', $thedate, $dateFormat, $tz) . ' ' : '';
 			$html .= JText::_('COM_RESOURCES_IN') . ' <a href="' . JRoute::_('index.php?option=' . $option . '&type=' . $typenorm) . '">' . $resource->getTypeTitle() . '</a></p>' . "\n";
 		}
 
@@ -997,8 +885,8 @@ class ResourcesHtml
 	 * @param      object $helper   ResourcesHelper
 	 * @return     string HTML
 	 */
-	//public static function citationCOins($cite, $resource, $config, $helper)
-	public static function citationCOins($cite, $model)
+	//public function citationCOins($cite, $resource, $config, $helper)
+	public function citationCOins($cite, $model)
 	{
 		if (!$cite) 
 		{
@@ -1008,7 +896,7 @@ class ResourcesHtml
 		$html  = '<span class="Z3988" title="ctx_ver=Z39.88-2004&amp;rft_val_fmt=info%3Aofi%2Ffmt%3Akev%3Amtx%3Ajournal';
 
 		// Get contribtool params
-		$tconfig = JComponentHelper::getParams('com_tools');
+		$tconfig =& JComponentHelper::getParams('com_tools');
 		$doi = '';
 
 		/*
@@ -1092,11 +980,12 @@ class ResourcesHtml
 	 * @param      unknown $fsize Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function about($database, $show_edit, $usersgroups, $resource, $helper, $config, $sections, $thistool, $curtool, $alltools, $revision, $params, $attribs, $option, $fsize)
+	public function about($database, $show_edit, $usersgroups, $resource, $helper, $config, $sections, $thistool, $curtool, $alltools, $revision, $params, $attribs, $option, $fsize)
 	{
 		$exp1Format = '%B %d, %Y';
 		$exp2Format = '%I:%M %p, %B %d, %Y';
 		$yearFormat = '%Y';
+		$dateFormat = '%d %b %Y';
 		$tz = null;
 
 		if (version_compare(JVERSION, '1.6', 'ge'))
@@ -1104,6 +993,7 @@ class ResourcesHtml
 			$exp1Format = 'M d, Y';
 			$exp2Format = 'h:i A, M d, Y';
 			$yearFormat = 'Y';
+			$dateFormat = 'd M Y';
 			$tz = false;
 		}
 
@@ -1143,7 +1033,7 @@ class ResourcesHtml
 		$maintext = stripslashes($maintext);
 
 		if ($introtext) {
-			$document = JFactory::getDocument();
+			$document =& JFactory::getDocument();
 			$document->setDescription(self::encode_html(strip_tags($introtext)));
 		}
 
@@ -1212,7 +1102,7 @@ class ResourcesHtml
 					'domain'   => ''
 				);
 				ximport('Hubzero_Wiki_Parser');
-				$p = Hubzero_Wiki_Parser::getInstance();
+				$p =& Hubzero_Wiki_Parser::getInstance();
 				$maintext = $p->parse($maintext, $wikiconfig);
 			}
 		}
@@ -1241,14 +1131,14 @@ class ResourcesHtml
 			if ($params->get('show_metadata')) {
 				$supported = null;
 				if ($resource->type == 7) {
-					$database = JFactory::getDBO();
+					$database =& JFactory::getDBO();
 					$rt = new ResourcesTags($database);
 					$supported = $rt->checkTagUsage($config->get('supportedtag'), $resource->id);
 				}
 				$xtra = '';
 				if ($supported) {
 					include_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'helpers' . DS . 'handler.php');
-					$tag = new TagsTableTag($database);
+					$tag = new TagsTag($database);
 					$tag->loadTag($config->get('supportedtag'));
 
 					$sl = $config->get('supportedlink');
@@ -1278,7 +1168,7 @@ class ResourcesHtml
 		} else {
 			$helper->getFirstChild();
 
-			$jconfig = JFactory::getConfig();
+			$jconfig =& JFactory::getConfig();
 
 			switch ($resource->type)
 			{
@@ -1441,8 +1331,8 @@ class ResourcesHtml
 				if ($resource->revision!='dev') 
 				{
 					$versiontext .=  ' - '.JText::_('COM_RESOURCES_PUBLISHED_ON').' ';
-					$versiontext .= ($thistool->released && $thistool->released != '0000-00-00 00:00:00') ? JHTML::_('date', $thistool->released, JText::_('DATE_FORMAT_HZ1')): JHTML::_('date', $resource->publish_up, JText::_('DATE_FORMAT_HZ1'));
-					$versiontext .= ($thistool->unpublished && $thistool->unpublished != '0000-00-00 00:00:00') ? ', '.JText::_('COM_RESOURCES_UNPUBLISHED_ON').' '.JHTML::_('date', $thistool->unpublished, JText::_('DATE_FORMAT_HZ1')): '';
+					$versiontext .= ($thistool->released && $thistool->released != '0000-00-00 00:00:00') ? JHTML::_('date', $thistool->released, $dateFormat, $tz): JHTML::_('date', $resource->publish_up, $dateFormat, $tz);
+					$versiontext .= ($thistool->unpublished && $thistool->unpublished != '0000-00-00 00:00:00') ? ', '.JText::_('COM_RESOURCES_UNPUBLISHED_ON').' '.JHTML::_('date', $thistool->unpublished, $dateFormat, $tz): '';
 				} 
 				else 
 				{
@@ -1452,7 +1342,7 @@ class ResourcesHtml
 			else if ($curtool) 
 			{
 				$versiontext .= $curtool->version.'</strong> - '.JText::_('PUBLISHED_ON').' ';
-				$versiontext .= ($curtool->released && $curtool->released != '0000-00-00 00:00:00') ? JHTML::_('date', $curtool->released, JText::_('DATE_FORMAT_HZ1')) : JHTML::_('date', $resource->publish_up, JText::_('DATE_FORMAT_HZ1'));
+				$versiontext .= ($curtool->released && $curtool->released != '0000-00-00 00:00:00') ? JHTML::_('date', $curtool->released, $dateFormat, $tz): JHTML::_('date', $resource->publish_up, $dateFormat, $tz);
 			}
 
 			if ($revision == 'dev') 
@@ -1550,7 +1440,7 @@ class ResourcesHtml
 					if ($alltools && ($resource->doi || $resource->doi_label)) 
 					{
 						// Get contribtool params
-						$tconfig = JComponentHelper::getParams('com_tools');
+						$tconfig =& JComponentHelper::getParams('com_tools');
 						$doi = '';
 
 						if ($resource->doi && $tconfig->get('doi_shoulder'))
@@ -1566,10 +1456,10 @@ class ResourcesHtml
 					} 
 					else 
 					{
-						$juri = JURI::getInstance();
+						$juri =& JURI::getInstance();
 
 						$cite->location = $juri->base() . ltrim($sef, DS);
-						$cite->date = JFactory::getDate()->toSql();
+						$cite->date = date("Y-m-d H:i:s");
 					}
 					$cite->url = '';
 					$cite->type = '';
@@ -1617,7 +1507,7 @@ class ResourcesHtml
 			{
 				$helper->getTagCloud($show_edit);
 
-				$juser = JFactory::getUser();
+				$juser =& JFactory::getUser();
 
 				if ($helper->tagCloud) 
 				{
@@ -1645,25 +1535,18 @@ class ResourcesHtml
 	 * @param      string  $rev       Tool revision
 	 * @return     string HTML
 	 */
-	public static function citation($option, $cite, $id, $citations, $type, $rev='')
+	public function citation($option, $cite, $id, $citations, $type, $rev='')
 	{
 		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_citations' . DS . 'helpers' . DS . 'format.php');
 
 		$html  = '<p>' . JText::_('COM_RESOURCES_CITATION_INSTRUCTIONS') . '</p>' . "\n";
-		if (trim($citations))
-		{
-			$html .= '<ul class="citations results">' . "\n";
-			$html .= "\t" . '<li>' . "\n";
-			$html .= $citations;
-			$html .= "\t" . '</li>' . "\n";
-			$html .= '</ul>' . "\n";
-		}
+		$html .= $citations;
 		if ($cite) 
 		{
 			$html .= '<ul class="citations results">' . "\n";
 			$html .= "\t" . '<li>' . "\n";
 			$html .= CitationFormat::formatReference($cite);
-			if (is_numeric($rev) || (is_string($rev) && $rev != 'dev')) 
+			if ($rev != 'dev') 
 			{
 				$html .= "\t\t" . '<p class="details">' . "\n";
 				$html .= "\t\t\t" . '<a href="index.php?option=' . $option . '&task=citation&id=' . $id . '&format=bibtex&no_html=1&rev=' . $rev . '" title="' . JText::_('COM_RESOURCES_DOWNLOAD_BIBTEX_FORMAT') . '">BibTex</a> <span>|</span> ' . "\n";
@@ -1672,9 +1555,7 @@ class ResourcesHtml
 			}
 			$html .= "\t" . '</li>' . "\n";
 			$html .= '</ul>' . "\n";
-			
 		}
-		
 		/*if ($type == 7) 
 		{
 			$html .= '<p>'.JText::_('In addition, we would appreciate it if you would add the following acknowledgment to your publication:').'</p>' . "\n";
@@ -1693,7 +1574,7 @@ class ResourcesHtml
 	 * @param      integer $rating Rating (out of 5 total)
 	 * @return     string 
 	 */
-	public static function getRatingClass($rating=0)
+	public function getRatingClass($rating=0)
 	{
 		switch ($rating)
 		{
@@ -1730,9 +1611,9 @@ class ResourcesHtml
 	 * @param      integer $fsize Parameter description (if any) ...
 	 * @return     string Return description (if any) ...
 	 */
-	public static function writeChildren($config, $option, $database, $resource, $children, $live_site, $id=0, $active=0, $pid=0, $fsize=0)
+	public function writeChildren($config, $option, $database, $resource, $children, $live_site, $id=0, $active=0, $pid=0, $fsize=0)
 	{
-	    $juser = JFactory::getUser();
+	    $juser =& JFactory::getUser();
 		$out   = '';
 		$blorp = '';
 		if ($children != NULL) 
@@ -1876,15 +1757,6 @@ class ResourcesHtml
 					$child->title = str_replace('&', '&amp;', $child->title);
 					$child->title = str_replace('&amp;quot;', '&quot;', $child->title);
 
-					// width & height
-					$attribs = new $paramsClass($child->attribs);
-					$width  = intval($attribs->get('width', 640));
-					$height = intval($attribs->get('height', 360));
-					if ($width > 0 && $height > 0) 
-					{
-						$class .= ' ' . ($width + 20) . 'x' . ($height + 60);
-					}
-
 					// user guide 
 					//$guide = 0;
 					if (strtolower($title) !=  preg_replace('/user guide/', '', strtolower($title))) 
@@ -1918,7 +1790,7 @@ class ResourcesHtml
 	 * @param      string $url File path/name
 	 * @return     string
 	 */
-	public static function getFileExtension($url)
+	public function getFileExtension($url)
 	{
 		jimport('joomla.filesystem.file');
 		return JFile::getExt($url);
@@ -1933,10 +1805,10 @@ class ResourcesHtml
 	 * @param      integer $action Action
 	 * @return     string
 	 */
-	public static function processPath($option, $item, $pid=0, $action=0)
+	public function processPath($option, $item, $pid=0, $action=0)
 	{
-		$database = JFactory::getDBO();
-		$juser = JFactory::getUser();
+		$database =& JFactory::getDBO();
+		$juser =& JFactory::getUser();
 
 		$rt = new ResourcesType($database);
 		$rt->load($item->type);
@@ -2008,11 +1880,11 @@ class ResourcesHtml
 	 * @param      string $xact       Extra parameters to add
 	 * @return     string 
 	 */
-	public static function primary_child($option, $resource, $firstChild, $xact='')
+	public function primary_child($option, $resource, $firstChild, $xact='')
 	{
-	    $juser = JFactory::getUser();
+	    $juser =& JFactory::getUser();
 
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		$html = '';
 
@@ -2021,7 +1893,7 @@ class ResourcesHtml
 			case 7:
 				if (version_compare(JVERSION, '1.6', 'lt'))
 				{
-					$jacl = JFactory::getACL();
+					$jacl =& JFactory::getACL();
 					$jacl->addACL('com_tools', 'manage', 'users', 'super administrator');
 					$jacl->addACL('com_tools', 'manage', 'users', 'administrator');
 					$jacl->addACL('com_tools', 'manage', 'users', 'manager');
@@ -2030,14 +1902,15 @@ class ResourcesHtml
 				}
 				else
 				{
-					$authorized = $juser->authorise('core.manage', 'com_tools.' . $resource->id);
+					$authorized = $juser->authorise('core.manage', 'com_tools.' . $this->get('id'));
 				}
 
-				$juser = JFactory::getUser();
+				$juser =& JFactory::getUser();
 
 				$mconfig = JComponentHelper::getParams('com_tools');
 
 				// Ensure we have a connection to the middleware
+				$this->can_launch = true;
 				if (!$mconfig->get('mw_on')
 				 || ($mconfig->get('mw_on') > 1 && !$authorized)) 
 				{
@@ -2055,7 +1928,7 @@ class ResourcesHtml
 
 				// Generate the URL that launches a tool session
 				$lurl ='';
-				$database = JFactory::getDBO();
+				$database =& JFactory::getDBO();
 				$tables = $database->getTableList();
 				$table = $database->getPrefix() . 'tool_version';
 
@@ -2123,24 +1996,13 @@ class ResourcesHtml
 					{
 						$groups[] = $xgroup->cn;
 					}
-					// Check if they're in the admin tool group
-					$admingroup = JComponentHelper::getParams('com_tools')->get('admingroup');
-					if ($admingroup && in_array($admingroup, $groups))
+					if ($toolgroups) 
 					{
-						$ingroup = true;
-					}
-					// Not in the admin group
-					// Check if they're in the tool's group
-					else
-					{
-						if ($toolgroups) 
+						foreach ($toolgroups as $toolgroup)
 						{
-							foreach ($toolgroups as $toolgroup)
+							if (in_array($toolgroup->cn, $groups)) 
 							{
-								if (in_array($toolgroup->cn, $groups)) 
-								{
-									$ingroup = true;
-								}
+								$ingroup = true;
 							}
 						}
 					}
@@ -2335,8 +2197,8 @@ class ResourcesHtml
 					}
 
 					$attribs = new $paramsClass($firstChild->attribs);
-					$width  = intval($attribs->get('width', 640));
-					$height = intval($attribs->get('height', 360));
+					$width  = intval($attribs->get('width', 0));
+					$height = intval($attribs->get('height', 0));
 					if ($width > 0 && $height > 0) 
 					{
 						$class .= ' ' . ($width + 20) . 'x' . ($height + 60);
@@ -2394,7 +2256,7 @@ class ResourcesHtml
 	 * @param      string  $pop      Pop-up content
 	 * @return     string
 	 */
-	public static function primaryButton($class, $href, $msg, $xtra='', $title='', $action='', $disabled=false, $pop = '')
+	public function primaryButton($class, $href, $msg, $xtra='', $title='', $action='', $disabled=false, $pop = '')
 	{
 		$out = '';
 
@@ -2436,7 +2298,7 @@ class ResourcesHtml
 	 * @param      integer $fsize     Format the filesize?
 	 * @return     string
 	 */
-	public static function getFileAttribs($path, $base_path='', $fsize=0)
+	public function getFileAttribs($path, $base_path='', $fsize=0)
 	{
 		// Return nothing if no path provided
 		if (!$path) 
@@ -2519,7 +2381,7 @@ class ResourcesHtml
 	 * @param      integer $fileSize File size to format
 	 * @return     string
 	 */
-	public static function formatsize($file_size)
+	public function formatsize($file_size)
 	{
 		ximport('Hubzero_View_Helper_Html');
 		return Hubzero_View_Helper_Html::formatSize($file_size);
@@ -2534,67 +2396,68 @@ class ResourcesHtml
 	 * @param      integer $show_date Date to display
 	 * @return     string HTML
 	 */
-	public static function writeResults(&$database, &$lines, $show_edit=0, $show_date=3)
+	public function writeResults(&$database, &$lines, $show_edit=0, $show_date=3)
 	{
 		$paramsClass = 'JParameter';
+		$dateFormat = '%d %b %Y';
+		$tz = 0;
 		if (version_compare(JVERSION, '1.6', 'ge'))
 		{
 			$paramsClass = 'JRegistry';
+			$dateFormat = 'd M Y';
+			$tz = true;
 		}
 
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 
-		$config = JComponentHelper::getParams('com_resources');
+		$config =& JComponentHelper::getParams('com_resources');
 
 		$html  = '<ol class="resources results">' . "\n";
-		if (is_array($lines))
+		foreach ($lines as $line)
 		{
-			foreach ($lines as $line)
+			// Instantiate a helper object
+			$helper = new ResourcesHelper($line->id, $database);
+			$helper->getContributors();
+			$helper->getContributorIDs();
+
+			// Determine if they have access to edit
+			if (!$juser->get('guest')) 
 			{
-				// Instantiate a helper object
-				$helper = new ResourcesHelper($line->id, $database);
-				$helper->getContributors();
-				$helper->getContributorIDs();
-
-				// Determine if they have access to edit
-				if (!$juser->get('guest')) 
+				if ((!$show_edit && $line->created_by == $juser->get('id'))
+				 || in_array($juser->get('id'), $helper->contributorIDs)) 
 				{
-					if ((!$show_edit && $line->created_by == $juser->get('id'))
-					 || in_array($juser->get('id'), $helper->contributorIDs)) 
-					{
-						$show_edit = 2;
-					}
+					$show_edit = 2;
 				}
-
-				// Get parameters
-				$params = clone($config);
-				$rparams = new $paramsClass($line->params);
-				$params->merge($rparams);
-
-				// Instantiate a new view
-				$view = new JView(array(
-					'name'   => 'browse',
-					'layout' => 'item'
-				));
-				$view->option = 'com_resources';
-				$view->config = $config;
-				$view->params = $params;
-				$view->juser  = $juser;
-				$view->helper = $helper;
-				$view->line   = $line;
-				$view->show_edit = $show_edit;
-
-				// Set the display date
-				switch ($params->get('show_date'))
-				{
-					case 0: $view->thedate = ''; break;
-					case 1: $view->thedate = JHTML::_('date', $line->created, JText::_('DATE_FORMAT_HZ1'));    break;
-					case 2: $view->thedate = JHTML::_('date', $line->modified, JText::_('DATE_FORMAT_HZ1'));   break;
-					case 3: $view->thedate = JHTML::_('date', $line->publish_up, JText::_('DATE_FORMAT_HZ1')); break;
-				}
-
-				$html .= $view->loadTemplate();
 			}
+
+			// Get parameters
+			$params = clone($config);
+			$rparams = new $paramsClass($line->params);
+			$params->merge($rparams);
+
+			// Instantiate a new view
+			$view = new JView(array(
+				'name'   => 'browse',
+				'layout' => 'item'
+			));
+			$view->option = 'com_resources';
+			$view->config = $config;
+			$view->params = $params;
+			$view->juser  = $juser;
+			$view->helper = $helper;
+			$view->line   = $line;
+			$view->show_edit = $show_edit;
+
+			// Set the display date
+			switch ($params->get('show_date'))
+			{
+				case 0: $view->thedate = ''; break;
+				case 1: $view->thedate = JHTML::_('date', $line->created, $dateFormat, $tz);    break;
+				case 2: $view->thedate = JHTML::_('date', $line->modified, $dateFormat, $tz);   break;
+				case 3: $view->thedate = JHTML::_('date', $line->publish_up, $dateFormat, $tz); break;
+			}
+
+			$html .= $view->loadTemplate();
 		}
 		$html .= '</ol>' . "\n";
 
