@@ -2,7 +2,7 @@
 /**
  * @package		Joomla.Site
  * @subpackage	com_users
- * @copyright	Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
+ * @copyright	Copyright (C) 2005 - 2013 Open Source Matters, Inc. All rights reserved.
  * @license		GNU General Public License version 2 or later; see LICENSE.txt
  */
 
@@ -29,13 +29,12 @@ class UsersControllerUser extends UsersController
 		$app = JFactory::getApplication();
 
 		// Populate the data array:
-		$data             = array();
-		$options          = array();
-		$data['return']   = base64_decode(JRequest::getVar('return', '', 'POST', 'BASE64'));
+		$data = array();
+		$data['return'] = base64_decode(JRequest::getVar('return', '', 'POST', 'BASE64'));
 		$data['username'] = JRequest::getVar('username', '', 'method', 'username');
 		$data['password'] = JRequest::getString('passwd', '', 'post', JREQUEST_ALLOWRAW);
 
-		$authenticator    = JRequest::getVar('authenticator', '', 'method');
+		$authenticator = JRequest::getVar('authenticator', '', 'method');
 
 		// If a specific authenticator is specified try to call the login method for that plugin
 		if (!empty($authenticator)) {
@@ -57,14 +56,12 @@ class UsersControllerUser extends UsersController
 						$myplugin = new $className($this,(array)$plugin);
 
 						$myplugin->login($credentials, $options);
-
+						
 						if (isset($options['return'])) {
 								$data['return'] = $options['return'];
 						}
 					}
 
-					$options['authenticator'] = $authenticator;
-
 					break;
 				}
 			}
@@ -203,44 +200,19 @@ class UsersControllerUser extends UsersController
 		if (!($error instanceof Exception)) {
 			// If the authenticator is empty, but they have an active third party session,
 			// redirect to a page indicating this and offering complete signout
-			if(isset($juser->auth_link_id) && $juser->auth_link_id && empty($authenticator))
+			if($juser->auth_link_id && empty($authenticator))
 			{
 				ximport('Hubzero_Auth_Link');
 				ximport('Hubzero_Auth_Domain');
-				$auth_domain_name = '';
-				$auth_domain      = Hubzero_Auth_Link::find_by_id($juser->auth_link_id);
-
-				if (is_object($auth_domain))
-				{
-					$auth_domain_id   = $auth_domain->auth_domain_id;
-					$auth_domain_name = Hubzero_Auth_Domain::find_by_id($auth_domain_id)->authenticator;
-				}
+				$auth_domain_id   = Hubzero_Auth_Link::find_by_id($juser->auth_link_id)->auth_domain_id;
+				$auth_domain_name = Hubzero_Auth_Domain::find_by_id($auth_domain_id)->authenticator;
 
 				// Redirect to user third party signout view
 				// Only do this for PUCAS for the time being (it's the one that doesn't lose session info after hub logout)
 				if($auth_domain_name == 'pucas')
 				{
-					// Get plugin params
-					$plugin      = JPluginHelper::getPlugin('authentication', $auth_domain_name);
-					$paramsClass = 'JParameter';
-					if (version_compare(JVERSION, '1.6', 'ge'))
-					{
-						$paramsClass = 'JRegistry';
-					}
-
-					$pparams = new $paramsClass($plugin->params);
-					$auto_logoff = $pparams->get('auto_logoff', false);
-
-					if ($auto_logoff)
-					{
-						$app->redirect(JRoute::_('index.php?option=com_users&task=user.logout&authenticator=' . $auth_domain_name, false));
-						return;
-					}
-					else
-					{
-						$app->redirect(JRoute::_('index.php?option=com_users&view=endsinglesignon&authenticator=' . $auth_domain_name, false));
-						return;
-					}
+					$app->redirect(JRoute::_('index.php?option=com_users&view=endsinglesignon&authenticator=' . $auth_domain_name, false));
+					return;
 				}
 			}
 
@@ -277,7 +249,7 @@ class UsersControllerUser extends UsersController
 		// Check for errors.
 		if ($return === false) {
 			// Get the validation messages.
-			$app	=  JFactory::getApplication();
+			$app	= &JFactory::getApplication();
 			$errors	= $model->getErrors();
 
 			// Push up to three validation messages out to the user.
@@ -414,7 +386,7 @@ class UsersControllerUser extends UsersController
 
 					$myplugin = new $className($this,(array)$plugin);
 
-					$myplugin->link();
+					$myplugin->link($credentials, $options);
 				} else {
 					// No Link method is availble
 					$app->redirect(JRoute::_('index.php?option=com_members&id=' . $user->get('id') . '&active=account'),
@@ -434,4 +406,4 @@ class UsersControllerUser extends UsersController
 	}
 
 	public function attach(){}
-}
+}
\ No newline at end of file
