@@ -147,7 +147,7 @@ class Hubzero_User_Password
 	 * @param unknown $storage Parameter description (if any) ...
 	 * @return mixed Return description (if any) ...
 	 */
-	public static function getInstance($instance, $storage = null)
+	public function getInstance($instance, $storage = null)
 	{
 		$hzup = new Hubzero_User_Password();
 		
@@ -166,7 +166,7 @@ class Hubzero_User_Password
 	 */
 	public function create()
 	{
-		$db =  JFactory::getDBO();
+		$db = &JFactory::getDBO();
 		
 		if (empty($db))
 		{
@@ -279,7 +279,7 @@ class Hubzero_User_Password
 	 */
 	function update()
 	{
-		$db =  JFactory::getDBO();
+		$db = &JFactory::getDBO();
 		
 		$query = "UPDATE #__users_password SET ";
 		
@@ -556,7 +556,7 @@ class Hubzero_User_Password
 		return $this->__set($key, $value);
 	}
 
-	public static function isPasswordExpired($user = null)
+	public function isPasswordExpired($user = null)
 	{
 		$hzup = self::getInstance($user);
 		
@@ -591,52 +591,29 @@ class Hubzero_User_Password
 		return true;
 	}
 
-	public static function getPasshash($password)
+	public function changePassword($user = null, $password)
 	{
-		// Get the password encryption/hashing mechanism
-		$config = JComponentHelper::getParams('com_members');
-		$type   = $config->get('passhash_mechanism', 'CRYPT_SHA512');
-
-		switch ($type)
-		{
-			case 'MD5':
-				$passhash = "{MD5}" . base64_encode(pack('H*', md5($password)));
-				break;
-
-			case 'CRYPT_SHA512':
-			default:
-				$encrypted = crypt($password, '$6$' . JUserHelper::genRandomPassword(8) . '$');
-				$passhash = "{CRYPT}" . $encrypted;
-				break;
-		}
-
-		return $passhash;
-	}
-
-	public static function changePassword($user = null, $password)
-	{
-		$passhash = self::getPasshash($password);
+		$passhash = "{MD5}" . base64_encode(pack('H*', md5($password)));
 
 		return self::changePasshash($user, $passhash);
 	}
 
-	public static function changePasshash($user = null, $passhash)
+	public function changePasshash($user = null, $passhash)
 	{
 		ximport('Hubzero_User_Password_History');
-
+		
 		// Get config values for min, max, and warning
-		$config        = JComponentHelper::getParams('com_members');
-		$shadowMin     = $config->get('shadowMin', '0');
-		$shadowMax     = $config->get('shadowMax', null);
+		$config = & JComponentHelper::getParams('com_members');
+		$shadowMin = $config->get('shadowMin', '0');
+		$shadowMax = $config->get('shadowMax', null);
 		$shadowWarning = $config->get('shadowWarning', '7');
-
-		// Translate empty shadowMax to mean NULL
+		
 		$shadowMax = ($shadowMax == '') ? null : $shadowMax;
-
+		
 		$hzup = self::getInstance($user);
-
+		
 		$oldhash = $hzup->__get('passhash');
-
+		
 		$hzup->__set('passhash', $passhash);
 		$hzup->__set('shadowFlag', null);
 		$hzup->__set('shadowLastChange', intval(time() / 86400));
@@ -646,73 +623,60 @@ class Hubzero_User_Password
 		$hzup->__set('shadowInactive', '0');
 		$hzup->__set('shadowExpire', null);
 		$hzup->update();
-
+		
 		$db = JFactory::getDBO();
-
-		$db->setQuery("UPDATE `#__xprofiles` SET userPassword=" . $db->Quote($passhash) . " WHERE uidNumber=" . $db->Quote($hzup->get('user_id')));
+		
+		$db->setQuery("UPDATE #__xprofiles SET userPassword=" . $db->Quote($passhash) . " WHERE uidNumber=" . $db->Quote($hzup->get('user_id')) . ";");
 		$db->query();
-
-		$db->setQuery("UPDATE `#__users` SET password=" . $db->Quote($passhash) . " WHERE id=" . $db->Quote($hzup->get('user_id')));
+		
+		$db->setQuery("UPDATE #__users SET password=" . $db->Quote($passhash) . " WHERE id=" . $db->Quote($hzup->get('user_id')) . ";");
 		$db->query();
-
+		
 		if (!empty($oldhash))
 		{
 			Hubzero_User_Password_History::addPassword($oldhash, $user);
 		}
-
+		
 		return true;
 	}
 
-	public static function comparePasswords($passhash, $password)
+	public function comparePasswords($passhash, $password)
 	{
 		if (empty($passhash) || empty($password))
 		{
 			return false;
 		}
-
+		
 		preg_match("/^\s*(\{(.*)\}\s*|)((.*?)\s*:\s*|)(.*?)\s*$/", $passhash, $matches);
-
+		
 		$encryption = strtolower($matches[2]);
-
+		
 		if (empty($encryption))
 		{ // Joomla
 			$encryption = "md5-hex";
-
+			
 			if (!empty($matches[4]))
 			{ // Joomla 1.5
 				$crypt = $matches[4];
-				$salt  = $matches[5];
+				$salt = $matches[5];
 			}
 			else
 			{ // Joomla 1.0
 				$crypt = $matches[5];
-				$salt  = '';
+				$salt = '';
 			}
 		}
 		else
 		{
-			$salt  = $matches[4];
+			$salt = $matches[4];
 			$crypt = $matches[5];
 		}
-
+		
 		if ($encryption == 'md5')
 		{
 			$encryption = "md5-base64";
 		}
-		else if ($encryption == 'crypt')
-		{
-			preg_match('/\$([[:alnum:]]{1,2})\$[[:alnum:]]{8}\$/', $passhash, $parts);
-			$salt = $parts[0];
-
-			switch ($parts[1])
-			{
-				case '6':
-				default:
-					$encryption = 'crypt-sha512';
-					break;
-			}
-		}
-
+		
 		if (empty($salt) && ($encryption == 'ssha'))
 		{
 			$salt = substr(base64_decode(substr($crypt, -32)), -4);
@@ -723,16 +687,16 @@ class Hubzero_User_Password
 			jimport('joomla.user.helper');
 			$hashed = JUserHelper::getCryptedPassword($password, $salt, $encryption);
 		}
-
+		
 		return ($crypt == $hashed);
 	}
 
-	public static function passwordMatches($user = null, $password, $alltables = false)
+	public function passwordMatches($user = null, $password, $alltables = false)
 	{
 		$passhash = null;
-
+		
 		$hzup = self::getInstance($user);
-
+		
 		if (is_object($hzup) && !empty($hzup->passhash))
 		{
 			$passhash = $hzup->passhash;
@@ -740,7 +704,7 @@ class Hubzero_User_Password
 		else if ($alltables)
 		{
 			$profile = Hubzero_User_Profile::getInstance($user);
-
+			
 			if (is_object($profile) && ($profile->get('userPassword') != ''))
 			{
 				$passhash = $profile->get('userPassword');
@@ -748,35 +712,24 @@ class Hubzero_User_Password
 			else
 			{
 				$user = JUser::getInstance($user);
-
+				
 				if (is_object($user) && !empty($user->password))
 				{
 					$passhash = $user->password;
 				}
 			}
 		}
-
+		
 		return self::comparePasswords($passhash, $password);
 	}
 
-	public static function invalidatePassword($user = null)
+	public function invalidatePassword($user = null)
 	{
 		$hzup = self::getInstance($user);
-
+		
 		$hzup->__set('shadowFlag', '-1');
 		$hzup->update();
-
-		return true;
-	}
-
-	public static function expirePassword($user = null)
-	{
-		$hzup = self::getInstance($user);
-
-		$hzup->__set('shadowLastChange', '1');
-		$hzup->__set('shadowMax', '0');
-		$hzup->update();
-
+		
 		return true;
 	}
 }
