@@ -3,7 +3,7 @@
  * @package     Joomla.Platform
  * @subpackage  Document
  *
- * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
+ * @copyright   Copyright (C) 2005 - 2013 Open Source Matters, Inc. All rights reserved.
  * @license     GNU General Public License version 2 or later; see LICENSE
  */
 
@@ -75,7 +75,7 @@ class JDocument extends JObject
 	 *
 	 * @var    string
 	 */
-	public $_generator = 'HUBzero - The open source platform for scientific and educational collaboration';
+	public $_generator = 'Joomla! - Open Source Content Management';
 
 	/**
 	 * Document modified date
@@ -481,11 +481,11 @@ class JDocument extends JObject
 	{
 		if (!isset($this->_script[strtolower($type)]))
 		{
-			$this->_script[strtolower($type)] = array($content);
+			$this->_script[strtolower($type)] = $content;
 		}
 		else
 		{
-			$this->_script[strtolower($type)][] = chr(13) . $content;
+			$this->_script[strtolower($type)] .= chr(13) . $content;
 		}
 
 		return $this;
