@@ -7,6 +7,9 @@ class Migration20130401000000ComGroups extends Hubzero_Migration
 {
 	protected static function up($db)
 	{
-		self::deletePluginEntry('groups', 'userenrollment');
+		$query = "DELETE FROM `#__plugins` WHERE folder='groups' AND element='userenrollment';";
+
+		$db->setQuery($query);
+		$db->query();
 	}
 }
\ No newline at end of file
