@@ -498,11 +498,6 @@ class Migration20130718000009ComMenus extends Hubzero_Migration
 					$db->query();
 				}
 			}
-
-			// Fix menu link type menu items to be alias type
-			$query = "UPDATE `#__menu` SET `type` = 'alias', `link` = 'index.php?Itemid=', `params` = REPLACE(`params`, 'menu_item', 'aliasoptions') WHERE `type` = 'menulink'";
-			$db->setQuery($query);
-			$db->query();
 		}
 
 		// Now we can get rid of the components table as well
@@ -513,15 +508,16 @@ class Migration20130718000009ComMenus extends Hubzero_Migration
 			$db->query();
 		}
 
-		if (!$db->tableHasKey('#__menu', 'idx_client_id_parent_id_alias_language')
+		// @FIXME: this index effectively prevents one from having two menu items with the same alias, even in different menus?
+		/*if (!$db->tableHasKey('#__menu', 'idx_client_id_parent_id_alias_language')
 				&& $db->tableHasField('#__menu', 'client_id')
 				&& $db->tableHasField('#__menu', 'parent_id')
 				&& $db->tableHasField('#__menu', 'alias')
 				&& $db->tableHasField('#__menu', 'language'))
 		{
-			$query = "ALTER TABLE `#__menu` ADD INDEX `idx_client_id_parent_id_alias_language` (`client_id` ASC, `parent_id` ASC, `alias` ASC, `language` ASC);";
+			$query = "ALTER TABLE `#__menu` ADD UNIQUE INDEX `idx_client_id_parent_id_alias_language` (`client_id` ASC, `parent_id` ASC, `alias` ASC, `language` ASC);";
 			$db->setQuery($query);
 			$db->query();
-		}
+		}*/
 	}
 }
\ No newline at end of file
