@@ -31,7 +31,7 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$juser = JFactory::getUser();
+$juser =& JFactory::getUser();
 
 $total = count($this->courses);
 
@@ -57,20 +57,11 @@ $total = count($this->courses);
 			//$status = $this->getStatus($group);
 ?>
 		<li class="course">
-			<a href="<?php echo JRoute::_('index.php?option=com_courses&gid=' . $course->alias . $sfx); ?>"><?php echo $this->escape(stripslashes($course->title)); ?></a>
-			<?php if ($course->section_title) { ?>
-			<small><strong><?php echo JText::_('MOD_MYCOURSES_SECTION'); ?></strong> <?php echo $this->escape($course->section_title); ?></small>
+			<a href="<?php echo JRoute::_('index.php?option=com_courses&gid=' . $course->alias . $sfx); ?>"><?php echo stripslashes($course->title); ?></a>
+			<?php if ($course->state == 3) { ?>
+			<small><?php echo JText::_('Draft'); ?></small>
 			<?php } ?>
-			<?php 
-			switch ($course->state) 
-			{
-				case 3: ?><small><?php echo JText::_('MOD_MYCOURSES_COURSE_STATE_DRAFT'); ?></small><?php break;
-				case 2: ?><small><?php echo JText::_('MOD_MYCOURSES_COURSE_STATE_DELETED'); ?></small><?php break;
-				case 1: ?><small><?php echo JText::_('MOD_MYCOURSES_COURSE_STATE_PUBLISHED'); ?></small><?php break;
-				case 0: ?><small><?php echo JText::_('MOD_MYCOURSES_COURSE_STATE_UNPUBLISHED'); ?></small><?php break;
-			} 
-			?>
-			<span><span class="<?php echo $this->escape($course->role); ?> status"><?php echo $this->escape($course->role); ?></span></span>
+			<span><span class="<?php echo $course->role; ?> status"><?php echo $course->role; ?></span></span>
 		</li>
 <?php
 			$i++;
