@@ -75,18 +75,26 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 	 */
 	public function onSectionEdit()
 	{
+		/*$obj = new stdClass;
+		$obj->name  = $this->_name;
+		$obj->title = JText::_('PLG_COURSES_' . strtoupper($this->_name));*/
+
 		return $this->onCourseAreas();
 	}
 
 	/**
 	 * Return the alias and name for this category of content
 	 * 
-	 * @return     array
+	 * @return     object
 	 */
-	public function onAssetgroupEdit()
+	/*public function onAssetGroupEdit()
 	{
-		return $this->onCourseAreas();
-	}
+		$obj = new stdClass;
+		$obj->name  = $this->_name;
+		$obj->title = JText::_('PLG_COURSES_' . strtoupper($this->_name));
+
+		return $obj;
+	}*/
 
 	/**
 	 * Update any category associated with the assetgroup
@@ -101,86 +109,30 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			return;
 		}
 
-		if (!$assetgroup->params('discussions_category'))
-		{
-			return;
-		}
-
-		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'section.php');
 		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'category.php');
 		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'unit.php');
 
-		// Load the parent unit
 		$unit = CoursesModelUnit::getInstance($assetgroup->get('unit_id'));
-		$db = JFactory::getDBO();
 
-		// Attempt to load the category
-		$category = new ForumTableCategory($db);
+		$category = new ForumCategory(JFactory::getDBO());
 		$category->loadByObject($assetgroup->get('id'), null, $unit->get('offering_id'), 'course');
-
-		// Is there a category already?
-		if (!$category->id)
+		if ($category->id)
 		{
-			// No category
-			// Is there a parent section?
-			$section = new ForumTableSection($db);
-			$section->loadByObject($unit->get('id'), $unit->get('offering_id'), 'course');
-			if (!$section->id)
+			$category->state = $assetgroup->get('state');
+			if ($assetgroup->get('title') == '--')
 			{
-				// No parent section
-				// Create it!
-				$section->title     = $unit->get('title');
-				$section->alias     = $unit->get('alias');
-				$section->state     = $unit->get('state');
-				$section->scope     = 'course';
-				$section->scope_id  = $unit->get('offering_id');
-				$section->object_id = $unit->get('id');
-				$section->ordering  = $unit->get('ordering');
-				if ($section->check())
-				{
-					$section->store();
-				}
+				$category->title = $assetgroup->assets()->fetch('first')->get('title');
 			}
-			// Assign the section ID
-			$category->section_id = $section->id;
-		}
-
-		// Don't change "Deleted" items
-		if ($category->state == 2)
-		{
-			return $category->id;
-		}
-
-		// Assign asset group data to category to keep them in sync
-		$category->state = $assetgroup->get('state');
-		if ($assetgroup->get('title') == '--')
-		{
-			$ag = ($assetgroup->assets() ? $assetgroup->assets()->fetch('first') : null);
-			if ($ag)
+			else
 			{
-				$category->title = $ag->get('title');
+				$category->title = $assetgroup->get('title');
+			}
+			$category->alias = $assetgroup->get('alias');
+			if ($category->check())
+			{
+				$category->store();
 			}
 		}
-		else
-		{
-			$category->title = $assetgroup->get('title');
-		}
-		$category->scope     = 'course';
-		$category->scope_id  = $unit->get('offering_id');
-		$category->object_id = $assetgroup->get('id');
-		$category->title     = ($category->title ? $category->title : $assetgroup->get('title'));
-		$category->alias     = $assetgroup->get('alias');
-		if (!$category->id)
-		{
-			$category->description = JText::sprintf('Discussions for %s', $category->title);
-		}
-		$category->ordering  = $assetgroup->get('ordering');
-		if ($category->check())
-		{
-			$category->store();
-		}
-
-
 		return $category->id;
 	}
 
@@ -200,17 +152,12 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'category.php');
 		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'unit.php');
 
-		$db   = JFactory::getDBO();
 		$unit = CoursesModelUnit::getInstance($assetgroup->get('unit_id'));
 
-		// Attempt to load an associated category
-		$category = new ForumTableCategory($db);
+		$category = new ForumCategory(JFactory::getDBO());
 		$category->loadByObject($assetgroup->get('id'), null, $unit->get('offering_id'), 'course');
-
-		// Was a category found?
-		if ($category->id && $category->state != 2)
+		if ($category->id)
 		{
-			// Mark as deleted
 			$category->state = 2;
 			if ($category->check())
 			{
@@ -219,8 +166,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'post.php');
 
-			// Mark all threads in category as deleted
-			$thread = new ForumTablePost($db);
+			$thread = new ForumPost(JFactory::getDBO());
 			$thread->setStateByCategory($category->get('id'), 2);
 		}
 
@@ -249,10 +195,9 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 
 		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'section.php');
 
-		$db      = JFactory::getDBO();
-		$section = new ForumTableSection($db);
-		$section->loadByObject($unit->get('id'), $unit->get('offering_id'), 'course');
-		if ($section->id && $section->state != 2)
+		$section = new ForumSection(JFactory::getDBO());
+		$section->loadByAlias($unit->get('alias'), $unit->get('offering_id'), 'course');
+		if ($section->id)
 		{
 			$section->state    = $unit->get('state');
 			$section->title    = $unit->get('title');
@@ -281,8 +226,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 
 		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'section.php');
 
-		$db      = JFactory::getDBO();
-		$section = new ForumTableSection($db);
+		$section = new ForumSection(JFactory::getDBO());
 		$section->loadByAlias($unit->get('alias'), $unit->get('offering_id'), 'course');
 		if ($section->id)
 		{
@@ -306,7 +250,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 
 				require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'post.php');
 
-				$thread = new ForumTablePost($db);
+				$thread = new ForumPost(JFactory::getDBO());
 				$thread->setStateByCategory($ids, 2);
 			}
 		}
@@ -350,35 +294,36 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			}
 		}
 
-		$this->config   = $config;
-		$this->course   = $course;
+		$this->config = $config;
+		$this->course = $course;
 		$this->offering = $offering;
 		$this->database = JFactory::getDBO();
 
 		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'post.php');
 
-		$paramsClass = 'JParameter';
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$paramsClass = 'JRegistry';
-		}
-		$this->params->merge(new $paramsClass($offering->section()->get('params')));
-
 		// Determine if we need to return any HTML (meaning this is the active plugin)
 		if ($return == 'html') 
 		{
 			$this->_active = $this->_name;
 
+			$paramsClass = 'JParameter';
+			if (version_compare(JVERSION, '1.6', 'ge'))
+			{
+				$paramsClass = 'JRegistry';
+			}
+
+			$this->params->merge(new $paramsClass($offering->section()->get('params')));
+
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'category.php');
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'section.php');
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'attachment.php');
-			//require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'models' . DS . 'pagination.php');
+			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'models' . DS . 'pagination.php');
 			require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'models' . DS . 'tags.php');
 
 			//Create user object
 			$this->juser = JFactory::getUser();
 
-			$this->section = new ForumTableSection($this->database);
+			$this->section = new ForumSection($this->database);
 			$this->sections = $this->section->getRecords(array(
 				'state'    => 1, 
 				'scope'    => 'course',
@@ -388,7 +333,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			));
 
 			// Make a list of linked sections
-			/*$linked = array();
+			$linked = array();
 			if ($this->sections)
 			{
 				foreach ($this->sections as $section)
@@ -408,7 +353,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 				{
 					if (!isset($linked[$unit->get('id')]))
 					{
-						$section = new ForumTableSection($this->database);
+						$section = new ForumSection($this->database);
 						$section->title     = $unit->get('title');
 						$section->alias     = $unit->get('alias');
 						$section->state     = 1;
@@ -423,7 +368,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 						}
 					}
 				}
-			}*/
+			}
 
 			//option and paging vars
 			$this->option = 'com_courses';
@@ -468,8 +413,8 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 							JRequest::setVar('category', $c);
 							$action = 'editcategory';
 						}
-						$d = JRequest::getVar('d', '');
-						switch ($d)
+						$d = JRequest::getVar('file', '');
+						switch ($c)
 						{
 							case 'edit':
 								$action = 'editcategory';
@@ -496,10 +441,6 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			{
 				$action = JRequest::getVar('action', $action, 'get');
 			}
-			if ($action == 'edit' && JRequest::getInt('post', 0))
-			{
-				$action = 'editthread';
-			}
 
 			//push the stylesheet to the view
 			ximport('Hubzero_Document');
@@ -507,7 +448,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 
 			$this->base = 'index.php?option=' . $this->option . '&gid=' . $this->course->get('alias') . '&offering=' . $this->offering->get('alias') . ($this->offering->section()->get('alias') != '__default' ? ':' . $this->offering->section()->get('alias') : '') . '&active=' . $this->_name;
 
-			$pathway = JFactory::getApplication()->getPathway();
+			$pathway =& JFactory::getApplication()->getPathway();
 			$pathway->addItem(
 				JText::_('PLG_COURSES_' . strtoupper($this->_name)), 
 				'index.php?option=' . $this->option . '&gid=' . $this->course->get('alias') . '&offering=' . $this->offering->get('alias') . '&active=' . $this->_name
@@ -542,14 +483,13 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			}
 		}
 
-		$tModel = new ForumTablePost($this->database);
+		$tModel = new ForumPost($this->database);
 
 		$arr['metadata']['count'] = $tModel->getCount(array(
 			'scope'    => 'course',
 			'scope_id' => $offering->get('id'),
 			'state'    => 1,
-			'parent'   => 0,
-			'scope_sub_id' => ($this->params->get('discussions_threads', 'all') != 'all' ? $course->offering()->section()->get('id') : null)
+			'parent'   => 0
 		));
 
 		// Return the output
@@ -565,12 +505,6 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 	 */
 	public function onCourseAfterLecture($course, $unit, $lecture)
 	{
-		// Are discussions turned on?
-		if (!$lecture->params('discussions_category'))
-		{
-			return '';
-		}
-
 		$paramsClass = 'JParameter';
 		if (version_compare(JVERSION, '1.6', 'ge'))
 		{
@@ -640,12 +574,12 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$view->filters['sort'] = 'c.created';
 		$view->filters['object_id'] = $lecture->get('id');
 
-		$view->post  = new ForumTablePost($this->database);
+		$view->post  = new ForumPost($this->database);
 		$view->total = 0;
 		$view->rows  = null;
 
 		// Load the section
-		$section = new ForumTableSection($this->database);
+		$section = new ForumSection($this->database);
 		if (!$section->loadByAlias($unit->get('alias'), $view->filters['scope_id'], $view->filters['scope']))
 		{
 			// Create a default section
@@ -661,7 +595,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			}
 		}
 
-		$category = new ForumTableCategory($this->database);
+		$category = new ForumCategory($this->database);
 		$category->loadByObject($lecture->get('id'), $section->get('id'), $view->filters['scope_id'], $view->filters['scope']);
 		if (!$category->get('id'))
 		{
@@ -680,22 +614,21 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			$category->scope       = $view->filters['scope'];
 			$category->scope_id    = $view->filters['scope_id'];
 			$category->object_id   = $lecture->get('id');
-			$category->ordering    = $lecture->get('ordering');
 			if ($category->check())
 			{
 				$category->store();
 			}
 		}
 
-		$view->post->scope        = $view->filters['scope'];
-		$view->post->scope_id     = $view->filters['scope_id'];
+		$view->post->scope = $view->filters['scope'];
+		$view->post->scope_id = $view->filters['scope_id'];
 		$view->post->scope_sub_id = $course->offering()->section()->get('id');
-		$view->post->category_id  = $category->get('id');
-		$view->post->object_id    = $lecture->get('id');
-		$view->post->parent       = 0;
+		$view->post->category_id = $category->get('id');
+		$view->post->object_id = $lecture->get('id');
+		$view->post->parent = 0;
 
 		// Get attachments
-		$view->attach = new ForumTableAttachment($this->database);
+		$view->attach = new ForumAttachment($this->database);
 		$view->attachments = $view->attach->getAttachments($view->post->id);
 
 		$view->thread = JRequest::getInt('thread', 0);
@@ -871,7 +804,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 	/**
 	 * Get an entire thread
 	 * 
-	 * @param      object $post    ForumTablePost
+	 * @param      object $post    ForumPost
 	 * @param      array  $filters Filters to apply
 	 * @return     void
 	 */
@@ -893,7 +826,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			'filepath' => '',
 			'domain'   => $post->id
 		);
-		$p = Hubzero_Wiki_Parser::getInstance();
+		$p =& Hubzero_Wiki_Parser::getInstance();
 
 		$view = new Hubzero_Plugin_View(
 			array(
@@ -927,11 +860,6 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			}
 			$total = count($rows);
 
-			if (!isset($children[$post->get('parent')]))
-			{
-				$children[$post->get('parent')] = array();
-			}
-
 			$view->comments = $this->treeRecurse($children[$post->get('parent')], $children);
 		}
 		//print_r($this->database); die();
@@ -953,7 +881,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 
 		$view->wikiconfig = $wikiconfig;
-		$view->attach     = new ForumTableAttachment($this->database);
+		$view->attach     = new ForumAttachment($this->database);
 		$view->course     = $this->course;
 		$view->search     = $filters['search'];
 		$view->post       = $post;
@@ -967,7 +895,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 	/**
 	 * Get a filtered list of threads
 	 * 
-	 * @param      object $post    ForumTablePost
+	 * @param      object $post    ForumPost
 	 * @param      array  $filters Filters to apply
 	 * @return     void
 	 */
@@ -1042,7 +970,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 	/**
 	 * Get a filtered list of threads
 	 * 
-	 * @param      object $post    ForumTablePost
+	 * @param      object $post    ForumPost
 	 * @param      array  $filters Filters to apply
 	 * @return     void
 	 */
@@ -1059,48 +987,48 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$filters['sort'] = 'created';
 		$filters['sort_Dir'] = 'ASC'; // Needs to be reverse order that items are prepended with AJAX
 
-		if ($results = $post->find($filters))
-		{
-			foreach ($results as $key => $row)
+			if ($results = $post->find($filters))
 			{
-				$threads->lastid = $row->id > $threads->lastid 
-								 ? $row->id 
-								 : $threads->lastid;
-				$threads->lastchange = ($row->created > $threads->lastchange) 
-									 ? $row->created 
-									 : $threads->lastchange;
-
-				$cview = new Hubzero_Plugin_View(
-								array(
-						'folder'  => 'courses',
-						'element' => $this->_name,
-						'name'    => 'threads',
-						'layout'  => '_thread'
-					)
-				);
-				$cview->option      = $this->option;
-				$cview->thread      = $row;
-
-				$cview->unit       = '';
-				$cview->lecture    = '';
-				if ($this->_active == 'outline')
+				foreach ($results as $key => $row)
 				{
-					$cview->unit       = $this->unit->get('alias');
-					$cview->lecture    = $this->lecture->get('alias');
+					$threads->lastid = $row->id > $threads->lastid 
+									 ? $row->id 
+									 : $threads->lastid;
+					$threads->lastchange = ($row->created > $threads->lastchange) 
+										 ? $row->created 
+										 : $threads->lastchange;
+
+					$cview = new Hubzero_Plugin_View(
+									array(
+							'folder'  => 'courses',
+							'element' => $this->_name,
+							'name'    => 'threads',
+							'layout'  => '_thread'
+						)
+					);
+					$cview->option      = $this->option;
+					$cview->thread      = $row;
+
+					$cview->unit       = '';
+					$cview->lecture    = '';
+					if ($this->_active == 'outline')
+					{
+						$cview->unit       = $this->unit->get('alias');
+						$cview->lecture    = $this->lecture->get('alias');
+					}
+
+					$cview->cls         = 'odd';
+					$cview->base        = $this->base;
+					$cview->search      = '';
+					$cview->course      = $this->course;
+					$cview->instructors = $this->_instructors();
+
+					$results[$key]->mine = ($row->created_by == $this->juser->get('id')) ? true : false;
+					$results[$key]->html = $cview->loadTemplate();
 				}
-
-				$cview->cls         = 'odd';
-				$cview->base        = $this->base;
-				$cview->search      = '';
-				$cview->course      = $this->course;
-				$cview->instructors = $this->_instructors();
-
-				$results[$key]->mine = ($row->created_by == $this->juser->get('id')) ? true : false;
-				$results[$key]->html = $cview->loadTemplate();
+				$threads->total = count($results);
+				$threads->posts = $results;
 			}
-			$threads->total = count($results);
-			$threads->posts = $results;
-		}
 
 		return $threads;
 	}
@@ -1108,7 +1036,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 	/**
 	 * Get a filtered list of posts for a thread
 	 * 
-	 * @param      object $post    ForumTablePost
+	 * @param      object $post    ForumPost
 	 * @param      array  $filters Filters to apply
 	 * @return     void
 	 */
@@ -1132,7 +1060,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 				'filepath' => '',
 				'domain'   => $post->id
 			);
-			$p = Hubzero_Wiki_Parser::getInstance();
+			$p =& Hubzero_Wiki_Parser::getInstance();
 
 			foreach ($results as $key => $row)
 			{
@@ -1168,7 +1096,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 				$cview->base       = $this->base;
 				$cview->parser     = $p;
 				$cview->wikiconfig = $wikiconfig;
-				$cview->attach     = new ForumTableAttachment($this->database);
+				$cview->attach     = new ForumAttachment($this->database);
 				$cview->course     = $this->course;
 				$cview->search     = '';
 
@@ -1224,7 +1152,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 		$this->redirect($url);
 	}
-
+	
 	/**
 	 * Set permissions
 	 * 
@@ -1354,7 +1282,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			$view->filters['sort'] = 'c.created';
 			//$view->filters['object_id'] = 0;
 
-			$view->post = new ForumTablePost($this->database);
+			$view->post = new ForumPost($this->database);
 
 			$data = new stdClass();
 			$data->success = true;
@@ -1463,7 +1391,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			$view->sections = $this->sections;
 		}
 
-		$model = new ForumTableCategory($this->database);
+		$model = new ForumCategory($this->database);
 
 		$view->stats = new stdClass;
 		$view->stats->categories = 0;
@@ -1500,7 +1428,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			 && $view->sections[$key]->object_id)
 			{
 				$view->sections[$key]->categories = array();
-				/*$unit = CoursesModelUnit::getInstance($view->sections[$key]->object_id);
+				$unit = CoursesModelUnit::getInstance($view->sections[$key]->object_id);
 				if ($unit->assetgroups()->total())
 				{
 					foreach ($unit->assetgroups() as $agt) 
@@ -1517,38 +1445,33 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 								{
 									continue;
 								}
-								$cat = new ForumTableCategory($this->database);
-								$cat->loadByObject($ag->get('id'), $section->id, $this->offering->get('id'), 'course');
-								if (!$cat->get('id'))
+								$cat = new ForumCategory($this->database);
+								$cat->section_id  = $section->id;
+								if ($ag->get('title') == '--')
 								{
-									$cat->section_id  = $section->id;
-									if ($ag->get('title') == '--')
-									{
-										$cat->title       = $ag->assets()->fetch('first')->get('title');
-									}
-									else
-									{
-										$cat->title       = $ag->get('title');
-									}
-									$cat->alias       = $ag->get('alias');
-									$cat->description = JText::sprintf('Discussions for %s', $ag->get('title'));
-									$cat->state       = 1;
-									$cat->scope       = 'course';
-									$cat->scope_id    = $this->offering->get('id');
-									$cat->object_id   = $ag->get('id');
-									$cat->ordering    = $ag->get('ordering');
-									if ($cat->check())
-									{
-										$cat->store();
-										$view->sections[$key]->categories[] = $cat;
-									}
+									$cat->title       = $ag->assets()->fetch('first')->get('title');
+								}
+								else
+								{
+									$cat->title       = $ag->get('title');
+								}
+								$cat->alias       = $ag->get('alias');
+								$cat->description = JText::sprintf('Discussions for %s', $ag->get('title'));
+								$cat->state       = 1;
+								$cat->scope       = 'course';
+								$cat->scope_id    = $this->offering->get('id');
+								$cat->object_id   = $ag->get('id');
+								if ($cat->check())
+								{
+									$cat->store();
+									$view->sections[$key]->categories[] = $cat;
 								}
 								$cat->threads = 0;
 								$cat->posts = 0;
 							}
 						}
 					}
-				}*/
+				}
 			}
 
 			$view->stats->categories += count($view->sections[$key]->categories);
@@ -1563,7 +1486,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			}
 		}
 
-		$view->post = new ForumTablePost($this->database);
+		$view->post = new ForumPost($this->database);
 		$view->post->scope    = $view->filters['scope'];
 		$view->post->scope_id = $view->filters['scope_id'];
 		$view->post->scope_sub_id = $this->offering->section()->get('id');
@@ -1645,19 +1568,19 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$view->thread = JRequest::getInt('thread', 0);
 		$view->notifications = $this->getPluginMessage();
 
-		$view->post = new ForumTablePost($this->database);
+		$view->post = new ForumPost($this->database);
 		$view->post->scope    = $view->filters['scope'];
 		$view->post->scope_id = $view->filters['scope_id'];
 		$view->post->scope_sub_id = $view->filters['scope_sub_id'];
 
-		$this->section = new ForumTableSection($this->database);
+		$this->section = new ForumSection($this->database);
 		$view->sections = $this->section->getRecords(array(
 				'state'    => $view->filters['state'],
 				'scope'    => $view->filters['scope'], 
 				'scope_id' => $view->filters['scope_id']
 			));
 
-		$model = new ForumTableCategory($this->database);
+		$model = new ForumCategory($this->database);
 
 		$view->stats = new stdClass;
 		$view->stats->categories = 0;
@@ -1737,7 +1660,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			'sort_Dir' => 'ASC'
 		));
 
-		$model = new ForumTableCategory($this->database);
+		$model = new ForumCategory($this->database);
 
 		$view->stats = new stdClass;
 		$view->stats->categories = 0;
@@ -1761,7 +1684,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			}
 		}
 
-		$post = new ForumTablePost($this->database);
+		$post = new ForumPost($this->database);
 		$view->lastpost = $post->getLastActivity($this->offering->get('id'), 'course');
 
 		//get authorization
@@ -1799,7 +1722,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$fields = array_map('trim', $fields);
 
 		// Instantiate a new table row and bind the incoming data
-		$model = new ForumTableSection($this->database);
+		$model = new ForumSection($this->database);
 		if (!$model->bind($fields))
 		{
 			$this->setRedirect(
@@ -1837,7 +1760,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$alias = JRequest::getVar('section', '');
 
 		// Load the section
-		$model = new ForumTableSection($this->database);
+		$model = new ForumSection($this->database);
 		$model->loadByAlias($alias, $this->offering->get('id'), 'course');
 
 		// Make the sure the section exist
@@ -1864,7 +1787,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 
 		// Get all the categories in this section
-		$cModel = new ForumTableCategory($this->database);
+		$cModel = new ForumCategory($this->database);
 		$categories = $cModel->getRecords(array(
 			'section_id' => $model->id,
 			'scope'      => 'course', 
@@ -1880,7 +1803,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			}
 
 			// Set all the threads/posts in all the categories to "deleted"
-			$tModel = new ForumTablePost($this->database);
+			$tModel = new ForumPost($this->database);
 			if (!$tModel->setStateByCategory($cats, 2))  // 0 = unpublished, 1 = published, 2 = deleted 
 			{
 				$this->setError($tModel->getError());
@@ -1952,11 +1875,11 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		//$view->filters['sticky'] = false;
 		$view->filters['sort_Dir'] = 'ASC';
 		
-		$view->section = new ForumTableSection($this->database);
+		$view->section = new ForumSection($this->database);
 		$view->section->loadByAlias($view->filters['section'], $this->offering->get('id'), 'course');
 		$view->filters['section_id'] = $view->section->id;
 
-		$view->category = new ForumTableCategory($this->database);
+		$view->category = new ForumCategory($this->database);
 		$view->category->loadByAlias($view->filters['category'], $view->section->id, $this->offering->get('id'), 'course');
 		$view->filters['category_id'] = $view->category->id;
 
@@ -1968,7 +1891,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 
 		// Initiate a forum object
-		$view->forum = new ForumTablePost($this->database);
+		$view->forum = new ForumPost($this->database);
 
 		// Get record count
 		$view->total = $view->forum->getCount($view->filters);
@@ -2034,7 +1957,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$this->view->filters['scope']    = 'course';
 		$this->view->filters['scope_id'] = $this->offering->get('id');
 
-		$this->view->section = new ForumTableSection($this->database);
+		$this->view->section = new ForumSection($this->database);
 		$this->view->section->title = JText::_('Posts');
 		$this->view->section->alias = str_replace(' ', '-', $this->view->section->title);
 		$this->view->section->alias = preg_replace("/[^a-zA-Z0-9\-]/", '', strtolower($this->view->section->title));
@@ -2052,7 +1975,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 		$this->view->sections = $s;
 
-		$this->view->category = new ForumTableCategory($this->database);
+		$this->view->category = new ForumCategory($this->database);
 		$this->view->category->title = JText::_('Search');
 		$this->view->category->alias = str_replace(' ', '-', $this->view->category->title);
 		$this->view->category->alias = preg_replace("/[^a-zA-Z0-9\-]/", '', strtolower($this->view->category->title));
@@ -2071,7 +1994,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$this->view->categories = $c;
 
 		// Initiate a forum object
-		$this->view->forum = new ForumTablePost($this->database);
+		$this->view->forum = new ForumPost($this->database);
 
 		// Get record count
 		$this->view->total = $this->view->forum->getCount($this->view->filters);
@@ -2143,7 +2066,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			return;
 		}
 
-		$sModel = new ForumTableSection($this->database);
+		$sModel = new ForumSection($this->database);
 		$sModel->loadByAlias($section, $this->offering->get('id'), 'course');
 
 		// Incoming
@@ -2153,7 +2076,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 		else 
 		{
-			$this->view->model = new ForumTableCategory($this->database);
+			$this->view->model = new ForumCategory($this->database);
 			$this->view->model->loadByAlias($category, $sModel->id, $this->offering->get('id'), 'course');
 		}
 
@@ -2182,7 +2105,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		{
 			$this->view->sections = array();
 
-			$default = new ForumTableSection($this->database);
+			$default = new ForumSection($this->database);
 			$default->id = 0;
 			$default->title = JText::_('Categories');
 			$default->alias = str_replace(' ', '-', $default->title);
@@ -2223,7 +2146,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$fields = JRequest::getVar('fields', array(), 'post');
 		$fields = array_map('trim', $fields);
 
-		$model = new ForumTableCategory($this->database);
+		$model = new ForumCategory($this->database);
 		if (!$model->bind($fields))
 		{
 			$this->addPluginMessage($model->getError(), 'error');
@@ -2284,11 +2207,11 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 		
 		$section = JRequest::getVar('section', '');
-		$sModel = new ForumTableSection($this->database);
+		$sModel = new ForumSection($this->database);
 		$sModel->loadByAlias($section, $this->offering->get('id'), 'course');
 
 		// Initiate a forum object
-		$model = new ForumTableCategory($this->database);
+		$model = new ForumCategory($this->database);
 		$model->loadByAlias($category, $sModel->id, $this->offering->get('id'), 'course');
 
 		// Check if user is authorized to delete entries
@@ -2304,7 +2227,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 
 		// Set all the threads/posts in all the categories to "deleted"
-		$tModel = new ForumTablePost($this->database);
+		$tModel = new ForumPost($this->database);
 		if (!$tModel->setStateByCategory($model->id, 2))  /* 0 = unpublished, 1 = published, 2 = deleted */
 		{
 			$this->setError($tModel->getError());
@@ -2368,11 +2291,11 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 
 		$thread   = JRequest::getInt('thread', 0);
 
-		$view->section = new ForumTableSection($this->database);
+		$view->section = new ForumSection($this->database);
 		$view->section->loadByAlias($view->filters['section'], $this->offering->get('id'), 'course');
 		$view->filters['section_id'] = $view->section->id;
 
-		$view->category = new ForumTableCategory($this->database);
+		$view->category = new ForumCategory($this->database);
 		$view->category->loadByAlias($view->filters['category'], $view->section->id, $this->offering->get('id'), 'course');
 		$view->filters['category_id'] = $view->category->id;
 
@@ -2383,7 +2306,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 
 		// Initiate a forum object
-		$view->post = new ForumTablePost($this->database);
+		$view->post = new ForumPost($this->database);
 
 		// Load the topic
 		$view->post->load($thread);
@@ -2461,12 +2384,12 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$view->participants = $view->post->getParticipants($view->filters);
 
 		// Get attachments
-		$view->attach = new ForumTableAttachment($this->database);
+		$view->attach = new ForumAttachment($this->database);
 		$view->attachments = $view->attach->getAttachments($view->post->id);
 		
 		// Get tags on this article
-		$view->tModel = new ForumModelTags($view->post->id);
-		$view->tags = $view->tModel->tags('cloud');
+		$view->tModel = new ForumTags($this->database);
+		$view->tags = $view->tModel->get_tag_cloud(0, 0, $view->post->id);
 
 		// Get authorization
 		$this->_authorize('category', $view->category->id);
@@ -2565,9 +2488,8 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 				'layout'  => 'edit'
 			)
 		);
-		$this->view->name = $this->_name;
 
-		$id = JRequest::getInt('post', 0);
+		$id = JRequest::getInt('thread', 0);
 		$category = JRequest::getVar('category', '');
 		$sectionAlias = JRequest::getVar('section', '');
 
@@ -2584,7 +2506,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			return;
 		}
 
-		$this->view->category = new ForumTableCategory($this->database);
+		$this->view->category = new ForumCategory($this->database);
 		$this->view->category->loadByAlias($category);
 
 		// Incoming
@@ -2594,7 +2516,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 		else 
 		{
-			$this->view->post = new ForumTablePost($this->database);
+			$this->view->post = new ForumPost($this->database);
 			$this->view->post->load($id);
 		}
 
@@ -2611,7 +2533,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			return;
 		}
 
-		$sModel = new ForumTableSection($this->database);
+		$sModel = new ForumSection($this->database);
 		$this->view->sections = $sModel->getRecords(array(
 			'state'    => 1, 
 			'scope'    => 'course',
@@ -2630,7 +2552,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			$this->view->sections[] = $default;
 		}
 
-		$cModel = new ForumTableCategory($this->database);
+		$cModel = new ForumCategory($this->database);
 		foreach ($this->view->sections as $key => $section)
 		{
 			$this->view->sections[$key]->categories = $cModel->getRecords(array(
@@ -2642,8 +2564,8 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 
 		// Get tags on this article
-		$this->view->tModel = new ForumModelTags($this->view->post->id);
-		$this->view->tags = $this->view->tModel->tags('string'); //$this->view->post->created_by
+		$this->view->tModel = new ForumTags($this->database);
+		$this->view->tags = $this->view->tModel->get_tag_string($this->view->post->id, 0, 0, $this->view->post->created_by);
 
 		$this->view->option = $this->option;
 		$this->view->config = $this->params;
@@ -2703,12 +2625,12 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 
 		if ($fields['id'])
 		{
-			$old = new ForumTablePost($this->database);
+			$old = new ForumPost($this->database);
 			$old->load(intval($fields['id']));
 		}
 
 		// Bind data
-		$model = new ForumTablePost($this->database);
+		$model = new ForumPost($this->database);
 		if (!$model->bind($fields)) 
 		{
 			$this->addPluginMessage($model->getError(), 'error');
@@ -2728,7 +2650,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 
 		// Load the category
-		$category = new ForumTableCategory($this->database);
+		$category = new ForumCategory($this->database);
 		$category->load(intval($model->category_id));
 		if (!$model->object_id && $category->object_id)
 		{
@@ -2772,8 +2694,8 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 
 		// Save tags
 		$tags = JRequest::getVar('tags', '', 'post');
-		$tagger = new ForumModelTags($model->id);
-		$tagger->setTags($tags, $this->juser->get('id'), 1);
+		$tagger = new ForumTags($this->database);
+		$tagger->tag_object($this->juser->get('id'), $model->id, $tags, 1);
 
 		// Being called through AJAX?
 		if ($no_html)
@@ -2845,7 +2767,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$id = ($id) ? $id : JRequest::getInt('thread', 0);
 
 		// Initiate a forum object
-		$model = new ForumTablePost($this->database);
+		$model = new ForumPost($this->database);
 		$model->load($id);
 
 		// Make the sure the category exist
@@ -2945,7 +2867,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path)) 
+			if (!JFolder::create($path, 0777)) 
 			{
 				$this->setError(JText::_('PLG_COURSES_DISCUSSIONS_UNABLE_TO_CREATE_UPLOAD_PATH'));
 				return;
@@ -2968,7 +2890,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		{
 			// File was uploaded
 			// Create database entry
-			$row = new ForumTableAttachment($this->database);
+			$row = new ForumAttachment($this->database);
 			$row->bind(array(
 				'id'          => 0,
 				'parent'      => $listdir,
@@ -3019,7 +2941,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		}
 
 		// Instantiate an attachment object
-		$attach = new ForumTableAttachment($this->database);
+		$attach = new ForumAttachment($this->database);
 		if (!$post)
 		{
 			$attach->loadByThread($thread, $file);
@@ -3037,7 +2959,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 		$file = $attach->filename;
 
 		// Get the parent ticket the file is attached to
-		$this->model = new ForumTablePost($this->database);
+		$this->model = new ForumPost($this->database);
 		$this->model->load($attach->post_id);
 
 		if (!$this->model->id) 
@@ -3180,7 +3102,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 
 		//$inc = ($this->_task == 'orderup' ? -1 : 1);
 
-		$row = new ForumTableSection($this->database);
+		$row = new ForumSection($this->database);
 		//$row->load($id);
 		if ($row->loadByAlias($alias, $this->offering->get('id'), 'course'))
 		{
@@ -3201,11 +3123,6 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 	 */
 	public function onCourseDelete($course)
 	{
-		if (!$course->exists())
-		{
-			return '';
-		}
-
 		$log = JText::_('PLG_COURSES_FORUM') . ': ';
 
 		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'post.php');
@@ -3215,23 +3132,11 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 
 		$this->database = JFactory::getDBO();
 
-		$sModel = new ForumTableSection($this->database);
-		$sections = array();
-		foreach ($course->offerings() as $offering)
-		{
-			if (!$offering->exists())
-			{
-				continue;
-			}
-			$sec = $sModel->getRecords(array(
-				'scope'    => 'course',
-				'scope_id' => $offering->get('id')
-			));
-			foreach ($sec as $s)
-			{
-				$sections[] = $s;
-			}
-		}
+		$sModel = new ForumSection($this->database);
+		$sections = $sModel->getRecords(array(
+			'scope'    => 'course',
+			'scope_id' => $course->offering()->get('id')
+		));
 
 		// Do we have any IDs?
 		if (count($sections) > 0) 
@@ -3240,7 +3145,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 			foreach ($sections as $section) 
 			{
 				// Get the categories in this section
-				$cModel = new ForumTableCategory($this->database);
+				$cModel = new ForumCategory($this->database);
 				$categories = $cModel->getRecords(array(
 					'section_id' => $section->id,
 					'scope'      => 'course',
@@ -3257,7 +3162,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 					}
 
 					// Set all the threads/posts in all the categories to "deleted"
-					$tModel = new ForumTablePost($this->database);
+					$tModel = new ForumPost($this->database);
 					if (!$tModel->setStateByCategory($cats, 2))  /* 0 = unpublished, 1 = published, 2 = deleted */
 					{
 						$this->setError($tModel->getError());
@@ -3265,7 +3170,7 @@ class plgCoursesDiscussions extends Hubzero_Plugin
 					$log .= 'forum.section.' . $section->id . '.category.' . $category->id . '.post' . "\n";
 
 					// Set all the categories to "deleted"
-					if (!$cModel->setStateBySection($section->id, 2))  /* 0 = unpublished, 1 = published, 2 = deleted */
+					if (!$cModel->setStateBySection($model->id, 2))  /* 0 = unpublished, 1 = published, 2 = deleted */
 					{
 						$this->setError($cModel->getError());
 					}
