@@ -31,9 +31,61 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+$dateFormat = '%d %b %Y';
+$timeFormat = '%I:%M %p';
+$tz = 0;
+if (version_compare(JVERSION, '1.6', 'ge'))
+{
+	$dateFormat = 'd M Y';
+	$timeFormat = 'H:i p';
+	$tz = true;
+}
+
 $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=courses';
+
+//section links
+/*$sections = array(
+	array(
+		'name'  => 'enrolled',
+		'title' => JText::_('PLG_MEMBERS_COURSES_ENROLLED'),
+		'link'  => JRoute::_('index.php?option='.$this->option.'&id='.$this->member->get('uidNumber').'&active=courses&task=enrolled&limit=' . $this->filters['limit'] . '&limitstart=0')
+	),
+	array(
+		'name'  => 'manager',
+		'title' => JText::_('PLG_MEMBERS_COURSES_MANAGER'),
+		'link'  => JRoute::_('index.php?option='.$this->option.'&id='.$this->member->get('uidNumber').'&active=courses&task=manager&limit=' . $this->filters['limit'] . '&limitstart=0')
+	),
+	array(
+		'name'  => 'instructor',
+		'title' => JText::_('PLG_MEMBERS_COURSES_INSTRUCTOR'),
+		'link'  => JRoute::_('index.php?option='.$this->option.'&id='.$this->member->get('uidNumber').'&active=courses&task=instructor&limit=' . $this->filters['limit'] . '&limitstart=0')
+	),
+	array(
+		'name'  => 'ta',
+		'title' => JText::_('PLG_MEMBERS_COURSES_TA'),
+		'link'  => JRoute::_('index.php?option='.$this->option.'&id='.$this->member->get('uidNumber').'&active=courses&task=ta&limit=' . $this->filters['limit'] . '&limitstart=0')
+	)
+);
+$active = null;
+
+$has = 0;
+if ($this->roles)
+{
+	foreach ($this->roles as $role)
+	{
+		if ($role->total > 0)
+		{
+			$has++;
+		}
+		if ($this->filters['task'] == $role->alias)
+		{
+			$active = $role;
+		}
+	}
+}*/
 ?>
 <h3 class="section-header">
+	<a name="courses"></a>
 	<?php echo JText::_('PLG_MEMBERS_COURSES'); ?>
 </h3>
 
@@ -42,6 +94,14 @@ $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNu
 
 <?php if ($this->roles && $this->hasRoles > 1) { ?>
 	<ul class="entries-menu user-options">
+		<?php /*foreach ($sections as $s) { ?>
+			<?php $sel = ($this->filters['task'] == $s['name']) ? 'active' : ''; ?>
+			<li>
+				<a class="<?php echo $s['name'] . ' ' . $sel; ?>" title="<?php echo $this->escape($s['title']); ?>" href="<?php echo $s['link']; ?>">
+					<?php echo $this->escape($s['title']); ?>
+				</a>
+			</li>
+		<?php }*/ ?>
 		<?php foreach ($this->roles as $s) { ?>
 			<?php 
 			if ($s->total <= 0)
@@ -56,7 +116,7 @@ $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNu
 			}
 			?>
 			<li>
-				<a class="<?php echo $s->alias . ' ' . $sel; ?>" title="<?php echo $this->escape(stripslashes($s->title)); ?>" href="<?php echo JRoute::_($base . '&task=' . $s->alias . '&sort=' . $this->filters['sort']); ?>">
+				<a class="<?php echo $s->alias . ' ' . $sel; ?>" title="<?php echo $this->escape(stripslashes($s->title)); ?>" href="<?php echo JRoute::_($base . '&task=' . $s->alias . '&sort=title'); ?>">
 					<?php echo $this->escape(stripslashes($s->title)); ?> (<?php echo $this->escape($s->total); ?>)
 				</a>
 			</li>
@@ -69,13 +129,13 @@ $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNu
 
 			<ul class="entries-menu order-options">
 				<li>
-					<a<?php echo ($this->filters['sort'] == 'title') ? ' class="active"' : ''; ?> href="<?php echo JRoute::_($base . '&task=' . urlencode($this->filters['task']) . '&sort=title'); ?>" title="<?php echo JText::_('PLG_MEMBERS_COURSES_SORT_BY_TITLE'); ?>">
-						<?php echo JText::_('PLG_MEMBERS_COURSES_SORT_TITLE'); ?>
+					<a<?php echo ($this->filters['sort'] == 'title') ? ' class="active"' : ''; ?> href="<?php echo JRoute::_($base . '&task=' . urlencode($this->filters['task']) . '&sort=title'); ?>" title="<?php echo JText::_('PLG_MEMBERS_COURSES_SORT_TITLE'); ?>">
+						&darr; <?php echo JText::_('PLG_MEMBERS_COURSES_TITLE'); ?>
 					</a>
 				</li>
 				<li>
-					<a<?php echo ($this->filters['sort'] == 'enrolled') ? ' class="active"' : ''; ?> href="<?php echo JRoute::_($base . '&task=' . urlencode($this->filters['task']) . '&sort=enrolled'); ?>" title="<?php echo JText::_('PLG_MEMBERS_COURSES_SORT_BY_ENROLLED'); ?>">
-						<?php echo JText::_('PLG_MEMBERS_COURSES_SORT_ENROLLED'); ?>
+					<a<?php echo ($this->filters['sort'] == 'enrolled') ? ' class="active"' : ''; ?> href="<?php echo JRoute::_($base . '&task=' . urlencode($this->filters['task']) . '&sort=enrolled'); ?>" title="<?php echo JText::_('PLG_MEMBERS_COURSES_SORT_ENROLLED'); ?>">
+						&darr; <?php echo JText::_('PLG_MEMBERS_COURSES_ENROLLED'); ?>
 					</a>
 				</li>
 			</ul>
@@ -132,17 +192,8 @@ $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNu
 							</a><br />
 							<span class="entry-details">
 								<?php echo $dateText; ?> 
-								<!-- 
-								<span class="entry-date-at"><?php echo JText::_('PLG_MEMBERS_COURSES_AT'); ?></span> 
-								<span class="entry-time"><time datetime="<?php echo $row->enrolled; ?>"><?php echo JHTML::_('date', $row->enrolled, JText::_('TIME_FORMAT_HZ1')); ?></time></span> 
-								-->
-								<span class="entry-date-on"><?php echo JText::_('PLG_MEMBERS_COURSES_ON'); ?></span> 
-								<span class="entry-date"><time datetime="<?php echo $row->enrolled; ?>"><?php echo JHTML::_('date', $row->enrolled, JText::_('DATE_FORMAT_HZ1')); ?></time></span>
-								<?php if ($row->section_title) { ?>
-								<span class="entry-section">
-									 &mdash; <strong><?php echo JText::_('PLG_MEMBERS_COURSES_SECTION'); ?></strong> <?php echo $this->escape(stripslashes($row->section_title)); ?>
-								</span>
-								<?php } ?>
+								<span class="entry-date-at">@</span> <span class="entry-time"><time datetime="<?php echo $row->enrolled; ?>"><?php echo JHTML::_('date', $row->enrolled, $timeFormat, $tz); ?></time></span> 
+								<span class="entry-date-on">on</span> <span class="entry-date"><time datetime="<?php echo $row->enrolled; ?>"><?php echo JHTML::_('date', $row->enrolled, $dateFormat, $tz); ?></time></span>
 							</span>
 						</td>
 						<td>
@@ -157,12 +208,10 @@ $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNu
 							<?php echo JText::_('PLG_MEMBERS_COURSES_STARTS'); ?><br />
 							<span class="entry-details">
 							<?php if ($row->starts != '0000-00-00 00:00:00') { ?>
-								<span class="entry-date-at"><?php echo JText::_('PLG_MEMBERS_COURSES_AT'); ?></span> 
-								<span class="entry-time"><time datetime="<?php echo $row->starts; ?>"><?php echo JHTML::_('date', $row->starts, JText::_('TIME_FORMAT_HZ1')); ?></time></span> 
-								<span class="entry-date-on"><?php echo JText::_('PLG_MEMBERS_COURSES_ON'); ?></span> 
-								<span class="entry-date"><time datetime="<?php echo $row->starts; ?>"><?php echo JHTML::_('date', $row->starts, JText::_('DATE_FORMAT_HZ1')); ?></time></span>
+								<span class="entry-date-at">@</span> <span class="entry-time"><time datetime="<?php echo $row->starts; ?>"><?php echo JHTML::_('date', $row->starts, $timeFormat, $tz); ?></time></span> 
+								<span class="entry-date-on">on</span> <span class="entry-date"><time datetime="<?php echo $row->starts; ?>"><?php echo JHTML::_('date', $row->starts, $dateFormat, $tz); ?></time></span>
 							<?php } else { ?>
-								<?php echo JText::_('PLG_MEMBERS_COURSES_NA'); ?>
+								<?php echo JText::_('n/a'); ?>
 							<?php } ?>
 							</span>
 							<?php } ?>
@@ -172,12 +221,10 @@ $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNu
 							<?php echo JText::_('PLG_MEMBERS_COURSES_ENDS'); ?><br />
 							<span class="entry-details">
 								<?php if ($row->ends != '0000-00-00 00:00:00') { ?>
-								<span class="entry-date-at"><?php echo JText::_('PLG_MEMBERS_COURSES_AT'); ?></span> 
-								<span class="entry-time"><time datetime="<?php echo $row->ends; ?>"><?php echo JHTML::_('date', $row->ends, JText::_('TIME_FORMAT_HZ1')); ?></time></span> 
-								<span class="entry-date-on"><?php echo JText::_('PLG_MEMBERS_COURSES_ON'); ?></span> 
-								<span class="entry-date"><time datetime="<?php echo $row->ends; ?>"><?php echo JHTML::_('date', $row->ends, JText::_('DATE_FORMAT_HZ1')); ?></time></span>
+								<span class="entry-date-at">@</span> <span class="entry-time"><time datetime="<?php echo $row->ends; ?>"><?php echo JHTML::_('date', $row->ends, $timeFormat, $tz); ?></time></span> 
+								<span class="entry-date-on">on</span> <span class="entry-date"><time datetime="<?php echo $row->ends; ?>"><?php echo JHTML::_('date', $row->ends, $dateFormat, $tz); ?></time></span>
 								<?php } else { ?>
-									<?php echo JText::_('PLG_MEMBERS_COURSES_NA'); ?>
+									<?php echo JText::_('n/a'); ?>
 								<?php } ?>
 							</span>
 							<?php } ?>
@@ -201,7 +248,6 @@ $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNu
 			$this->pageNav->setAdditionalUrlParam('active', 'courses');
 			$this->pageNav->setAdditionalUrlParam('task', $this->filters['task']);
 			$this->pageNav->setAdditionalUrlParam('action', '');
-			$this->pageNav->setAdditionalUrlParam('sort', $this->filters['sort']);
 			
 			echo $this->pageNav->getListFooter();
 			?>
@@ -212,14 +258,14 @@ $base = 'index.php?option=' . $this->option . '&id=' . $this->member->get('uidNu
 	<div id="courses-introduction">
 		<div class="instructions">
 			<ol>
-				<li><?php echo JText::sprintf('PLG_MEMBERS_COURSES_FIND_COURSE', JRoute::_('index.php?option=com_courses')); ?></li>
-				<li><?php echo JText::_('PLG_MEMBERS_COURSES_ENROLL'); ?></li>
-				<li><?php echo JText::_('PLG_MEMBERS_COURSES_GET_LEARNING'); ?></li>
+				<li><?php echo JText::sprintf('Find a <a href="%s">course</a> that looks interesting.', JRoute::_('index.php?option=com_courses')); ?></li>
+				<li><?php echo JText::_('Enroll.'); ?></li>
+				<li><?php echo JText::_('Get learning!'); ?></li>
 			</ol>
 		</div><!-- / .instructions -->
 		<div class="questions">
-			<p><strong><?php echo JText::_('PLG_MEMBERS_COURSES_WHAT_ARE_COURSES'); ?></strong></p>
-			<p><?php echo JText::_('PLG_MEMBERS_COURSES_EXPLANATION'); ?><p>
+			<p><strong>What are courses?</strong></p>
+			<p>This is how you can add other content on the site to a collection. You can collect wiki pages, resources, and more. You can even collect other collections!<p>
 		</div><!-- / .post-type -->
 	</div><!-- / #collection-introduction -->
 <?php } ?>
