@@ -256,10 +256,6 @@ class plgMembersDashboard extends Hubzero_Plugin
 		$this->view->columns = array();
 		for ($c = 0; $c < $cols; $c++)
 		{
-			if (!isset($mymods[$c]))
-			{
-				$mymods[$c] = array();
-			}
 			$this->view->columns[$c] = $this->output_modules($mymods[$c], $this->member->get('uidNumber'), $this->_act);
 		}
 	}
@@ -370,7 +366,7 @@ class plgMembersDashboard extends Hubzero_Plugin
 				$view->rendered = $rendered;
 				$view->juser = $this->juser;
 
-				$app = JFactory::getApplication();
+				$app =& JFactory::getApplication();
 				$view->admin = $app->isAdmin();
 
 				$html .= $view->loadTemplate();
@@ -433,7 +429,7 @@ class plgMembersDashboard extends Hubzero_Plugin
 	 */
 	protected function save($rtrn=0)
 	{
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		if ($app->isAdmin())
 		{
 			return $this->saveTask($rtrn);
@@ -465,7 +461,7 @@ class plgMembersDashboard extends Hubzero_Plugin
 		$myhub = new MyhubPrefs($this->database);
 		$myhub->load($uid);
 		$myhub->prefs = $ids;
-		$myhub->modified = JFactory::getDate()->toSql();
+		$myhub->modified = date("Y-m-d H:i:s");
 		if (!$myhub->check()) 
 		{
 			$this->setError($myhub->getError());
@@ -553,7 +549,7 @@ class plgMembersDashboard extends Hubzero_Plugin
 			)
 		);
 		
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		
 		// Incoming
 		$mid = JRequest::getInt('mid', 0);
@@ -655,7 +651,7 @@ class plgMembersDashboard extends Hubzero_Plugin
 		if (in_array($mid, $mods))
 		{
 			// This module already exists
-			$app = JFactory::getApplication();
+			$app =& JFactory::getApplication();
 			if (!$app->isAdmin())
 			{
 				return 'ERROR';
@@ -789,7 +785,7 @@ class plgMembersDashboard extends Hubzero_Plugin
 		$myhub = new MyhubPrefs($this->database);
 		$myhub->load($this->member->get('uidNumber'));
 		$myhub->prefs = rtrim(str_replace(",;", ";", $prefs), ";");
-		$myhub->modified = JFactory::getDate()->toSql();
+		$myhub->modified = date("Y-m-d H:i:s");
 		if (!$myhub->check()) 
 		{
 			$this->setError($myhub->getError());
@@ -861,14 +857,10 @@ class plgMembersDashboard extends Hubzero_Plugin
 		$this->view->task = $this->task;
 		$this->view->juser = $this->juser;
 
-		$base = str_replace('/administrator', '', rtrim(JURI::getInstance()->base(true), '/'));
-
-		$document = JFactory::getDocument();
-		$document->addStylesheet($base . DS . 'plugins' . DS . 'members' . DS . 'dashboard' . DS . 'dashboard.css');
-		//$document->addScript($base . DS . 'plugins' . DS . 'members' . DS . 'dashboard' . DS . 'xsortables.js');
-		//$document->addScript($base . DS . 'media/system/js/jquery.js');
-		//$document->addScript($base . DS . 'media/system/js/jquery.noconflict.js');
-		//$document->addScript($base . DS . 'plugins' . DS . 'members' . DS . 'dashboard' . DS . 'dashboard.admin.js');
+		$document =& JFactory::getDocument();
+		$document->addStylesheet(DS . 'plugins' . DS . 'members' . DS . 'dashboard' . DS . 'dashboard.css');
+		$document->addScript(DS . 'plugins' . DS . 'members' . DS . 'dashboard' . DS . 'xsortables.js');
+		$document->addScript(DS . 'plugins' . DS . 'members' . DS . 'dashboard' . DS . 'dashboard.admin.js');
 
 		// Select user's list of modules from database
 		$myhub = new MyhubPrefs($this->database);
@@ -933,9 +925,7 @@ class plgMembersDashboard extends Hubzero_Plugin
 		{
 			$this->view->setError($this->getError());
 		}
-		
-		$this->view->messages = ($this->getPluginMessage()) ? $this->getPluginMessage() : array();
-		
+
 		return $this->view->loadTemplate();
 	}
 
@@ -1039,7 +1029,7 @@ class plgMembersDashboard extends Hubzero_Plugin
 
 		// Redirect
 		$this->setRedirect(
-			'index.php?option=com_members&controller=plugins&task=manage&plugin=dashboard',
+			'index.php?option=com_members&controller=plugins' . $this->_controller . '&task=manage&plugin=dashboard',
 			JText::_('Module successfully pushed')
 		);
 		return;
@@ -1101,7 +1091,7 @@ class plgMembersDashboard extends Hubzero_Plugin
 	{
 		// Redirect
 		$this->setRedirect(
-			'index.php?option=com_members&controller=plugins&task=manage&plugin=dashboard'
+			'index.php?option=com_members&controller=plugins' . $this->_controller . '&task=manage&plugin=dashboard'
 		);
 		return;
 	}
