@@ -85,7 +85,7 @@ $show_gallery 	= ($this->pubconfig->get('show_gallery', 0)) ? 1 : 0;
 $show_notes 	= ($this->pubconfig->get('show_notes', 0)) ? 1 : 0;
 $show_license 	= ($this->pubconfig->get('show_license', 0)) ? 1 : 0;
 
-$jconfig = JFactory::getConfig();
+$jconfig =& JFactory::getConfig();
 $sitename = $jconfig->getValue('config.sitename');
 
 // Get access info
@@ -166,7 +166,7 @@ $append .= '</span>';
 					: JText::_('PLG_PROJECTS_PUBLICATIONS_PUB_REVIEW_APPROVAL_NEEDED'); ?>
 			</li>
 			<?php } ?>
-			<?php if(!$this->row->doi && !$republish && !$post && $doi_txt && $this->pubconfig->get('doi_service')) { ?>
+			<?php if(!$this->row->doi && !$republish && !$post && $doi_txt) { ?>
 			<li><?php echo $doi_txt; ?></li>
 			<?php } ?>
 			<li>
@@ -186,38 +186,17 @@ $append .= '</span>';
 				 } ?>
 			</li>
 		</ul>
-		<p class="ipadded">
+		<p>
 			<input class="option" name="agree" type="radio" value="1" />
 			<?php echo JText::_('PLG_PROJECTS_PUBLICATIONS_PUB_REVIEW_AGREE_TO') . ' <a href="' 
 			. $this->pubconfig->get('deposit_terms', 'https://localhost:5000/legal/termsofdeposit?no_html=1'). '" class="popup">' 
 			. $sitename . ' ' . JText::_('PLG_PROJECTS_PUBLICATIONS_PUB_REVIEW_TERMS_OF_DEPOSIT') . '</a>.'; ?>
 		</p>
 		<?php if ($this->task == 'publish') { ?>
-			
 		<p class="pubdate">
-			<?php if (isset($this->submitter)) { 
-				// Do we have a submitter choice?
-				$submitter = $this->submitter->name;
-				$submitter.= $this->submitter->organization ? ', ' . $this->submitter->organization : '';
-				$submitter.= '<input type="hidden" name="submitter" value="' . $this->submitter->uid. '" />';
-				if ($this->submitter->uid != $this->uid)
-				{
-					$submitter  = '<select name="submitter">' . "\n";
-					$submitter .= '<option value="' . $this->uid . '" selected="selected">' . $this->juser->get('name') 
-						. '</option>' . "\n";
-					$submitter .= '<option value="' . $this->submitter->uid . '">' . $this->submitter->name . '</option>' . "\n";
-					$submitter .= '</select>';
-				}
-				
-			?>
-			<label class="block">
-				<span class="review-label"><?php echo ucfirst(JText::_('PLG_PROJECTS_PUBLICATIONS_SUBMITTER')); ?>:</span> <?php echo $submitter; ?>
-			</label>
-			<?php } ?>
-			<label>
-				<span class="review-label"><?php echo JText::_('PLG_PROJECTS_PUBLICATIONS_PUB_PUBLISH_WHEN'); ?>*:</span>
+			<label>	<?php echo JText::_('PLG_PROJECTS_PUBLICATIONS_PUB_PUBLISH_WHEN'); ?>*:
 				<input type="text" id="publish_date" name="publish_date" value="<?php echo $this->pubdate; ?>" placeholder="<?php echo JText::_('PLG_PROJECTS_PUBLICATIONS_IMMEDIATE'); ?>" />
-				<span class="hint block"><?php echo JText::_('PLG_PROJECTS_PUBLICATIONS_HINT_EMBARGO'); ?></span>				
+				<span class="hint block"><?php echo JText::_('PLG_PROJECTS_PUBLICATIONS_HINT_EMBARGO'); ?></span>
 			</label>
 		</p>
 		<?php } ?>
@@ -245,20 +224,39 @@ else if ($this->authorized == 3)
 	<div class="pub-review-content">
 		<?php
 		
-		if ($this->authorized != 3) 
-		{
-			// Draw status bar
-			PublicationContribHelper::drawStatusBar($this, NULL, false, 1);	
+		if ($this->authorized != 3) {
+			$view = new Hubzero_Plugin_View(
+				array(
+					'folder'=>'projects',
+					'element'=>'publications',
+					'name'=>'edit',
+					'layout'=>'statusbar'
+				)
+			);
+			$view->row = $this->row;
+			$view->version = $this->version;
+			$view->panels = $this->panels;
+			$view->active = '';
+			$view->move = 0;
+			$view->hide_version = 1;
+			$view->lastpane = $this->lastpane;
+			$view->option = $this->option;
+			$view->project = $this->project;
+			$view->current_idx = $this->current_idx;
+			$view->last_idx = $this->last_idx;
+			$view->checked = $this->checked;
+			$view->url = $this->url;
+			$view->review = 1;
+			$view->display();	
 		}
 		
 		$description = '';
-		if ($this->pub->description) 
-		{
+		if($this->pub->description) {
 			$description = $this->parser->parse( stripslashes($this->pub->description), $this->wikiconfig );
 		}
 		
 		// Process metadata
-		$metadata = PublicationsHtml::processMetadata($this->pub->metadata, $this->_category, $this->parser, $this->wikiconfig, 0);
+		$metadata = PublicationsHtml::processMetadata($this->pub->metadata, $this->_category, 0, $this->pub->id, $this->option, $this->parser, $this->wikiconfig);
 	
 		?>
 		<div class="two columns first">
@@ -330,26 +328,29 @@ else if ($this->authorized == 3)
 			?>
 			<div class="three columns first second">
 				<ul class="c-list">
-					<li>
 				<?php	foreach($this->primary as $att) {
-					
-						// Draw item
-						$itemHtml = $this->_typeHelper->dispatchByType($att->type, 'drawItem', 
-						$data = array(
-								'att' 		=> $att, 
-								'item'		=> NULL,
-								'canedit' 	=> 0, 
-								'pid' 		=> $this->pub->id,
-								'vid'		=> $this->row->id,
-								'url'		=> $this->url,
-								'option'	=> $this->option,
-								'move'		=> 0,
-								'role'		=> 1,
-								'path'		=> $this->prefix . $this->fpath
-						));
-						echo $itemHtml;			
-				 } ?>
-					</li>
+						if ($att->type == 'file') {
+							$fpath = $this->version == 'dev' ? $att->path : $att->path;
+							$file = str_replace($this->fpath.DS, '', $fpath);
+							$ext = explode('.',$file);
+							$ext = end($ext);
+							$ext = strtolower($ext); 
+							$revision = '';
+							$revision = $this->projectsHelper->showGitInfo($gitpath, $this->project_path, $att->vcs_hash, $att->path);	
+						}					
+				?>
+						<?php if ($att->type == 'file') { ?>
+						<li><img src="<?php echo ProjectsHtml::getFileIcon($ext); ?>" alt="<?php echo $ext; ?>" /><?php echo $file; echo $att->title && $att->title != $fpath ? ' - "<span class="italic">'.$att->title.'</span>"' : ''; ?><?php if($revision) { ?><span class="c-iteminfo"><?php echo $revision; ?></span><?php } ?></li>
+						<?php } elseif ($att->type == 'data') { ?>
+						<li><span class="databases"><?php echo $att->title; ?>
+							[<a href="<?php echo $att->path; ?>" rel="external"><?php echo JText::_('view'); ?></a>]</span>
+						</li>
+						<?php } 
+						elseif ($att->type == 'note') { ?>
+						<li><span class="notes"><?php echo $att->title; ?></span>
+						</li>
+						<?php } ?>
+				<?php } ?>
 				</ul>	
 			</div>
 			<div class="three columns third summary">
@@ -364,26 +365,23 @@ else if ($this->authorized == 3)
 			<?php } ?>
 			<?php } ?>
 			<p class="pub-review-label"><?php echo JText::_('PLG_PROJECTS_PUBLICATIONS_SUPPORTING_DOCS'); ?></p>
-				<?php if(count($this->secondary) > 0) { ?>
+				<?php if(count($this->secondary) > 0) { 
+					$gitpath = $this->config->get('gitpath', '/opt/local/bin/git');
+				?>
 				<ul class="c-list">
-					<li>
 				<?php	foreach($this->secondary as $att) {
-					// Draw item
-					$itemHtml = $this->_typeHelper->dispatchByType($att->type, 'drawItem', 
-					$data = array(
-							'att' 		=> $att, 
-							'item'		=> NULL,
-							'canedit' 	=> 0, 
-							'pid' 		=> $this->pub->id,
-							'vid'		=> $this->row->id,
-							'url'		=> $this->url,
-							'option'	=> $this->option,
-							'move'		=> 0,
-							'role'		=> 0,
-							'path'		=> $this->prefix . $this->fpath
-					));
-					echo $itemHtml;
-				 } ?>
+					if ($att->type == 'file') {
+						$fpath = $this->version == 'dev' ? $att->path : $att->path;
+						$file = str_replace($this->fpath.DS, '', $fpath);
+						$ext = explode('.',$file);
+						$ext = end($ext);
+						$ext = strtolower($ext); 
+						$revision = '';
+						$revision = $this->projectsHelper->showGitInfo($gitpath, $this->project_path, $att->vcs_hash, $att->path);	
+					}
+				?>
+						<li><img src="<?php echo ProjectsHtml::getFileIcon($ext); ?>" alt="<?php echo $ext; ?>" /><?php echo $file; echo $att->title && $att->title != $fpath ? ' - "<span class="italic">'.$att->title.'</span>"' : ''; ?><?php if($revision) { ?><span class="c-iteminfo"><?php echo $revision; ?></span><?php } ?></li>	
+				<?php } ?>
 				</ul>	
 				<?php if($this->version == 'dev') { ?>
 					<p class="footnote">*<?php echo JText::_('PLG_PROJECTS_PUBLICATIONS_CONTENT_UPDATED_NOTICE'); ?></p>
