@@ -82,7 +82,7 @@ class plgProjectsTodo extends JPlugin
 	 */
 	public function &onProjectCount( $project, &$counts, $admin = 0 ) 
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 				
 		$objTD = new ProjectTodo( $database );
 		$counts['todo'] = $objTD->getTodos($project->id, $filters = array('count' => 1));
@@ -155,17 +155,17 @@ class plgProjectsTodo extends JPlugin
 			// Load language file
 			$this->loadLanguage();
 			
-			$database = JFactory::getDBO();
+			$database =& JFactory::getDBO();
 			
 			// Load component configs
-			$this->_config = JComponentHelper::getParams( 'com_projects' );
+			$this->_config =& JComponentHelper::getParams( 'com_projects' );
 			
 			// Enable views
 			ximport('Hubzero_View_Helper_Html');
 			ximport('Hubzero_Plugin_View');
 			
 			// Get JS and css
-			$document = JFactory::getDocument();
+			$document =& JFactory::getDocument();
 			$document->addStylesheet('components' . DS . 'com_projects' . DS . 'assets' . DS . 'css' . DS . 'calendar.css');
 						
 			Hubzero_Document::addPluginScript('projects', 'todo');
@@ -193,7 +193,7 @@ class plgProjectsTodo extends JPlugin
 			$this->_uid = $uid;
 			if (!$this->_uid) 
 			{
-				$juser = JFactory::getUser();
+				$juser =& JFactory::getUser();
 				$this->_uid = $juser->get('id');
 			}
 			
@@ -377,8 +377,8 @@ class plgProjectsTodo extends JPlugin
 			);
 								
 			// Append breadcrumbs
-			$app = JFactory::getApplication();
-			$pathway = $app->getPathway();
+			$app =& JFactory::getApplication();
+			$pathway =& $app->getPathway();
 			$pathway->addItem(
 					stripslashes($objTD->content),
 					JRoute::_('index.php?option=' . $this->_option . a 
@@ -465,7 +465,7 @@ class plgProjectsTodo extends JPlugin
 		if (!$objTD->loadTodo($this->_project->id, $todoid)) 
 		{
 			$objTD->created_by 	= $this->_uid;
-			$objTD->created 	= JFactory::getDate()->toSql();
+			$objTD->created 	= date( 'Y-m-d H:i:s', time());
 			$objTD->projectid 	= $this->_project->id;
 			$assigned 			= $this->_uid; // assign to creator
 			$new 				= 1;
@@ -497,7 +497,6 @@ class plgProjectsTodo extends JPlugin
 			
 			// Get due date
 			$due = trim(JRequest::getVar('due', ''));
-
 			if ($due && $due!= 'mm/dd/yyyy') 
 			{
 				$date = explode('/', $due);
@@ -519,7 +518,7 @@ class plgProjectsTodo extends JPlugin
 						} 
 						if (checkdate($month, $day, $year)) 
 						{
-							$objTD->duedate = JFactory::getDate(mktime(0, 0, 0, $month, $day, $year))->toSql();
+							$objTD->duedate = date("Y-m-d H:i:s", mktime(0, 0, 0, $month, $day, $year));
 						}
 					}
 				}
@@ -584,7 +583,7 @@ class plgProjectsTodo extends JPlugin
 				$objTD->state = $state;
 				if ($state == 1) 
 				{
-					$objTD->closed = JFactory::getDate()->toSql();
+					$objTD->closed = date( 'Y-m-d H:i:s', time());
 					$objTD->closed_by = $this->_uid;
 				}
 				// Store content
@@ -606,7 +605,7 @@ class plgProjectsTodo extends JPlugin
 							JText::_('COM_PROJECTS_ACTIVITY_TODO_COMPLETED'), $objTD->id, 'to-do',
 							JRoute::_('index.php?option=' . $this->_option . a . 
 							'alias=' . $this->_project->alias . a . 'active=todo'. a .
-							'action=view') . '/?todoid=' . $objTD->id, 'todo', 1 );
+							'action=view') . '/?todoid=' . $objTD->id, 'todo', 0 );
 					}
 				}
 			}
@@ -621,7 +620,7 @@ class plgProjectsTodo extends JPlugin
 			{
 				$objTD 				= new ProjectTodo( $this->_database );
 				$objTD->created_by 	= $this->_uid;
-				$objTD->created 	= JFactory::getDate()->toSql();
+				$objTD->created 	= date( 'Y-m-d H:i:s', time());
 				$objTD->projectid 	= $this->_project->id;
 				$objTD->content 	= 'provisioned';
 				$objTD->state 		= 2; // inactive
@@ -925,7 +924,7 @@ class plgProjectsTodo extends JPlugin
 			$objC->parent_activity = $parent_activity;
 			$comment = Hubzero_View_Helper_Html::shortenText($comment, 250, 0);
 			$objC->comment = Hubzero_View_Helper_Html::purifyText($comment);
-			$objC->created = JFactory::getDate()->toSql();
+			$objC->created = date( 'Y-m-d H:i:s' );
 			$objC->created_by = $this->_uid;
 			if (!$objC->store()) 
 			{
