@@ -57,7 +57,7 @@ class plgPublicationsReviews extends Hubzero_Plugin
 		$this->loadLanguage();
 		
 		$this->infolink = '/kb/points/';
-		$upconfig = JComponentHelper::getParams( 'com_members' );
+		$upconfig =& JComponentHelper::getParams( 'com_userpoints' );
 		$this->banking = $upconfig->get('bankAccounts');
 	}
 	
@@ -133,14 +133,7 @@ class plgPublicationsReviews extends Hubzero_Plugin
 			if (!array_intersect( $areas, $this->onPublicationAreas( $publication ) ) 
 			&& !array_intersect( $areas, array_keys( $this->onPublicationAreas( $publication ) ) )) 
 			{
-				if ($publication->_category->_params->get('plg_reviews')) 
-				{
-					$rtrn == 'metadata';
-				}
-				else
-				{
-					return $arr;
-				}
+				$rtrn = 'metadata';
 			}
 		}
 		
@@ -162,7 +155,7 @@ class plgPublicationsReviews extends Hubzero_Plugin
 		$h->execute();
 
 		// Get reviews for this publication
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 		$r = new PublicationReview( $database );
 		$reviews = $r->getRatings( $publication->id );
 		
@@ -267,7 +260,7 @@ class plgPublicationsReviews extends Hubzero_Plugin
 	 */
 	public function getComments($item, $category, $level, $abuse=false)
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 		
 		$level++;
 
@@ -297,7 +290,7 @@ class plgPublicationsReviews extends Hubzero_Plugin
 	 */	
 	public function getAbuseReports($item, $category)
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		$ra = new ReportAbuse( $database );
 		return $ra->getCount( array('id'=>$item, 'category'=>$category) );
@@ -312,7 +305,7 @@ class plgPublicationsReviews extends Hubzero_Plugin
 	 */	
 	public function getMemberPhoto( $member, $anonymous = 0 )
 	{
-		$config = JComponentHelper::getParams( 'com_members' );
+		$config =& JComponentHelper::getParams( 'com_members' );
 		
 		if (!$anonymous && $member->get('picture')) 
 		{
@@ -392,7 +385,7 @@ class PlgPublicationsReviewsHelper extends JObject
 	{
 		if ($this->_redirect != NULL) 
 		{
-			$app = JFactory::getApplication();
+			$app =& JFactory::getApplication();
 			$app->redirect($this->_redirect, $this->_message, $this->_messageType);
 		}
 	}
@@ -411,7 +404,7 @@ class PlgPublicationsReviewsHelper extends JObject
 		
 		if ($action) {
 			// Check the user's logged-in status
-			$juser = JFactory::getUser();
+			$juser =& JFactory::getUser();
 			if ($juser->get('guest')) 
 			{
 				$this->loggedin = false;
@@ -439,7 +432,7 @@ class PlgPublicationsReviewsHelper extends JObject
 	 */	
 	private function savereply()
 	{	
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		
 		// Is the user logged in?
 		if ($juser->get('guest')) 
@@ -452,7 +445,7 @@ class PlgPublicationsReviewsHelper extends JObject
 		$id       = JRequest::getInt('referenceid', 0 );
 		$rid      = JRequest::getInt('rid', 0 );
 		$category = JRequest::getVar('category', '' );
-		$when     = JFactory::getDate()->toSql();
+		$when     = date( 'Y-m-d H:i:s');
 		
 		// Trim and addslashes all posted items
 		$_POST = array_map('trim',$_POST);
@@ -471,7 +464,7 @@ class PlgPublicationsReviewsHelper extends JObject
 			return;
 		}
 		
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 		ximport( 'Hubzero_Comment' );
 			
 		$row = new Hubzero_Comment( $database );
@@ -510,8 +503,8 @@ class PlgPublicationsReviewsHelper extends JObject
 	 */	
 	public function deletereply()
 	{
-		$database = JFactory::getDBO();
-		$publication = $this->publication;
+		$database =& JFactory::getDBO();
+		$publication =& $this->publication;
 		
 		// Incoming
 		$replyid = JRequest::getInt( 'refid', 0 );
@@ -552,8 +545,8 @@ class PlgPublicationsReviewsHelper extends JObject
 	 */	
 	public function rateitem()
 	{		
-		$database = JFactory::getDBO();
-		$juser = JFactory::getUser();
+		$database =& JFactory::getDBO();
+		$juser =& JFactory::getUser();
 				
 		$id   = JRequest::getInt( 'refid', 0 );
 		$ajax = JRequest::getInt( 'ajax', 0 );
@@ -596,7 +589,7 @@ class PlgPublicationsReviewsHelper extends JObject
 				$v->category = $cat;
 				$v->voter = $juser->get('id');
 				$v->ip = $ip;
-				$v->voted = JFactory::getDate()->toSql();
+				$v->voted = date( 'Y-m-d H:i:s', time() );
 				$v->helpful = $vote;
 
 				if (!$v->check()) 
@@ -642,14 +635,14 @@ class PlgPublicationsReviewsHelper extends JObject
 	public function editreview()
 	{
 		// Is the user logged in?
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError( JText::_('PLG_PUBLICATION_REVIEWS_LOGIN_NOTICE') );
 			return;
 		}
 		
-		$publication = $this->publication;
+		$publication =& $this->publication;
 		
 		// Do we have an ID?
 		if (!$publication->id) 
@@ -662,7 +655,7 @@ class PlgPublicationsReviewsHelper extends JObject
 		// Incoming
 		$myr = JRequest::getInt( 'myrating', 0 );
 
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 		
 		$review = new PublicationReview( $database );
 		$review->loadUserReview( $publication->id, $juser->get('id'), $publication->version_id  );
@@ -699,7 +692,7 @@ class PlgPublicationsReviewsHelper extends JObject
 	public function savereview()
 	{
 		// Is the user logged in?
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError( JText::_('PLG_PUBLICATION_REVIEWS_LOGIN_NOTICE') );
@@ -717,7 +710,7 @@ class PlgPublicationsReviewsHelper extends JObject
 			return;
 		}
 		
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 		
 		// Bind the form data to our object
 		$row = new PublicationReview( $database );
@@ -732,7 +725,7 @@ class PlgPublicationsReviewsHelper extends JObject
 		$row->comment   = Hubzero_View_Helper_Html::purifyText($row->comment);
 		$row->comment   = nl2br($row->comment);
 		$row->anonymous = ($row->anonymous == 1 || $row->anonymous == '1') ? $row->anonymous : 0;
-		$row->created   = ($row->created) ? $row->created : JFactory::getDate()->toSql();
+		$row->created   = ($row->created) ? $row->created : date( "Y-m-d H:i:s" );
 		$row->created_by = $juser->get('id');
 		
 		// Check for missing (required) fields
@@ -750,7 +743,7 @@ class PlgPublicationsReviewsHelper extends JObject
 		
 		// Calculate the new average rating for the parent publication
 		$pub = new Publication( $database );
-		$publication = $this->publication;
+		$publication =& $this->publication;
 		$pub->load($publication_id);
 		$pub->calculateRating();
 		$pub->updateRating();
@@ -771,13 +764,13 @@ class PlgPublicationsReviewsHelper extends JObject
 		$users = $pa->getAuthors($publication->version_id, 1, 1, true );
 		
 		// Get the HUB configuration
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 		
 		// Build the subject
 		$subject = $jconfig->getValue('config.sitename').' '.JText::_('PLG_PUBLICATION_REVIEWS_CONTRIBUTIONS');
 		
 		// Message
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		$eview = new Hubzero_Plugin_View(
 			array(
 				'folder'=>'publications',
@@ -798,7 +791,7 @@ class PlgPublicationsReviewsHelper extends JObject
 		
 		// Send message
 		JPluginHelper::importPlugin( 'xmessage' );
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 		if (!$dispatcher->trigger( 'onSendMessage', array( 
 				'publications_new_comment', 
 				$subject, 
@@ -820,8 +813,8 @@ class PlgPublicationsReviewsHelper extends JObject
 	 */	
 	public function deletereview()
 	{
-		$database = JFactory::getDBO();
-		$publication = $this->publication;
+		$database =& JFactory::getDBO();
+		$publication =& $this->publication;
 		
 		// Incoming
 		$reviewid = JRequest::getInt( 'reviewid', 0 );
@@ -876,7 +869,7 @@ class PlgPublicationsReviewsHelper extends JObject
 
 		// Recalculate the average rating for the parent publication
 		$pub = new Publication( $database );
-		$publication = $this->publication;
+		$publication =& $this->publication;
 		$pub->load($publication->id);
 		$pub->calculateRating();
 		$pub->updateRating();
