@@ -1,12 +1,12 @@
 <?php
 defined('_JEXEC') or die('Restricted access');
 
-$config = JFactory::getConfig();
-$juser  = JFactory::getUser();
+$config =& JFactory::getConfig();
+$juser  =& JFactory::getUser();
 
 $this->template = 'hubbasic2013';
 
-$lang = JFactory::getLanguage();
+$lang =& JFactory::getLanguage();
 $lang->load('tpl_' . $this->template);
 
 $browser = new Hubzero_Browser();
@@ -20,8 +20,6 @@ $v = $browser->getBrowserMajorVersion();
 <!--[if IE 9 ]>    <html dir="<?php echo  $this->direction; ?>" lang="<?php echo  $this->language; ?>" class="ie9"> <![endif]-->
 <!--[if (gt IE 9)|!(IE)]><!--> <html dir="<?php echo $this->direction; ?>" lang="<?php echo  $this->language; ?>" class="<?php echo $b . ' ' . $b . $v; ?>"> <!--<![endif]-->
 	<head>
-		<!-- <meta http-equiv="X-UA-Compatible" content="IE=edge" /> Doesn't validate... -->
-
 		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
 
 		<title><?php echo $config->getValue('config.sitename') . ' - ' . (in_array($this->error->getCode(), array(404, 403, 500)) ? $this->error->getCode() : 500); ?></title>
@@ -50,9 +48,6 @@ $v = $browser->getBrowserMajorVersion();
 		<script type="text/javascript" src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/js/hub.js"></script>
 		<script type="text/javascript" src="<?php echo $this->baseurl; ?>/modules/mod_reportproblems/mod_reportproblems.js"></script>
 <?php } ?>
-		<!--[if IE 10]>
-			<link rel="stylesheet" type="text/css" media="screen" href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/browser/ie10.css" />
-		<![endif]-->
 		<!--[if IE 9]>
 			<link rel="stylesheet" type="text/css" media="screen" href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template; ?>/css/browser/ie9.css" />
 		<![endif]-->
@@ -86,7 +81,7 @@ $v = $browser->getBrowserMajorVersion();
 									<img src="<?php echo Hubzero_User_Profile_Helper::getMemberPhoto($profile); ?>" alt="<?php echo $juser->get('name'); ?>" width="30" height="30" />
 									<a class="account-details" href="<?php echo JRoute::_('index.php?option=com_members&id=' . $juser->get('id')); ?>">
 										<?php echo stripslashes($juser->get('name')); ?> 
-										<span class="account-email"><?php echo $juser->get('email'); ?></span>
+										<span class="account-username"><?php echo $juser->get('username'); ?></span>
 									</a>
 								</div>
 								<ul>
@@ -108,8 +103,7 @@ $v = $browser->getBrowserMajorVersion();
 					<?php } else { ?>
 						<ul class="menu <?php echo (!$juser->get('guest')) ? 'loggedin' : 'loggedout'; ?>">
 							<li id="account-login">
-								<?php $login_route = (version_compare(JVERSION, '2.5', 'ge')) ? 'index.php?option=com_users&view=login' : 'index.php?option=com_user&view=login'; ?>
-								<a href="<?php echo JRoute::_($login_route); ?>" title="<?php echo JText::_('TPL_HUBBASIC_LOGIN'); ?>"><?php echo JText::_('TPL_HUBBASIC_LOGIN'); ?></a>
+								<a href="<?php echo JRoute::_('index.php?option=com_login'); ?>" title="<?php echo JText::_('TPL_HUBBASIC_LOGIN'); ?>"><?php echo JText::_('TPL_HUBBASIC_LOGIN'); ?></a>
 							</li>
 							<li id="account-register">
 								<a href="<?php echo JRoute::_('index.php?option=com_register'); ?>" title="<?php echo JText::_('TPL_HUBBASIC_SIGN_UP'); ?>"><?php echo JText::_('TPL_HUBBASIC_REGISTER'); ?></a>
@@ -119,7 +113,8 @@ $v = $browser->getBrowserMajorVersion();
 					<?php } ?>
 					</div><!-- / #account -->
 
-					<div id="nav" role="menu">
+					<div id="nav" role="main navigation">
+						<a name="nav"></a>
 						<?php Hubzero_Module_Helper::displayModules('user3'); ?>
 					</div><!-- / #nav -->
 				</div><!-- / .inner -->
@@ -154,58 +149,58 @@ $v = $browser->getBrowserMajorVersion();
 		<div id="wrap">
 			<div id="content" class="<?php echo JRequest::getCmd('option', ''); ?> <?php echo 'code' . $this->error->getCode(); ?>" role="main">
 				<div class="inner">
+					<a name="content" id="content-anchor"></a>
 
 					<div class="main section">
-						<div class="grid">
-							<div class="col span-half">
-								<div id="errormessage">
-									<h2 class="error-code">
-										<?php echo (in_array($this->error->getCode(), array(404, 403, 500))) ? $this->error->getCode() : 500; ?>
-									</h2>
-								</div><!-- / #errormessage -->
-							</div><!-- / .col span-half -->
-							<div class="col span-half omega">
-								<div id="errorbox">
-									<div class="wrap">
+						<div class="two columns first">
+							<div id="errormessage">
+								<h2 class="error-code">
+									<?php echo (in_array($this->error->getCode(), array(404, 403, 500))) ? $this->error->getCode() : 500; ?>
+								</h2>
+							</div><!-- / #errormessage -->
+						</div><!-- / .two columns first -->
+						<div class="two columns second">
+							<div id="errorbox">
+								<div class="wrap">
+								<?php 
+								switch ($this->error->getCode())
+								{
+									case 404: ?>
+									<h3><?php echo JText::_('RE: Your Missing Page'); ?></h3>
+									<blockquote>
+										<p><?php echo JText::_("We're sorry to report that we couldn't find your page. Search parties were unable to recover any remains. It is our current belief that Hubzilla ate it."); ?></p>
+										<p><?php echo JText::_('In a difficult time like this we recommend seeking guidance from our <a href="/home">Home Page</a> or by <a href="/search">searching</a> for a new page. We understand that a new page may never fill the void left by your missing page but hope that you can find some consolation in the text of another.'); ?></p>
+										<p><?php echo JText::_('With our deepest sympathies and condolences,'); ?></p>
+									</blockquote>
+									<p class="signature">&mdash;Cpt. Mura, Science Special Search Party (SSSP)</p>
 									<?php 
-									switch ($this->error->getCode())
-									{
-										case 404: ?>
-										<h3><?php echo JText::_('RE: Your Missing Page'); ?></h3>
-										<blockquote>
-											<p><?php echo JText::_("We're sorry to report that we couldn't find your page. Search parties were unable to recover any remains. It is our current belief that Hubzilla ate it."); ?></p>
-											<p><?php echo JText::_('In a difficult time like this we recommend seeking guidance from our <a href="/home">Home Page</a> or by <a href="/search">searching</a> for a new page. We understand that a new page may never fill the void left by your missing page but hope that you can find some consolation in the text of another.'); ?></p>
-											<p><?php echo JText::_('With our deepest sympathies and condolences,'); ?></p>
-										</blockquote>
-										<p class="signature">&mdash;Cpt. Mura, Science Special Search Party (SSSP)</p>
-										<?php 
-										break;
-										case 403: ?>
-										<h3><?php echo JText::_('Access Denied!'); ?></h3>
-										<blockquote>
-											<p><?php echo JText::_('It appears you do not have access to this page. You may be detained for further questioning.'); ?></p>
-											<p><?php echo JText::_('Please bear with us during this grueling process of rebuilding in the wake of Hubzilla\'s attack.'); ?></p>
-											<p><?php echo JText::_('Please stay calm,'); ?></p>
-										</blockquote>
-										<p class="signature">&mdash;Cpt. Showa, Security</p>
-										<?php 
-										break;
-										case 500: 
-										default: ?>
-										<h3><?php echo JText::_('Will Hubzilla\'s reign of terror never cease?!'); ?></h3>
-										<blockquote>
-											<p><?php echo JText::_('It seems Hubzilla stomped on this page. Our disaster recovery teams are scouring the wreckage for survivors and our clean-up crews will take over shortly thereafter.'); ?></p>
-											<p><?php echo JText::_('Please bear with us during this grueling process of rebuilding in the wake of Hubzilla\'s attack.'); ?></p>
-											<p><?php echo JText::_('With our sincere apologies,'); ?></p>
-										</blockquote>
-										<p class="signature">&mdash;Cpt. Hayata, Disaster Recovery Team (DRT)</p>
-										<?php 
-										break;
-									} ?>
-									</div><!-- / .wrap -->
-								</div><!-- / #errorbox -->
-							</div><!-- / .col span-half omega -->
-						</div><!-- / .grid -->
+									break;
+									case 403: ?>
+									<h3><?php echo JText::_('Access Denied!'); ?></h3>
+									<blockquote>
+										<p><?php echo JText::_('It appears you do not have access to this page. You may be detained for further questioning.'); ?></p>
+										<p><?php echo JText::_('Please bear with us during this grueling process of rebuilding in the wake of Hubzilla\'s attack.'); ?></p>
+										<p><?php echo JText::_('Please stay calm,'); ?></p>
+									</blockquote>
+									<p class="signature">&mdash;Cpt. Showa, Security</p>
+									<?php 
+									break;
+									case 500: 
+									default: ?>
+									<h3><?php echo JText::_('Will Hubzilla\'s reign of terror never cease?!'); ?></h3>
+									<blockquote>
+										<p><?php echo JText::_('It seems Hubzilla stomped on this page. Our disaster recovery teams are scouring the wreckage for survivors and our clean-up crews will take over shortly thereafter.'); ?></p>
+										<p><?php echo JText::_('Please bear with us during this grueling process of rebuilding in the wake of Hubzilla\'s attack.'); ?></p>
+										<p><?php echo JText::_('With our sincere apologies,'); ?></p>
+									</blockquote>
+									<p class="signature">&mdash;Cpt. Hayata, Disaster Recovery Team (DRT)</p>
+									<?php 
+									break;
+								} ?>
+								</div><!-- / .wrap -->
+							</div><!-- / #errorbox -->
+						</div><!-- / .two columns second -->
+						<div class="clear"></div>
 					<?php if ($this->debug) { ?>
 						<p class="error">
 							<?php echo $this->error->getMessage(); ?>
@@ -222,6 +217,7 @@ $v = $browser->getBrowserMajorVersion();
 			</div><!-- / #content -->
 
 			<div id="footer">
+				<a name="footer" id="footer-anchor"></a>
 				<?php Hubzero_Module_Helper::displayModules('footer'); ?>
 			</div><!-- / #footer -->
 		</div><!-- / #wrap -->
